/*
 * ActionToDo.java
 *
 * Created on 21 fvrier 2003, 13:34
 */

package adelfeToolkit.activities;

import adelfeToolkit.language.LanguageChangeSupport;

/** This class represents an action the user of the toolkit has to do. It may be a
 * project, an activity or a step. An ActionToDo may contain seceral sub-works,
 * named steps, and several workproducts to produce.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class ActionToDo implements java.io.Serializable{
  
  /** This class represents a description of an activity or a step. A description
   * points to a html file that contains a description text about the action.
   */  
  private Description description;
  
  /** This class represents an example relative to an ActionToDo. An example points to a html file that contains a
   * sample text that illustrates the action.
   */  
  private Example example;
  
  /** The name of the ActionToDo */  
  private String actionName;
  
  /** A list that contains the different workproducts that have to be produced during
   * the ActionToDo.
   */  
  private WorkProductList workProducts;
  
  /** This value indicates whether the action is accessible by the user. */  
  private boolean accessible = true;
  
  /** This value indicates whether the action is completed. */  
  private boolean completed = true;
  
  /** a string that represents an abbreviation of the ActionToDo */  
  private String abbrev = "";
  
  /** Creates a new instance of ActionToDo */
  public ActionToDo() {
  }
  
  /** Getter for property description.
   * @return Value of property description.
   *
   */
  public Description getDescription() {
    return description;
  }
  
  /** Setter for property description.
   * @param description New value of property description.
   *
   */
  public void setDescription(Description description) {
    this.description = description;
  }
  
  /** Getter for property example.
   * @return Value of property example.
   *
   */
  public Example getExample() {
    return example;
  }
  
  /** Setter for property example.
   * @param example New value of property example.
   *
   */
  public void setExample(Example example) {
    this.example = example;
  }
  
  /** Getter for property actionName.
   * @return Value of property actionName.
   *
   */
  public java.lang.String getActionName() {
    return actionName;
  }
  
  /** Setter for property actionName.
   * @param actionName New value of property actionName.
   *
   */
  public void setActionName(java.lang.String actionName) {
    this.actionName = actionName;
  }
  
  /** Getter for property workProducts.
   * @return Value of property workProducts.
   */
  public WorkProductList getWorkProducts() {
    return workProducts;
  }
  
  /** Setter for property workProducts.
   * @param workProducts New value of property workProducts.
   *
   */
  public void setWorkProducts(WorkProductList workProducts) {
    this.workProducts = workProducts;
  }
  
  /** Getter for property accessible.
   * @return Value of property accessible.
   *
   */
  public boolean isAccessible() {
    return accessible;
  }
  
  /** Setter for property accessible.
   * @param accessible New value of property accessible.
   *
   */
  public void setAccessible(boolean accessible) {
    this.accessible = accessible;
  }
  
  /** Getter for property completed.
   * @return Value of property completed.
   *
   */
  public boolean isCompleted() {
    return completed;
  }
  
  /** Setter for property completed.
   * @param completed New value of property completed.
   *
   */
  public void setCompleted(boolean completed) {
    this.completed = completed;
  }
  
  /** Produces a String that represents the ActionToDo.
   * @return The String that represents the ActionToDo.
   */  
  public String toString() {
    return (getActionName());
  }
  
  /** This method returns a representative string of the ActionToDo in terms of a
   * LanguageChangeSupport, in which appears the ResourceBundle that contains
   * descriptions
   * @param lcs the LanguageChangeSupport that manage the language changes
   * @return The string that represents the ActionToDo
   */  
  public String toString(LanguageChangeSupport lcs) {
    return (lcs.getRessourceBundle().getString(this.getActionName()));
  }
  
  /** Getter for property abbrev.
   * @return Value of property abbrev.
   *
   */
  public java.lang.String getAbbrev() {
    return abbrev;
  }
  
  /** Setter for property abbrev.
   * @param abbrev New value of property abbrev.
   *
   */
  public void setAbbrev(java.lang.String abbrev) {
    this.abbrev = abbrev;
  }
}
