/*
 * Activity.java
 *
 * Created on 2 dcembre 2002, 10:22
 */

package adelfeToolkit.activities;

import java.io.Serializable;
import adelfeToolkit.language.*;

/** This class represents a SPEM activity.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class Activity extends ActionToDo implements Serializable, ToolTipable {
  
  /** The current step of the ActionToDo. */  
  private ActionToDo currentStep = null;
  
  /** The index of the current step in the StepList. */  
  private int currentIndex = -1;
  
  /** The list that contains the sub-steps. */  
  private StepList steps = new StepList();
  
  //  private StepList stepList = null;
  
  /** Creates a new instance of Activity */
  public Activity() {
  }
  
  /** Creates a new instance of Activity with initial values :
   * @param ab value for the abbrev field
   * @param access value for accessible field
   * @param wp value for workProducts field
   * @param ex value for example field
   * @param n value for actionName field
   * @param des value for description field
   * @param sl value for stepList field
   */  
  public Activity(boolean access, WorkProductList wp, Example ex, String n, Description des, StepList sl, String ab) {
    setAccessible(access);
    setWorkProducts(wp);
    setExample(ex);
    setActionName(n);
    setDescription(des);
    setSteps(sl);
    setAbbrev(ab);
    setCompleted(false);
  }
  
  /** Getter for property steps.
   * @return Value of property steps.
   *
   */
  public StepList getSteps() {
    return steps;
  }
  
  /** Setter for property steps.
   * @param steps New value of property steps.
   *
   */
  public void setSteps(StepList steps) {
    this.steps = steps;
    initializeStepWorkProductLists();
    if (steps.size() > 0) {
    }
  }
  
  /** This methods intializes the workproduct list of the each step of the steps field to
   * the value of workProducts. In fact all the steps of an activity have the same
   * workproduct list than the parent activity.
   */  
  private void initializeStepWorkProductLists() {
    int i = 0;
    while (i < steps.size()) {
      ((Step)steps.get(i)).setWorkProducts(getWorkProducts());
      i++;
    }
  }
  
  /** Getter for property currentStep.
   * @return Value of property currentStep.
   *
   */
  public ActionToDo getCurrentStep() {
    if (currentIndex != -1) {
      return currentStep;
    }
    else {
      return this;
    }
  }
  
  /** Setter for property currentStep.
   * @param currentStep New value of property currentStep.
   *
   */
  public void setCurrentStep(ActionToDo currentStep) {
    this.currentStep = currentStep;
  }
  
  /** Getter for property currentIndex.
   * @return Value of property currentIndex.
   *
   */
  public int getCurrentIndex() {
    return currentIndex;
  }
  
  /** Setter for property currentIndex.
   * @param currentIndex New value of property currentIndex.
   *
   */
  public void setCurrentIndex(int currentIndex) {
    this.currentIndex = currentIndex;
  }
  
  /** This method returns a string that represents the state of the Activity (name,
   * completed, ...).
   * @return The string that represents the state of the Activity
   */  
  public String displayString() {
    return ("Activity:"+getActionName()+" ; "+"completed:"+isCompleted());
  }
  
  /** This method returns a representative string of the Activity in terms of a
   * LanguageChangeSupport, in which appears the ResourceBundle that contains
   * descriptions
   * @param lcs the LanguageChangeSupport that manage the language changes
   * @return The string that represents the Activity
   */  
  public String toString(LanguageChangeSupport lcs) {
    return (this.getActionName()+ " - " + lcs.getRessourceBundle().getString(this.getActionName()));
  }
  
  /** This method sets the "completed" field to  given value of the current Activity
   * if the given name correspond or to try to fing a steps that corresponds
   * @param an the name of the action to sets
   * @param comp the new value
   */  
  public void setCompl(String an, boolean comp) {
    if (this.getActionName().equals(an)) {
      this.setCompleted(comp);
    }
    else {
      for (int i = 0;i<this.getSteps().size();i++) {
        ((Step)this.getSteps().get(i)).setCompl(an,comp);
      }
    }
  }
  
  /** This method sets the "accessible" field to  given value of the current Activity
   * if the given name correspond or to try to fing a steps that corresponds
   * @param an the name of the action to sets
   * @param acces the new value
   */  
  public void setAcces(String an, boolean acces) {
    if (this.getActionName().equals(an)) {
      this.setAccessible(acces);
    }
    else {
      for (int i = 0;i<this.getSteps().size();i++) {
        ((Step)this.getSteps().get(i)).setAcces(an,acces);
      }
    }
  }
}
