/*
 * DefaultActivityListCreator.java
 *
 * Created on 5 dcembre 2002, 14:53
 */

package adelfeToolkit.activities;

import java.io.ObjectOutputStream;
import java.io.FileOutputStream;
import adelfeToolkit.shortcuts.*;
import adelfeToolkit.utilities.*;

/** This class is a creator of default file for the AdelfeToolkit. It creates a dlf
 * file by serializing a Project object containing default activities and steps.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class DefaultProjectCreator {
  
  /** The default path to find the files the Description and Example objects have to point
   * to.
   */
  public final static String DEFAULT_PATH = "";
  
  /** The default Activity file name. */
  public final static String DEFAULT_FILE = "defaultActivity.html";
  
  /** Path to the OpenTool icon. */  
  public final static String OT_ICON = "/adelfeToolkit/resources/images/LienOT.jpg";
  
  /** Path to the drawing tool icon. */  
  public final static String DRAWING_ICON = "/adelfeToolkit/resources/images/LienDessin.gif";
  
  /** Path to the AMAS adequacy tool icon. */  
  public final static String ADEQ_ICON = "/adelfeToolkit/resources/images/LienAdeq.jpg";
  
  /** Path to the text editor icon. */  
  public final static String TEXT_ICON = "/adelfeToolkit/resources/images/LienFich.jpg";
  
  /** This string is a prefix for the descriptions. */  
  public final static String DF = "DF";
  /** This string is a prefix for the examples. */  
  public final static String EF = "EF";
  /** The default activity name. */  
  public final static String Default = "Introduction";
  /** Name of a activity or step. */  
  public final static String Define_User_Requirements = "Act01";
  /** Name of a activity or step. */  
  public final static String Validate_Requirements = "Act02";
  /** Name of a activity or step. */  
  public final static String Define_Consensual_Requirements = "Act03";
  /** Name of a activity or step. */  
  public final static String Establish_Keyword_Set = "Act04";
  /** Name of a activity or step. */  
  public final static String Extract_Limits_And_Constraints = "Act05";
  /** Name of a activity or step. */  
  public final static String Characterize_Environment = "Act06";
  /** Name of a activity or step. */  
  public final static String Determine_Use_Cases = "Act07";
  /** Name of a activity or step. */  
  public final static String Elaborate_UI_Prototypes = "Act08";
  /** Name of a activity or step. */  
  public final static String Validate_UI_Prototypes = "Act09";
  /** Name of a activity or step. */  
  public final static String Analyze_Domain = "Act10";
  /** Name of a activity or step. */  
  public final static String Verify_AMAS_Adequacy = "Act11";
  /** Name of a activity or step. */  
  public final static String Identify_Agents = "Act12";
  /** Name of a activity or step. */  
  public final static String Study_Interaction_Between_Entities = "Act13";
  /** Name of a activity or step. */  
  public final static String Study_Detailed_Architecture_And_MA_Model = "Act14";
  /** Name of a activity or step. */  
  public final static String Study_Interaction_Languages = "Act15";
  /** Name of a activity or step. */  
  public final static String Design_Agents = "Act16";
  /** Name of a activity or step. */  
  public final static String Fast_Prototyping = "Act17";
  /** Name of a activity or step. */  
  public final static String Complete_Design_Diagrams = "Act18";
  /** Name of a activity or step. */  
  public final static String Determine_Actors = "Stp01Act06";
  /** Name of a activity or step. */  
  public final static String Define_Context = "Stp02Act06";
  /** Name of a activity or step. */  
  public final static String Characterize_The_Environment = "Stp03Act06";
  /** Name of a activity or step. */  
  public final static String Draw_Up_An_Inventory_Of_Use_Cases = "Stp01Act07";
  /** Name of a activity or step. */  
  public final static String Identify_Cooperation_Failure_Possibilities = "Stp02Act07";
  /** Name of a activity or step. */  
  public final static String Elaborate_Sequence_Diagrams = "Stp03Act07";
  /** Name of a activity or step. */  
  public final static String Identify_Classes = "Stp01Act10";
  /** Name of a activity or step. */  
  public final static String Study_Interclass_Relationship = "Stp02Act10";
  /** Name of a activity or step. */  
  public final static String Construct_Preliminary_Class_Diagrams = "Stp03Act10";
  /** Name of a activity or step. */  
  public final static String Verify_Global_Level_AMAS_Adequacy = "Stp01Act11";
  /** Name of a activity or step. */  
  public final static String Verify_Local_Level_AMAS_Adequacy = "Stp02Act11";
  /** Name of a activity or step. */  
  public final static String Study_Entities_In_Domain_Context = "Stp01Act12";
  /** Name of a activity or step. */  
  public final static String Identify_Potentially_Cooperative_Entities = "Stp02Act12";
  /** Name of a activity or step. */  
  public final static String Determine_Agents = "Stp03Act12";
  /** Name of a activity or step. */  
  public final static String Study_Active_Passive_Entities_Relationships = "Stp01Act13";
  /** Name of a activity or step. */  
  public final static String Study_Active_Entities_Relationships = "Stp02Act13";
  /** Name of a activity or step. */  
  public final static String Study_Agents_Relationships = "Stp03Act13";
  /** Name of a activity or step. */  
  public final static String Determine_Packages = "Stp01Act14";
  /** Name of a activity or step. */  
  public final static String Determine_Classes = "Stp02Act14";
  /** Name of a activity or step. */  
  public final static String Use_Design_Patterns = "Stp03Act14";
  /** Name of a activity or step. */  
  public final static String Elaborate_Component_And_Class_Diagrams = "Stp04Act14";
  /** Name of a activity or step. */  
  public final static String Define_Interaction_Languages = "Stp03Act16";
  /** Name of a activity or step. */  
  public final static String Define_Skills = "Stp01Act16";
  /** Name of a activity or step. */  
  public final static String Define_Aptitudes = "Stp02Act16";
  /** Name of a activity or step. */  
  public final static String Define_World_Representations = "Stp04Act16";
  /** Name of a activity or step. */  
  public final static String Define_NCSs = "Stp05Act16";
  /** Name of a activity or step. */  
  public final static String Enhance_Design_Diagrams = "Stp01Act18";
  /** Name of a activity or step. */  
  public final static String Design_Dynamic_Behavior = "Stp02Act18";
  
  /** requirements set */  
  public static String RS = "Requirement_Set";
  
  /** keywords set */  
  public static String KS = "Keyword_Set";
  
  /** preliminary requirements */  
  public static String PR = "Preliminary_Requirements_WorkProduct";
  
  /** functional description */  
  public static String FD = "Functional_Description";
  
  /** scenarios */  
  public static String SC = "Scenarios";
  
  /** interface models */  
  public static String IM = "Interface_Models";
  
  /** environment definition */  
  public static String ED = "Environment_Definition";
  
  /** UI prototypes */  
  public static String UP = "UI_Prototypes";
  
  /** final requirements */  
  public static String FR = "Final_Requirements_WorkProduct";
  
  /** Internal Interactions Between Domain Classes */  
  public static String II = "Internal_Interactions_Between_Domain_Classes";
  
  /** domain model */  
  public static String DM = "Domain_Model";
  
  /** software architecture */  
  public static String SA = "Software_Architecture";
  
  /** amas adequacy synthesis */  
  public static String AA = "AMAS_Adequacy_Synthesis";
  
  /** analysis */  
  public static String AN = "Analysis_WorkProduct";
  
  /** protocol diagrams */  
  public static String PD = "Protocol_Diagrams";
  
  /** detailed models */  
  public static String DS = "Design_Models";
  
  /** interaction languages */  
  public static String IL = "Interaction_Languages";
  
  /** detailed architecture */  
  public static String DA = "Detailled_Architecture";
  
  /** design */  
  public static String DE = "Design_WorkProduct";
  
  
  
  /** Creates a new instance of DefaultActivityListCreator */
  public DefaultProjectCreator() {
  }
  
  /** The main method that really creates a Project and that serializes it to a dlf
   * file.
   * @param args the command line arguments
   */
  public static void main(String[] args) {
    
    //WorkProducts creation
    Document requirementSet = new Document();
    requirementSet.setName(RS);
    
    Document keywordSet = new Document();
    keywordSet.setName(KS);
    
    WorkProduct preliminaryRequirementsWorkProduct = new WorkProduct();
    preliminaryRequirementsWorkProduct.setName(PR);
    preliminaryRequirementsWorkProduct.setFile(null);
    preliminaryRequirementsWorkProduct.getSubWorkProducts().add(requirementSet);
    preliminaryRequirementsWorkProduct.getSubWorkProducts().add(keywordSet);
    
    Model functionalDescription = new Model();
    functionalDescription.setName(FD);
    
    Model scenarios = new Model();
    scenarios.setName(SC);
    
    Model interfaceModels = new Model();
    interfaceModels.setName(IM);
    
    Document environmentDefinition = new Document();
    environmentDefinition.setName(ED);
    environmentDefinition.getSubWorkProducts().add(functionalDescription);
    environmentDefinition.getSubWorkProducts().add(scenarios);
    
    Document uIPrototypes = new Document();
    uIPrototypes.setName(UP);
    uIPrototypes.getSubWorkProducts().add(interfaceModels);
    
    WorkProduct finalRequirementsWorkProduct = new WorkProduct();
    finalRequirementsWorkProduct.setName(FR);
    finalRequirementsWorkProduct.setFile(null);
    finalRequirementsWorkProduct.getSubWorkProducts().add(environmentDefinition);
    finalRequirementsWorkProduct.getSubWorkProducts().add(uIPrototypes);
    
    Model internalInteractionsBetweenDomainClasses = new Model();
    internalInteractionsBetweenDomainClasses.setName(II);
   
    Model domainModel = new Model();
    domainModel.setName(DM);
    
    Document softwareArchitecture = new Document();
    softwareArchitecture.setName(SA);
    softwareArchitecture.getSubWorkProducts().add(internalInteractionsBetweenDomainClasses);
    softwareArchitecture.getSubWorkProducts().add(domainModel);
    
    Document amasAdequacySynthesis = new Document();
    amasAdequacySynthesis.setName(AA);
    
    WorkProduct analysisWorkProduct = new WorkProduct();
    analysisWorkProduct.setName(AN);
    analysisWorkProduct.setFile(null);
    analysisWorkProduct.getSubWorkProducts().add(softwareArchitecture);
    analysisWorkProduct.getSubWorkProducts().add(amasAdequacySynthesis);
    
    Model protocolDiagrams = new Model();
    protocolDiagrams.setName(PD);
    
    Model designModels = new Model();
    designModels.setName(DS);
    
    Document interactionLanguages = new Document();
    interactionLanguages.setName(IL);
    interactionLanguages.getSubWorkProducts().add(protocolDiagrams);
    
    Document detailledArchitecture = new Document();
    detailledArchitecture.setName(DA);
    detailledArchitecture.getSubWorkProducts().add(designModels);
    
    WorkProduct designWorkProduct = new WorkProduct();
    designWorkProduct.setName(DE);
    designWorkProduct.setFile(null);
    designWorkProduct.getSubWorkProducts().add(interactionLanguages);
    designWorkProduct.getSubWorkProducts().add(detailledArchitecture);
    
    //WorkProductLists creation
    WorkProductList preliminaryRequirementsWorkProductList = new WorkProductList();
    preliminaryRequirementsWorkProductList.add(preliminaryRequirementsWorkProduct);
    
    WorkProductList finalRequirementsWorkProductList = new WorkProductList();
    finalRequirementsWorkProductList.add(finalRequirementsWorkProduct);
    
    WorkProductList analysisWorkProductList = new WorkProductList();
    analysisWorkProductList.add(analysisWorkProduct);
    
    WorkProductList designWorkProductList = new WorkProductList();
    designWorkProductList.add(designWorkProduct);
    
    WorkProductList projectWorkProductList = new WorkProductList();
    projectWorkProductList.add(preliminaryRequirementsWorkProduct);
    projectWorkProductList.add(finalRequirementsWorkProduct);
    projectWorkProductList.add(analysisWorkProduct);
    projectWorkProductList.add(designWorkProduct);
    
    WorkProductList defaultWorkProductList = new WorkProductList();
    WorkProductList defineUserRequirementsWorkProductList = new WorkProductList();
    defineUserRequirementsWorkProductList.add(requirementSet);
    WorkProductList validateRequirementsWorkProductList = new WorkProductList();
    validateRequirementsWorkProductList.add(requirementSet);
    WorkProductList defineConsensualRequirementsWorkProductList = new WorkProductList();
    defineConsensualRequirementsWorkProductList.add(requirementSet);
    WorkProductList establishKeywordSetWorkProductList = new WorkProductList();
    establishKeywordSetWorkProductList.add(keywordSet);
    WorkProductList extractLimitsAndConstraintsWorkProductList = new WorkProductList();
    extractLimitsAndConstraintsWorkProductList.add(requirementSet);
    WorkProductList characterizeEnvironmentWorkProductList = new WorkProductList();
    characterizeEnvironmentWorkProductList.add(environmentDefinition);
    WorkProductList determineUseCasesWorkProductList = new WorkProductList();
    determineUseCasesWorkProductList.add(environmentDefinition);
    WorkProductList elaborateUIPrototypesWorkProductList = new WorkProductList();
    elaborateUIPrototypesWorkProductList.add(uIPrototypes);
    WorkProductList validateUIPrototypesWorkProductList = new WorkProductList();
    validateUIPrototypesWorkProductList.add(uIPrototypes);
    validateUIPrototypesWorkProductList.add(environmentDefinition);
    WorkProductList analyzeDomainWorkProductList = new WorkProductList();
    analyzeDomainWorkProductList.add(softwareArchitecture);
    WorkProductList verifyAMASAdequacyWorkProductList = new WorkProductList();
    verifyAMASAdequacyWorkProductList.add(amasAdequacySynthesis);
    WorkProductList identifyAgentsWorkProductList = new WorkProductList();
    identifyAgentsWorkProductList.add(softwareArchitecture);
    WorkProductList studyInteractionsBetweenEntitiesWorkProductList = new WorkProductList();
    studyInteractionsBetweenEntitiesWorkProductList.add(softwareArchitecture);
    studyInteractionsBetweenEntitiesWorkProductList.add(environmentDefinition);
    WorkProductList studyDetailledArchitectureAndMAModelWorkProductList = new WorkProductList();
    studyDetailledArchitectureAndMAModelWorkProductList.add(detailledArchitecture);
    WorkProductList studyInteractionLanguageWorkProductList = new WorkProductList();
    studyInteractionLanguageWorkProductList.add(interactionLanguages);
    WorkProductList designAgentsWorkProductList = new WorkProductList();
    designAgentsWorkProductList.add(interactionLanguages);
    designAgentsWorkProductList.add(detailledArchitecture);
    WorkProductList fastPrototypingWorkProductList = new WorkProductList();
    fastPrototypingWorkProductList.add(interactionLanguages);
    fastPrototypingWorkProductList.add(detailledArchitecture);
    WorkProductList completeDesignDiagramsWorkProductList = new WorkProductList();
    completeDesignDiagramsWorkProductList.add(detailledArchitecture);
    
    //Shortcuts creation
    CreateAndOpenUCD createAndOpenUCD = new CreateAndOpenUCD("Create_and_Open_Use_Case_Diagram",OT_ICON,"");
    OpenUCD openUCD = new OpenUCD("Open_Use_Case_Diagram",OT_ICON,"");
    OpenSD openSD = new OpenSD("Open_Sequence(s)_Diagram(s)",OT_ICON,"");
    CreateAndOpenCD createAndOpenCD = new CreateAndOpenCD("Create_and_Open_Class_Diagram",OT_ICON,"");
    CreateAndOpenCLBD createAndOpenCLBD = new CreateAndOpenCLBD("Create_and_Open_Collaboration_Diagram",OT_ICON,"");
    CreateAndOpenCDWithClasses createAndOpenCDWithClasses = new CreateAndOpenCDWithClasses("Create_and_Open_Class_Diagram_with_Existing_Classes",OT_ICON,"");
    OpenCD openCD = new OpenCD("Open_Class_Diagram",OT_ICON,"");
    OpenDrawingTool openDrawingTool = new OpenDrawingTool("Open_Drawing_Tool", DRAWING_ICON, "");
    OpenAMASAdequacyTool openAMASAdequacyTool = new OpenAMASAdequacyTool("Open_AMAS_Adequacy_Tool",ADEQ_ICON,"");
    OpenPD openPD = new OpenPD("Open_Protocol_Diagram",OT_ICON,"");
    CreateAndOpenPackagesCD createAndOpenPackagesCD = new CreateAndOpenPackagesCD("Create_and_Open_Packages_Class_Diagram",OT_ICON,"");
    OpenPackagesCD openPackagesCD = new OpenPackagesCD("Open_Packages_Class_Diagram",OT_ICON,"");
    CreateAndOpenAgentsCD createAndOpenAgentsCD = new CreateAndOpenAgentsCD("Create_and_Open_Agents_Class_Diagram",OT_ICON,"");
    OpenAgentsCD openAgentsCD = new OpenAgentsCD("Open_Agents_Class_Diagram",OT_ICON,"");
    CreateAndOpenFIG createAndOpenFIG = new CreateAndOpenFIG("Create_and_Open_UI_Figure",OT_ICON,"");
    OpenFIG openFIG = new OpenFIG("Open_UI_Figure",OT_ICON,"");
    OpenTextEditor openTextEditor = new OpenTextEditor("Open_text_Editor", TEXT_ICON, "");
    OpenNCSTemplateRtf openNCSTemplate = new OpenNCSTemplateRtf("Open_NCS_Template", TEXT_ICON, "");
    OpenRequirementsTemplateRtf openRequirementsTemplate = new OpenRequirementsTemplateRtf("Open_Requirements_Template", TEXT_ICON, "");
    
    //Activity descriptions creation
    Description defaultActivityDescription = new Description(DEFAULT_PATH,"AdelfeIntroduction.html",Default);
    Description defineUserRequirementsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act01.html",Define_User_Requirements);
    Description validateRequirementsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act02.html",Validate_Requirements);
    Description defineConsensualRequirementsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act03.html",Define_Consensual_Requirements);
    Description establishKeywordSetDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act04.html",Establish_Keyword_Set);
    Description extractLimitsAndConstraintsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act05.html",Extract_Limits_And_Constraints);
    Description characterizeEnvironmentDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act06.html",Characterize_Environment);
    Description determineUseCasesDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act07.html",Determine_Use_Cases);
    Description elaborateUIPrototypesDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act08.html",Elaborate_UI_Prototypes);
    Description validateUIPrototypesDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act09.html",Validate_UI_Prototypes);
    Description analyzeDomainDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act10.html",Analyze_Domain);
    Description verifyAMASAdequacyDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act11.html",Verify_AMAS_Adequacy);
    Description identifyAgentsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act12.html",Identify_Agents);
    Description studyInteractionsBetweenEntitiesDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act13.html",Study_Interaction_Between_Entities);
    Description studyDetailledArchitectureAndMAModelDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act14.html",Study_Detailed_Architecture_And_MA_Model);
    Description studyInteractionLanguageDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act15.html",Study_Interaction_Languages);
    Description designAgentsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act16.html",Design_Agents);
    Description fastPrototypingDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act17.html",Fast_Prototyping);
    Description completeDesignDiagramsDescription  = new Description(DEFAULT_PATH+"ACTIVITIES/","Act18.html",Complete_Design_Diagrams);
    
    //Activity Description Shortcuts Affectation
    defineUserRequirementsDescription.getShortcuts().add(openRequirementsTemplate);
    establishKeywordSetDescription.getShortcuts().add(openTextEditor);
    elaborateUIPrototypesDescription.getShortcuts().add(openDrawingTool);
    elaborateUIPrototypesDescription.getShortcuts().add(createAndOpenFIG);
    validateUIPrototypesDescription.getShortcuts().add(openFIG);
    studyInteractionLanguageDescription.getShortcuts().add(createAndOpenAgentsCD);
    studyInteractionLanguageDescription.getShortcuts().add(openPD);
    designAgentsDescription.getShortcuts().add(openAgentsCD);
    fastPrototypingDescription.getShortcuts().add(createAndOpenCLBD);
    
    //Activity examples creation
    Example defaultActivityExample = new Example(DEFAULT_PATH,"Help.html","Introduction");
    Example defineUserRequirementsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct01.html",Define_User_Requirements);
    Example validateRequirementsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct02.html",Validate_Requirements);
    Example defineConsensualRequirementsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct03.html",Define_Consensual_Requirements);
    Example establishKeywordSetExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct04.html",Establish_Keyword_Set);
    Example extractLimitsAndConstraintsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct05.html",Extract_Limits_And_Constraints);
    Example characterizeEnvironmentExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct06.html",Characterize_Environment);
    Example determineUseCasesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct07.html",Determine_Use_Cases);
    Example elaborateUIPrototypesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct08.html",Elaborate_UI_Prototypes);
    Example validateUIPrototypesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct09.html",Validate_UI_Prototypes);
    Example analyzeDomainExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct10.html",Analyze_Domain);
    Example verifyAMASAdequacyExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct11.html",Verify_AMAS_Adequacy);
    Example identifyAgentsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct12.html",Identify_Agents);
    Example studyInteractionsBetweenEntitiesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct13.html",Study_Interaction_Between_Entities);
    Example studyDetailledArchitectureAndMAModelExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct14.html",Study_Detailed_Architecture_And_MA_Model);
    Example studyInteractionLanguageExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct15.html",Study_Interaction_Languages);
    Example designAgentsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct16.html",Design_Agents);
    Example fastPrototypingExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct17.html",Fast_Prototyping);
    Example completeDesignDiagramsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExAct18.html",Complete_Design_Diagrams);
    
    //Step descriptions creation
    Description determineActorsAndEntititesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act06.html",Determine_Actors);
    Description defineContextDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act06.html",Define_Context);
    Description characterizeTheEnvironmentDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act06.html",Characterize_The_Environment);
    Description drawUpAnInventoryOfUseCasesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act07.html",Draw_Up_An_Inventory_Of_Use_Cases);
    Description identifyCooperationFailurePossibilityDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act07.html",Identify_Cooperation_Failure_Possibilities);
    Description elaborateSequenceDiagramsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act07.html",Elaborate_Sequence_Diagrams);
    Description identifyClassesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act10.html",Identify_Classes);
    Description studyInterclassRelationshipDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act10.html",Study_Interclass_Relationship);
    Description constructPreliminaryClassDiagramsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act10.html",Construct_Preliminary_Class_Diagrams);
    Description verifyGlobalLevelAMASAdequacyDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act11.html",Verify_Global_Level_AMAS_Adequacy);
    Description verifyLocalLevelAMASAdequacyDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act11.html",Verify_Local_Level_AMAS_Adequacy);
    Description studyEntitiesInDomainContextDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act12.html",Study_Entities_In_Domain_Context);
    Description identifyPotentiallyCooperativeEntitiesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act12.html",Identify_Potentially_Cooperative_Entities);
    Description determineAgentsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act12.html",Determine_Agents);
    Description studyActivePassiveEntitiesRelationshipsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act13.html",Study_Active_Passive_Entities_Relationships);
    Description studyActiveEntitiesRelationshipsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act13.html",Study_Active_Entities_Relationships);
    Description studyAgentsRelationshipsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act13.html",Study_Agents_Relationships);
    Description determinePackagesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act14.html",Determine_Packages);
    Description determineClassesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act14.html",Determine_Classes);
    Description useDesignPatternsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act14.html",Use_Design_Patterns);
    Description elaborateComponentAndClassDiagramsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp04Act14.html",Elaborate_Component_And_Class_Diagrams);
    Description defineSkillsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act16.html",Define_Skills);
    Description defineAptitudesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act16.html",Define_Aptitudes);
    Description determineInteractionLanguagesDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp03Act16.html",Define_Interaction_Languages);
    Description defineWorldRepresentationDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp04Act16.html",Define_World_Representations);
    Description defineNCSDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp05Act16.html",Define_NCSs);
    Description enhanceDesignDiagramsDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp01Act18.html",Enhance_Design_Diagrams);
    Description designDynamicBehaviorDescription  = new Description(DEFAULT_PATH+"STEPS/","Stp02Act18.html",Design_Dynamic_Behavior);
    
    //Step Description Shortcuts Affectation
    determineActorsAndEntititesDescription.getShortcuts().add(createAndOpenUCD);
    defineContextDescription.getShortcuts().add(openUCD);
    drawUpAnInventoryOfUseCasesDescription.getShortcuts().add(openUCD);
    identifyCooperationFailurePossibilityDescription.getShortcuts().add(openUCD);
    elaborateSequenceDiagramsDescription.getShortcuts().add(openSD);
    identifyClassesDescription.getShortcuts().add(openUCD);
    studyInterclassRelationshipDescription.getShortcuts().add(openUCD);
    studyInterclassRelationshipDescription.getShortcuts().add(openSD);
    constructPreliminaryClassDiagramsDescription.getShortcuts().add(createAndOpenCDWithClasses);
    verifyGlobalLevelAMASAdequacyDescription.getShortcuts().add(openAMASAdequacyTool);
    verifyLocalLevelAMASAdequacyDescription.getShortcuts().add(openAMASAdequacyTool);
    determineAgentsDescription.getShortcuts().add(openCD);
    studyActivePassiveEntitiesRelationshipsDescription.getShortcuts().add(openCD);
    studyActiveEntitiesRelationshipsDescription.getShortcuts().add(openCD);
    studyAgentsRelationshipsDescription.getShortcuts().add(openPD);
    determinePackagesDescription.getShortcuts().add(createAndOpenPackagesCD);
    determineClassesDescription.getShortcuts().add(openPackagesCD);
    elaborateComponentAndClassDiagramsDescription.getShortcuts().add(openPackagesCD);
    defineSkillsDescription.getShortcuts().add(openAgentsCD);
    defineAptitudesDescription.getShortcuts().add(openAgentsCD);
    determineInteractionLanguagesDescription.getShortcuts().add(openAgentsCD);
    defineWorldRepresentationDescription.getShortcuts().add(openAgentsCD);
    defineNCSDescription.getShortcuts().add(openNCSTemplate);
    enhanceDesignDiagramsDescription.getShortcuts().add(openCD);
    enhanceDesignDiagramsDescription.getShortcuts().add(openPackagesCD);
    enhanceDesignDiagramsDescription.getShortcuts().add(openAgentsCD);
    designDynamicBehaviorDescription.getShortcuts().add(openCD);
    designDynamicBehaviorDescription.getShortcuts().add(openPackagesCD);
    designDynamicBehaviorDescription.getShortcuts().add(openAgentsCD);
    
    //Step examples creation
    Example determineActorsAndEntititesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act06.html",Determine_Actors);
    Example defineContextExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act06.html",Define_Context);
    Example characterizeTheEnvironmentExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act06.html",Characterize_The_Environment);
    Example drawUpAnInventoryOfUseCasesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act07.html",Draw_Up_An_Inventory_Of_Use_Cases);
    Example identifyCooperationFailurePossibilityExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act07.html",Identify_Cooperation_Failure_Possibilities);
    Example elaborateSequenceDiagramsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act07.html",Elaborate_Sequence_Diagrams);
    Example identifyClassesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act10.html",Identify_Classes);
    Example studyInterclassRelationshipExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act10.html",Study_Interclass_Relationship);
    Example constructPreliminaryClassDiagramsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act10.html",Construct_Preliminary_Class_Diagrams);
    Example verifyGlobalLevelAMASAdequacyExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act11.html",Verify_Global_Level_AMAS_Adequacy);
    Example verifyLocalLevelAMASAdequacyExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act11.html",Verify_Local_Level_AMAS_Adequacy);
    Example studyEntitiesInDomainContextExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act12.html",Study_Entities_In_Domain_Context);
    Example identifyPotentiallyCooperativeEntitiesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act12.html",Identify_Potentially_Cooperative_Entities);
    Example determineAgentsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act12.html",Determine_Agents);
    Example studyActivePassiveEntitiesRelationshipsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act13.html",Study_Active_Passive_Entities_Relationships);
    Example studyActiveEntitiesRelationshipsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act13.html",Study_Active_Entities_Relationships);
    Example studyAgentsRelationshipsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act13.html",Study_Agents_Relationships);
    Example determinePackagesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act14.html",Determine_Packages);
    Example determineClassesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act14.html",Determine_Classes);
    Example useDesignPatternsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act14.html",Use_Design_Patterns);
    Example elaborateComponentAndClassDiagramsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp04Act14.html",Elaborate_Component_And_Class_Diagrams);
    Example defineInteractionLanguagesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act15.html",Define_Interaction_Languages);
    Example defineSkillsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act16.html",Define_Skills);
    Example defineAptitudesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act16.html",Define_Aptitudes);
    Example determineInteractionLanguagesExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp03Act16.html",Define_Interaction_Languages);
    Example defineWorldRepresentationExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp04Act16.html",Define_World_Representations);
    Example defineNCSExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp05Act16.html",Define_NCSs);
    Example enhanceDesignDiagramsExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp01Act18.html",Enhance_Design_Diagrams);
    Example designDynamicBehaviorExample = new Example(DEFAULT_PATH+"EXAMPLE/","ExStp02Act18.html",Design_Dynamic_Behavior);
    
    //Steps creation
    Step determineActorsAndEntitites = new Step(false,determineActorsAndEntititesExample,Determine_Actors,determineActorsAndEntititesDescription,"Act6 Stp1");
    Step defineContext = new Step(false,defineContextExample,Define_Context,defineContextDescription,"Act6 Stp2");
    Step characterizeTheEnvironment = new Step(false,characterizeTheEnvironmentExample,Characterize_The_Environment,characterizeTheEnvironmentDescription,"Act6 Stp3");
    Step drawUpAnInventoryOfUseCases = new Step(false,drawUpAnInventoryOfUseCasesExample,Draw_Up_An_Inventory_Of_Use_Cases,drawUpAnInventoryOfUseCasesDescription,"Act7 Stp1");
    Step identifyCooperationFailurePossibility = new Step(false,identifyCooperationFailurePossibilityExample,Identify_Cooperation_Failure_Possibilities,identifyCooperationFailurePossibilityDescription,"Act7 Stp2");
    Step elaborateSequenceDiagrams = new Step(false,elaborateSequenceDiagramsExample,Elaborate_Sequence_Diagrams,elaborateSequenceDiagramsDescription,"Act7 Stp3");
    Step identifyClasses = new Step(false,identifyClassesExample,Identify_Classes,identifyClassesDescription,"Act10 Stp1");
    Step studyInterclassRelationship = new Step(false,studyInterclassRelationshipExample,Study_Interclass_Relationship,studyInterclassRelationshipDescription,"Act10 Stp2");
    Step constructPreliminaryClassDiagrams = new Step(false,constructPreliminaryClassDiagramsExample,Construct_Preliminary_Class_Diagrams,constructPreliminaryClassDiagramsDescription,"Act10 Stp3");
    Step verifyGlobalLevelAMASAdequacy = new Step(false,verifyGlobalLevelAMASAdequacyExample,Verify_Global_Level_AMAS_Adequacy,verifyGlobalLevelAMASAdequacyDescription,"Act11 Stp1");
    Step verifyLocalLevelAMASAdequacy = new Step(false,verifyLocalLevelAMASAdequacyExample,Verify_Local_Level_AMAS_Adequacy,verifyLocalLevelAMASAdequacyDescription,"Act11 Stp2");
    Step studyEntitiesInDomainContext = new Step(false,studyEntitiesInDomainContextExample,Study_Entities_In_Domain_Context,studyEntitiesInDomainContextDescription,"Act12 Stp1");
    Step identifyPotentiallyCooperativeEntities = new Step(false,identifyPotentiallyCooperativeEntitiesExample,Identify_Potentially_Cooperative_Entities,identifyPotentiallyCooperativeEntitiesDescription,"Act12 Stp2");
    Step determineAgents = new Step(false,determineAgentsExample,Determine_Agents,determineAgentsDescription,"Act12 Stp3");
    Step studyActivePassiveEntitiesRelationships = new Step(false,studyActivePassiveEntitiesRelationshipsExample,Study_Active_Passive_Entities_Relationships,studyActivePassiveEntitiesRelationshipsDescription,"Act13 Stp1");
    Step studyActiveEntitiesRelationships = new Step(false,studyActiveEntitiesRelationshipsExample,Study_Active_Entities_Relationships,studyActiveEntitiesRelationshipsDescription,"Act13 Stp2");
    Step studyAgentsRelationships = new Step(false,studyAgentsRelationshipsExample,Study_Agents_Relationships,studyAgentsRelationshipsDescription,"Act13 Stp3");
    Step determinePackages = new Step(false,determinePackagesExample,Determine_Packages,determinePackagesDescription,"Act14 Stp1");
    Step determineClasses = new Step(false,determineClassesExample,Determine_Classes,determineClassesDescription,"Act14 Stp2");
    Step useDesignPatterns = new Step(false,useDesignPatternsExample,Use_Design_Patterns,useDesignPatternsDescription,"Act14 Stp3");
    Step elaborateComponentAndClassDiagrams = new Step(false,elaborateComponentAndClassDiagramsExample,Elaborate_Component_And_Class_Diagrams,elaborateComponentAndClassDiagramsDescription,"Act14 Stp4");
    //Step defineInteractionLanguages = new Step(false,defineInteractionLanguagesExample,"Define Interaction Languages",defineInteractionLanguagesDescription);
    Step defineSkills = new Step(false,defineSkillsExample,Define_Skills,defineSkillsDescription,"Act16 Stp1");
    Step defineAptitudes = new Step(false,defineAptitudesExample,Define_Aptitudes,defineAptitudesDescription,"Act16 Stp2");
    Step determineInteractionLanguages = new Step(false,determineInteractionLanguagesExample,Define_Interaction_Languages,determineInteractionLanguagesDescription,"Act16 Stp3");
    Step defineWorldRepresentation = new Step(false,defineWorldRepresentationExample,Define_World_Representations,defineWorldRepresentationDescription,"Act16 Stp4");
    Step defineNCS = new Step(false,defineNCSExample,Define_NCSs,defineNCSDescription,"Act16 Stp5");
    Step enhanceDesignDiagrams = new Step(false,enhanceDesignDiagramsExample,Enhance_Design_Diagrams,enhanceDesignDiagramsDescription,"Act18 Stp1");
    Step designDynamicBehavior = new Step(false,designDynamicBehaviorExample,Design_Dynamic_Behavior,designDynamicBehaviorDescription,"Act18 Stp2");
    
    //StepLists creation
    StepList defaultActivityStepList = new StepList();
    StepList defineUserRequirementsStepList = new StepList();
    StepList validateRequirementsStepList = new StepList();
    StepList defineConsensualRequirementsStepList = new StepList();
    StepList establishKeywordSetStepList = new StepList();
    StepList extractLimitsAndConstraintsStepList = new StepList();
    StepList characterizeEnvironmentStepList = new StepList();
    characterizeEnvironmentStepList.add(determineActorsAndEntitites);
    characterizeEnvironmentStepList.add(defineContext);
    characterizeEnvironmentStepList.add(characterizeTheEnvironment);
    StepList determineUseCasesStepList = new StepList();
    determineUseCasesStepList.add(drawUpAnInventoryOfUseCases);
    determineUseCasesStepList.add(identifyCooperationFailurePossibility);
    determineUseCasesStepList.add(elaborateSequenceDiagrams);
    StepList elaborateUIPrototypesStepList = new StepList();
    StepList validateUIPrototypesStepList = new StepList();
    StepList analyzeDomainStepList = new StepList();
    analyzeDomainStepList.add(identifyClasses);
    analyzeDomainStepList.add(studyInterclassRelationship);
    analyzeDomainStepList.add(constructPreliminaryClassDiagrams);
    StepList verifyAMASAdequacyStepList = new StepList();
    verifyAMASAdequacyStepList.add(verifyGlobalLevelAMASAdequacy);
    verifyAMASAdequacyStepList.add(verifyLocalLevelAMASAdequacy);
    StepList identifyAgentsStepList = new StepList();
    identifyAgentsStepList.add(studyEntitiesInDomainContext);
    identifyAgentsStepList.add(identifyPotentiallyCooperativeEntities);
    identifyAgentsStepList.add(determineAgents);
    StepList studyInteractionsBetweenEntitiesStepList = new StepList();
    studyInteractionsBetweenEntitiesStepList.add(studyActivePassiveEntitiesRelationships);
    studyInteractionsBetweenEntitiesStepList.add(studyActiveEntitiesRelationships);
    studyInteractionsBetweenEntitiesStepList.add(studyAgentsRelationships);
    StepList studyDetailledArchitectureAndMAModelStepList = new StepList();
    studyDetailledArchitectureAndMAModelStepList.add(determinePackages);
    studyDetailledArchitectureAndMAModelStepList.add(determineClasses);
    studyDetailledArchitectureAndMAModelStepList.add(useDesignPatterns);
    studyDetailledArchitectureAndMAModelStepList.add(elaborateComponentAndClassDiagrams);
    StepList studyInteractionLanguageStepList = new StepList();
    //studyInteractionLanguageStepList.add(defineInteractionLanguages);
    StepList designAgentsStepList = new StepList();
    designAgentsStepList.add(defineSkills);
    designAgentsStepList.add(defineAptitudes);
    designAgentsStepList.add(determineInteractionLanguages);
    designAgentsStepList.add(defineWorldRepresentation);
    designAgentsStepList.add(defineNCS);
    StepList fastPrototypingStepList = new StepList();
    StepList completeDesignDiagramsStepList = new StepList();
    completeDesignDiagramsStepList.add(enhanceDesignDiagrams);
    completeDesignDiagramsStepList.add(designDynamicBehavior);
    
    // Activities creation
    Activity defaultActivity = new Activity(true,projectWorkProductList,defaultActivityExample,"Project",defaultActivityDescription,defaultActivityStepList,"");
    Activity defineUserRequirements = new Activity(true,defineUserRequirementsWorkProductList,defineUserRequirementsExample,Define_User_Requirements,defineUserRequirementsDescription,defineUserRequirementsStepList,"Act1");
    Activity validateRequirements = new Activity(false,validateRequirementsWorkProductList,validateRequirementsExample,Validate_Requirements,validateRequirementsDescription,validateRequirementsStepList,"Act2");
    Activity defineConsensualRequirements = new Activity(false,defineConsensualRequirementsWorkProductList,defineConsensualRequirementsExample,Define_Consensual_Requirements,defineConsensualRequirementsDescription,defineConsensualRequirementsStepList,"Act3");
    Activity establishKeywordSet = new Activity(false,establishKeywordSetWorkProductList,establishKeywordSetExample,Establish_Keyword_Set,establishKeywordSetDescription,establishKeywordSetStepList,"Act4");
    Activity extractLimitsAndConstraints = new Activity(false,extractLimitsAndConstraintsWorkProductList,extractLimitsAndConstraintsExample,Extract_Limits_And_Constraints,extractLimitsAndConstraintsDescription,extractLimitsAndConstraintsStepList,"Act5");
    Activity characterizeEnvironment = new Activity(false,characterizeEnvironmentWorkProductList,characterizeEnvironmentExample,Characterize_Environment,characterizeEnvironmentDescription,characterizeEnvironmentStepList,"Act6");
    Activity determineUseCases = new Activity(false,determineUseCasesWorkProductList,determineUseCasesExample,Determine_Use_Cases,determineUseCasesDescription,determineUseCasesStepList,"Act7");
    Activity elaborateUIPrototypes = new Activity(false,elaborateUIPrototypesWorkProductList,elaborateUIPrototypesExample,Elaborate_UI_Prototypes,elaborateUIPrototypesDescription,elaborateUIPrototypesStepList,"Act8");
    Activity validateUIPrototypes = new Activity(false,validateUIPrototypesWorkProductList,validateUIPrototypesExample,Validate_UI_Prototypes,validateUIPrototypesDescription,validateUIPrototypesStepList,"Act9");
    Activity analyzeDomain = new Activity(false,analyzeDomainWorkProductList,analyzeDomainExample,Analyze_Domain,analyzeDomainDescription,analyzeDomainStepList,"Act10");
    Activity verifyAMASAdequacy = new Activity(false,verifyAMASAdequacyWorkProductList,verifyAMASAdequacyExample,Verify_AMAS_Adequacy,verifyAMASAdequacyDescription,verifyAMASAdequacyStepList,"Act11");
    Activity identifyAgents = new Activity(false,identifyAgentsWorkProductList,identifyAgentsExample,Identify_Agents,identifyAgentsDescription,identifyAgentsStepList,"Act12");
    Activity studyInteractionsBetweenEntities = new Activity(false,studyInteractionsBetweenEntitiesWorkProductList,studyInteractionsBetweenEntitiesExample,Study_Interaction_Between_Entities,studyInteractionsBetweenEntitiesDescription,studyInteractionsBetweenEntitiesStepList,"Act13");
    Activity studyDetailledArchitectureAndMAModel = new Activity(false,studyDetailledArchitectureAndMAModelWorkProductList,studyDetailledArchitectureAndMAModelExample,Study_Detailed_Architecture_And_MA_Model,studyDetailledArchitectureAndMAModelDescription,studyDetailledArchitectureAndMAModelStepList,"Act14");
    Activity studyInteractionLanguage = new Activity(false,studyInteractionLanguageWorkProductList,studyInteractionLanguageExample,Study_Interaction_Languages,studyInteractionLanguageDescription,studyInteractionLanguageStepList,"Act15");
    Activity designAgents = new Activity(false,designAgentsWorkProductList,designAgentsExample,Design_Agents,designAgentsDescription,designAgentsStepList,"Act16");
    Activity fastPrototyping = new Activity(false,fastPrototypingWorkProductList,fastPrototypingExample,Fast_Prototyping,fastPrototypingDescription,fastPrototypingStepList,"Act17");
    Activity completeDesignDiagrams = new Activity(false,completeDesignDiagramsWorkProductList,completeDesignDiagramsExample,Complete_Design_Diagrams,completeDesignDiagramsDescription,completeDesignDiagramsStepList,"Act18");
    
    ActivityList al = new ActivityList();
    al.add(defineUserRequirements);
    al.add(validateRequirements);
    al.add(defineConsensualRequirements);
    al.add(establishKeywordSet);
    al.add(extractLimitsAndConstraints);
    al.add(characterizeEnvironment);
    al.add(determineUseCases);
    al.add(elaborateUIPrototypes);
    al.add(validateUIPrototypes);
    al.add(analyzeDomain);
    al.add(verifyAMASAdequacy);
    al.add(identifyAgents);
    al.add(studyInteractionsBetweenEntities);
    al.add(studyDetailledArchitectureAndMAModel);
    al.add(studyInteractionLanguage);
    al.add(designAgents);
    al.add(fastPrototyping);
    al.add(completeDesignDiagrams);
    
    Project project = new Project();
    project.setActivityList(al);
    project.setCurrentActivity((ActionToDo)al.get(0));
    project.setCurrentIndex(-1);
    project.setActionName("defaultProject");
    project.setWorkProducts(projectWorkProductList);
    project.setDescription(defaultActivityDescription);
    project.setExample(defaultActivityExample);
    
    try {
      FileOutputStream fos = new FileOutputStream("D:/picard/Documents/Programmation/adelfeToolkit/resources/defaultProject."+ExtensionGetter.dlf);
      ObjectOutputStream oos = new ObjectOutputStream(fos);
      
      oos.writeObject(project);
      
      oos.close();
      System.out.println("DefaultProjectCreator::main::OK...File created");}
    catch (java.io.FileNotFoundException e) {
      System.out.println("DefaultProjectCreator::main::File not found.");
    }
    catch (java.io.IOException e) {
      System.err.println("DefaultProjectCreator::main::IO exception");
    }
  }
}
