/*
 * AdelfeProject.java
 *
 * Created on 13 dcembre 2002, 08:24
 */

package adelfeToolkit.activities;

import java.net.URL;
import java.io.Serializable;
import adelfeToolkit.utilities.ExtensionGetter;
import adelfeToolkit.language.*;


/** A Project is a set of Activity object.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class Project extends ActionToDo implements Serializable, ToolTipable {
  
  /** the vector of activities */
  private ActivityList activityList = new ActivityList();
  
  /** the URL of the directory to save the project to. */
  private URL directory;
  
  /** the current Activity of the Project. */
  private ActionToDo currentActivity = this;
  
  /** the index of the currentActivity field in the activityList. */
  private int currentIndex = -1;
  
  /** the URL to the file to save the project to. */
  private URL fileToSaveTo = getClass().getResource("defaultProject."+ExtensionGetter.dlf);
  
  /** the list of workproducts that have been produced during the design. */
  private WorkProductList productedWorks;
  
  /** indicates whether the project has already been saved */
  private boolean alreadySaved;
  
  /** the number of saving already done. */
  private int saveNumber = 0;
  
  /** Creates a new instance of AdelfeProject */
  public Project() {
    setAccessible(true);
  }
  
  /** Getter for property activityList.
   * @return Value of property activityList.
   *
   */
  public ActivityList getActivityList() {
    return activityList;
  }
  
  /** Setter for property activityList.
   * @param activityList New value of property activityList.
   *
   */
  public void setActivityList(ActivityList activityList) {
    this.activityList = activityList;
  }
  
  /** Getter for property alreadySaved.
   * @return Value of property alreadySaved.
   *
   */
  public boolean isAlreadySaved() {
    return alreadySaved;
  }
  
  /** Setter for property alreadySaved.
   * @param alreadySaved New value of property alreadySaved.
   */
  public void setAlreadySaved(boolean alreadySaved) {
    this.alreadySaved = alreadySaved;
  }
  
  /** Getter for property currentActivity.
   * @return Value of property currentActivity.
   *
   */
  public ActionToDo getCurrentActivity() {
    // if (currentIndex != -1) {
    return currentActivity;
    //}
    //else {
    //return this;
    //}
  }
  
  /** Setter for property currentActivity.
   * @param currentActionToDo New value of property currentActivity.
   */
  public void setCurrentActivity(ActionToDo currentActionToDo) {
    this.currentActivity = currentActionToDo;
  }
  
  /** Getter for property currentIndex.
   * @return Value of property currentIndex.
   *
   */
  public int getCurrentIndex() {
    return currentIndex;
  }
  
  /** Setter for property currentIndex.
   * @param currentIndex New value of property currentIndex.
   */
  public void setCurrentIndex(int currentIndex) {
    this.currentIndex = currentIndex;
  }
  
  /** Getter for property directory.
   * @return Value of property directory.
   *
   */
  public java.net.URL getDirectory() {
    return directory;
  }
  
  /** Setter for property directory.
   * @param directory New value of property directory.
   *
   */
  public void setDirectory(java.net.URL directory) {
    this.directory = directory;
  }
  
  /** Getter for property fileToSaveTo.
   * @return Value of property fileToSaveTo.
   *
   */
  public java.net.URL getFileToSaveTo() {
    return fileToSaveTo;
  }
  
  /** Setter for property fileToSaveTo.
   * @param fileToSaveTo New value of property fileToSaveTo.
   *
   */
  public void setFileToSaveTo(java.net.URL fileToSaveTo) {
    this.fileToSaveTo = fileToSaveTo;
  }
  
  /** Getter for property productedWorks.
   * @return Value of property productedWorks.
   *
   */
  public WorkProductList getProductedWorks() {
    return productedWorks;
  }
  
  /** Setter for property productedWorks.
   * @param productedWorks New value of property productedWorks.
   *
   */
  public void setProductedWorks(WorkProductList productedWorks) {
    this.productedWorks = productedWorks;
  }
  
  /** Getter for property saveNumber.
   * @return Value of property saveNumber.
   *
   */
  public int getSaveNumber() {
    return saveNumber;
  }
  
  /** Setter for property saveNumber.
   * @param saveNumber New value of property saveNumber.
   *
   */
  public void setSaveNumber(int saveNumber) {
    this.saveNumber = saveNumber;
  }
  
  /** Sets the currentActivity field to the next activity in the activityList. */
  public void nextActivity() {
    if (currentIndex < activityList.size()-1) {
      currentIndex++;
      setCurrentActivity((Activity)activityList.get(currentIndex));
    }
  }
  
  /** get the name of the next Activity in the activityList from a given Activity name.
   * @param s the name of the reference Activity
   * @return the name of the Activity just after the given one.
   */
  public String getNextActivityName(String s) {
    int i = 0;
    Activity act = (Activity)activityList.get(i);
    while (! (act.getActionName().equals(s)) && (i < activityList.size())) {
      i++;
      act = (Activity)activityList.get(i);
    }
    if (i >= activityList.size()-1) {
      return ((Activity)activityList.get(i)).toString();
    }
    else {
      return ((Activity)activityList.get(i+1)).toString();
    }
  }
  
  /** get the string of the next Activity in the activityList from a given Activity name
   * in terms of a given LanguageChangeSupport.
   * @return the name of the Activity just after the given one.
   * @param lcs The LanguageChangeSupport that manages the language changes.
   * @param s the name of the reference Activity
   */
  public String getNextActivityString(String s, LanguageChangeSupport lcs) {
    int i = 0;
    boolean found = false;
    
    Activity act = (Activity)activityList.get(i);
    while (!found & (i < activityList.size()-1)) {
      if (act.toString(lcs).equals(s)) {
        found = true;}
      else {
        i++;
        act = (Activity)activityList.get(i);
      }
    }
    
    if (i >= activityList.size()-1) {
      return ((Activity)activityList.get(i)).toString(lcs);
    }
    else {
      return ((Activity)activityList.get(i+1)).toString(lcs);
    }
  }
  
  /** Sets the currentActivity field to the previous activity in the activityList. */
  public void previousActivity() {
    if (currentIndex > 0) {
      currentIndex++;
      setCurrentActivity((Activity)activityList.get(currentIndex));
    }
  }
  
  /** get the name of the previous Activity in the activityList from a given Activity name.
   * @param s the name of the reference Activity
   * @return the name of the Activity just before the given one.
   */
  public String getPreviousActivityName(String s) {
    int i = 0;
    boolean found = false;
    
    Activity act = (Activity)activityList.get(i);
    while (!found & (i < activityList.size()-1)) {
      if (act.getActionName().equals(s)) {
        found = true;}
      else {
        i++;
        act = (Activity)activityList.get(i);
      }
    }
    if (i > 0) {
      return ((Activity)activityList.get(i-1)).toString();
    }
    else {
      return ((Activity)activityList.get(i)).toString();
    }
  }
  
  /** get the string of the previous Activity in the activityList from a given Activity name
   * in terms of a given LanguageChangeSupport.
   * @return the name of the Activity just before the given one.
   * @param lcs The LanguageChangeSupport that manages the language changes.
   * @param s the name of the reference Activity
   */
  public String getPreviousActivityString(String s, LanguageChangeSupport lcs) {
    int i = 0;
    Activity act = (Activity)activityList.get(i);
    while (! (act.toString(lcs).equals(s)) && (i < activityList.size())) {
      i++;
      act = (Activity)activityList.get(i);
    }
    if (i > 0) {
      return ((Activity)activityList.get(i-1)).toString(lcs);
    }
    else {
      return ((Activity)activityList.get(i)).toString(lcs);
    }
  }
  
  /** Sets the currentActivity to a given ActionToDo if it is possible. It changes
   * also the currentIndex in functino of the currentActivity.
   * @param act the value for the new currentActivity.
   */
  public void setCurrentActionToDo(ActionToDo act) {
    if (act instanceof Activity) {
      int actNum = getActivityIndexForActionToDo(act);
      setCurrentActivity((Activity)act);
      setCurrentIndex(actNum);
    }
    else if (act instanceof Step) {
      int stpNum = getStepIndexForActionToDo(act);
      int actNum = getActivityIndexForActionToDo(act);
      ((Activity)this.getCurrentActivity()).setCurrentStep(act);
      ((Activity)this.getCurrentActivity()).setCurrentIndex(stpNum);
      setCurrentIndex(actNum);
    }
    else if (act instanceof Project) {
      setCurrentActivity((ActionToDo)this);
      setCurrentIndex(-1);
    }
    else {
      System.err.println("Project::setCurrentActionToDo::Bad class");
    }
  }
  
  /** This method find the index of the givenActionToDo in the activities List
   * @param act the ActionToDo to find
   * @return return the index of the ActionToDo in the activity list
   */  
  private int getActivityIndexForActionToDo(ActionToDo act) {
    return this.getActivityList().indexOf(act)+1;
  }
  
  /** This method find the index of the given ActionToDo in the activities List of the
   * currentActivity
   * @param act the ActionToDo to find
   * @return the index of the ActionToDo in the list
   */  
  private int getStepIndexForActionToDo(ActionToDo act) {
    return ((Activity)this.getCurrentActivity()).getSteps().indexOf(act)+1;
  }
  
  /** This method returns a string that represents the current state of the
   * project.
   * @return The string that represents the current state of the
   * project.
   */
  public String displayString() {
    return ("Project:"+getActionName()+" ; "+"completed:"+isCompleted()+" ; "+"directory:"+getDirectory()+" ; "+"file:"+getFileToSaveTo());
  }
  
  /** This method returns a string to represent the project.
   * @return The string to represent the project.
   */
  public String toString() {
    return (getActionName());
  }
}
