/*
 * ProjectList.java
 *
 * Created on 13 dcembre 2002, 08:39
 */

package adelfeToolkit.activities;

import java.util.Vector;

/** A ProjectList is a Vector of Project objects
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class ProjectList extends Vector {
  
  /** Creates a new instance of ProjectList */
  public ProjectList() {
  }
  
  /** Adds a Project to a ProjectList with no "doublon".
   * @param p the project to add to the project list
   */  
  public void addProject(Project p) {
    if (!containsProject(p)) {add(0,p);}
  }
  
  /** Displays a String that represents the project list. */  
  public void displayList() {
    System.out.print("[ ");
    for (int i=0;i<size();i++) {
      System.out.print(((Project)get(i)).getActionName());
      if (i == size()-1) {
        System.out.println(" ]");
      }
      else {
        System.out.println(" , ");
      }
    }
  }
  
  /** Indicates whether the list contains a given Project.
   * @param p the project to find
   * @return is the Project p contained in the ProjectList ?
   */  
  public boolean containsProject(Project p) {
    boolean result = false;
    int i = 0;
    java.net.URL url = p.getFileToSaveTo();
    if (url == null) {return result;}
    
    while ((i<size()) && !result) {
      result = url.getFile().equals(((Project)get(i)).getFileToSaveTo().getFile());
      i++;
    }
    
    return result;
  }
  
  /** Find the Project in the ProjectList corresponding to the given String name.
   * @param pName the name of the Project to find
   * @return the Project named pName
   */  
  public Project getProjectByName(String pName) {
    boolean found = false;
    int i = 0;
    
    while((!found) && (i<size())) {
      found = ((Project)get(i)).getActionName().equals(pName);
      i++;
    }
     
    return (Project)get(i-1);
  }
  
  /** Gets the index of a Project in the ProjectList
   * @param pName the name of the Project to find
   * @return the index of the Project named pName
   */  
  public int getNumberByName(String pName) {
    boolean found = false;
    int i = 0;
    
    while((!found) && (i<size())) {
      found = ((Project)get(i)).getActionName().equals(pName);
      i++;
    }
     
    return (i-1);
  }
  
}
