/*
 * Step.java
 *
 * Created on 9 dcembre 2002, 08:15
 */

package adelfeToolkit.activities;

import java.io.Serializable;

import adelfeToolkit.language.LanguageChangeSupport;

/** This class represents the SPEM class Step.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class Step extends ActionToDo implements Serializable {
  
  /** Creates a new instance of Step */
  public Step() {
  }
  
  /** Creates a new instance of Step with initial values:
   * @param ab initial value for the abbrev field
   * @param access inital value for accessible field
   * @param ex initial value for example field
   * @param n initail value for name field
   * @param des initial value for description field
   */  
  public Step(boolean access, Example ex, String n, Description des, String ab) {
    setAccessible(access);
    setExample(ex);
    setActionName(n);
    setDescription(des);
    setAbbrev(ab);
    setCompleted(false);
  } 
  
  /** This method returns a string that represents the current state of the
   * step (accessible, completed ...).
   * @return The string that represents the current state of the
   * step.
   */  
  public String displayString() {
    return ("Step:"+getActionName()+" ; "+"completed:"+isCompleted());
  }
  
  /** This method returns a representative string of the Step in terms of a
   * LanguageChangeSupport, in which appears the ResourceBundle that contains
   * descriptions
   * @param lcs the LanguageChangeSupport that manage the language changes
   * @return The string that represents the Step
   */  
   public String toString(LanguageChangeSupport lcs) {
    return (this.getActionName()+ " - " + lcs.getRessourceBundle().getString(this.getActionName()));
  }
   
   /** Sets the "completed" fields to the given value if the actionName fits with the
    * given name
    * @param an the actionName
    * @param comp the new value
    */   
   public void setCompl(String an, boolean comp) {
    if (this.getActionName().equals(an)) {
      this.setCompleted(comp);}
  }
   
   /** Sets the "accessible" field to the given new value if the actionName fits with
    * the given name
    * @param an the actionName
    * @param acces the new value
    */   
   public void setAcces(String an, boolean acces) {
    if (this.getActionName().equals(an)) {
      this.setAccessible(acces);}
  }
}
