/*
 * WorkProduct.java
 *
 * Created on 3 dcembre 2002, 15:42
 */

package adelfeToolkit.activities;

import java.io.Serializable;
import adelfeToolkit.language.*;

/** This class represents the SPEM class WorkProduct.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class WorkProduct implements Serializable, ToolTipable {
  
  /** final state representative string */  
  public final static String FINAL = "final";
  
  /** initial state */  
  public final static String INITIAL = "initial";
  
  /** draft state */  
  public final static String DRAFT = "draft";
  
  /** completed state */  
  public final static String COMPLETED = "completed";
  
  /** preliminary state */  
  public final static String PRELIMINARY = "preliminary";
  
  /** validated state */  
  public final static String VALIDATED = "validated";
  
  /** consensual state */  
  public final static String CONSENSUAL = "consensual";
  
  /** with actor state */  
  public final static String WITH_ACTORS = "with actors";
  
  /** with use cases state */  
  public final static String WITH_USE_CASES = "with use cases";
  
  /** including agents state */  
  public final static String INCLUDING_AGENTS = "including agents";
  
  /** with cooperation failure state */  
  public final static String WITH_COOP_FAIL = "with cooperation failure";
  
  /** including agent model state */  
  public final static String INCLUDING_AGENT_MODEL = "including agent model";
  
  /** with classes state */  
  public final static String WITH_CLASSES = "with classes";
  
  /** with packages state */  
  public final static String WITH_PACKAGES = "with packages";
  
  /** with use patterns states */  
  public final static String WITH_USE_PATTERNS = "use patterns choosen";
  
  /** with components states */  
  public final static String WITH_COMPONENTS = "with components";
  
  /** with agents state */  
  public final static String WITH_AGENTS = "agents designed";
  
  /** prototyped state */  
  public final static String PROTOTYPED = "agents prototyped";
  
  /** enhanced state */  
  public final static String ENHANCED = "enhanced";
  
  /** with state charts state */  
  public final static String WITH_STATE_CHARTS = "with state charts";
  
  
  
  
  /** the name of the workproduct */  
  private String name = "work product";
  
  /** The file that contains the real workproduct. */  
  private String file = "";
  
  /** indicates if it has been produced or not. */  
  private boolean producted = false;
  
  /** This value indicates whether the workproduct is accessible by the user. */  
  private boolean accessible = false;
  
  /** The sub workproducts of the workproduct. */  
  private WorkProductList subWorkProducts = new WorkProductList();
  
  /** the state of the WorkProduct. */  
  private String state = INITIAL;
  
  /** Creates a new instance of WorkProduct */
  public WorkProduct() {
  }
  
  /** Getter for property file.
   * @return Value of property file.
   *
   */
  public java.lang.String getFile() {
    return file;
  }  
  
  /** Setter for property file.
   * @param file New value of property file.
   *
   */
  public void setFile(java.lang.String file) {
    this.file = file;
  }
  
  /** Getter for property name.
   * @return Value of property name.
   *
   */
  public java.lang.String getName() {
    return name;
  }
  
  /** Setter for property name.
   * @param name New value of property name.
   *
   */
  public void setName(java.lang.String name) {
    this.name = name;
  }
  
  /** Getter for property producted.
   * @return Value of property producted.
   *
   */
  public boolean isProducted() {
    return producted;
  }
  
  /** Setter for property producted.
   * @param producted New value of property producted.
   *
   */
  public void setProducted(boolean producted) {
    this.producted = producted;
  }
  
  /** Sets the "producted" field to the given new value if the name fits with the
   * given string
   * @param wpn the name of the work product
   * @param prod the new value
   */  
  public void setProduc(String wpn, boolean prod) {
    if (this.getName().equals(wpn)) {
      this.setProducted(prod);
    }
    else {
      for (int i = 0;i<this.getSubWorkProducts().size();i++) {
        ((WorkProduct)this.getSubWorkProducts().get(i)).setProduc(wpn,prod);
      }
    }
  }
  
  /** Getter for property state.
   * @return Value of property state.
   *
   */
  public java.lang.String getState() {
    return state;
  }
  
  /** Setter for property state.
   * @param state New value of property state.
   *
   */
  public void setState(java.lang.String state) {
    this.state = state;
  }
  
  /** Sets the "state" field to the given new value if the name fits with the
   * given string
   * @param wpn the name of the work product
   * @param ns the new state
   */  
  public void setState(String wpn, String ns) {
    if (this.getName().equals(wpn)) {
      this.setState(ns);
    }
    else {
      for (int i = 0;i<this.getSubWorkProducts().size();i++) {
        ((WorkProduct)this.getSubWorkProducts().get(i)).setState(wpn,ns);
      }
    }
  }
  
  /** Getter for property subWorkProducts.
   * @return Value of property subWorkProducts.
   *
   */
  public WorkProductList getSubWorkProducts() {
    return subWorkProducts;
  }
  
  /** Setter for property subWorkProducts.
   * @param subWorkProducts New value of property subWorkProducts.
   *
   */
  public void setSubWorkProducts(WorkProductList subWorkProducts) {
    this.subWorkProducts = subWorkProducts;
  }
  
  /** This methods return a String that represents the WorkProduct (its name for
   * example).
   * @return the String that represents the WorkProduct
   */  
  public java.lang.String toString() {
    return name;
  }  
  
  /** This method returns a representative string of the WorkProduct in terms of a
   * LanguageChangeSupport, in which appears the ResourceBundle that contains
   * descriptions
   * @param lcs the LanguageChangeSupport that manage the language changes
   * @return The string that represents the WorkProduct
   */  
  public String toString(LanguageChangeSupport lcs) {
    return (lcs.getRessourceBundle().getString(this.getName()));
  }
  
  /** This method returns a string that represents the current state of the
   * work product (state, accessible, completed, ...).
   * @return The string that represents the current state of the
   * work product.
   */  
  public String displayString() {
    return ("WorkProduct:"+name+" ; "+"file:"+file+" ; "+"producted:"+producted+" ; "+"state:"+state+" ; "+"accessible:"+accessible);
  }
  
  /** Getter for property accessible.
   * @return Value of property accessible.
   *
   */
  public boolean isAccessible() {
    return accessible;
  }
  
  /** Setter for property accessible.
   * @param accessible New value of property accessible.
   *
   */
  public void setAccessible(boolean accessible) {
    this.accessible = accessible;
  }
  
  /** Sets the "accessible" fields to the given new value if the name fits with the
   * given string
   * @param wpn the name of the work product
   * @param acces the new value
   */  
  public void setAcces(String wpn, boolean acces) {
    if (this.getName().equals(wpn)) {
      this.setAccessible(acces);
    }
    else {
      for (int i = 0;i<this.getSubWorkProducts().size();i++) {
        ((WorkProduct)this.getSubWorkProducts().get(i)).setAcces(wpn,acces);
      }
    }
  }
  
}
