/*
 * AdelfeParameterUI.java
 *
 * Created on 19 mars 2003, 10:23
 */

package adelfeToolkit.gui;

import java.io.File;
import java.net.URL;

import javax.swing.JFileChooser;
import javax.swing.JOptionPane;

import adelfeToolkit.language.LanguageChangeEvent;
import adelfeToolkit.language.LanguageChangeListener;
import adelfeToolkit.language.LanguageChangeSupport;
import adelfeToolkit.utilities.Confirmer;

/** This class is a specific JFrame to tune different parameters of the Toolkit
 * @author IRIT - Toulouse (ADELFE)
 */
public class AdelfeParameterUI extends javax.swing.JFrame implements adelfeToolkit.utilities.LogWriter, LanguageChangeListener {
  
  /** Creates new form AdelfeParameterUI which is owned by a given AdelfeToolkitUI.
   * @param o the owner of the AdelfeParameterUI
   */
  public AdelfeParameterUI(AdelfeToolkitUI o) {
    owner = o;
    languageChangeSupport = o.getLanguageChangeSupport();
    languageChangeSupport.addLanguageChangeListener(this);
    initComponents();
    initOptions();
    this.setIconImage(java.awt.Toolkit.getDefaultToolkit().getImage(getClass().getResource("/adelfeToolkit/gui/image/SMAC.gif")));
  }
  
  /** this method sets the different fields to initial values */  
  public void initOptions() {
    adelfeToolkit.AdelfeToolkit at = owner.getMyOwner();
    openToolTextField.setText(at.getOpenTool());
    drawingToolTextField.setText(at.getDrawingTool());
    projectDirectoryTextField.setText(at.getProjectDirectory());
    textEditorTextField.setText(at.getTextEditor());
    allActivitiesAreAccessibleCheckBox.setSelected(at.isAllActivitiesAreAccessible());
    descriptionModuleIsVisibleCheckBox.setSelected(at.isDescriptionModuleIsVisible());
    documentModuleIsVisibleCheckBox.setSelected(at.isDocumentModuleIsVisible());
    exampleModuleIsVisibleCheckBox.setSelected(at.isExampleModuleIsVisible());
    managerModuleIsVisibleCheckBox.setSelected(at.isManagerModuleIsVisible());
    synthesisModuleIsVisibleCheckBox.setSelected(at.isSynthesisModuleIsVisible());
  }
  
  /** This method saves the parameters only for the session (if NO choosen), in config
   * file (if YES choosen).
   */  
  private void saveParameters() {
    choice = Confirmer.confirm(this,this.languageChangeSupport);
    switch (choice) {
      case Confirmer.NO_OPTION : {
        if (openToolChanged) {saveOpenTool();}
        if (projectDirectoryChanged) {saveProjectDirectory();}
        if (allActivitiesAreAccessibleChanged) {saveAllActivitiesAreAccessible();}
        if (textEditorChanged) {saveTextEditor();}
        if (drawingToolChanged) {saveDrawingTool();}
        if (synthesisModuleIsVisibleChanged) {saveSynthesisModuleIsVisible();}
        if (documentModuleIsVisibleChanged) {saveDocumentModuleIsVisible();}
        if (exampleModuleIsVisibleChanged) {saveExampleModuleIsVisible();}
        if (managerModuleIsVisibleChanged) {saveManagerModuleIsVisible();}
        if (descriptionModuleIsVisibleChanged) {saveDescriptionModuleIsVisible();}
        break;
      }
      case Confirmer.YES_OPTION  : {
        if (openToolChanged) {saveOpenTool();owner.getMyOwner().saveOpenTool();}
        if (projectDirectoryChanged) {saveProjectDirectory();owner.getMyOwner().saveProjectDirectory();}
        if (allActivitiesAreAccessibleChanged) {saveAllActivitiesAreAccessible();owner.getMyOwner().saveAllActivitiesAreAccessible();}
        if (textEditorChanged) {saveTextEditor();owner.getMyOwner().saveTextEditor();}
        if (drawingToolChanged) {saveDrawingTool();owner.getMyOwner().saveDrawingTool();}
        if (synthesisModuleIsVisibleChanged) {saveSynthesisModuleIsVisible();owner.getMyOwner().saveSynthesisModuleIsVisible();}
        if (documentModuleIsVisibleChanged) {saveDocumentModuleIsVisible();owner.getMyOwner().saveDocumentModuleIsVisible();}
        if (exampleModuleIsVisibleChanged) {saveExampleModuleIsVisible();owner.getMyOwner().saveExampleModuleIsVisible();}
        if (managerModuleIsVisibleChanged) {saveManagerModuleIsVisible();owner.getMyOwner().saveManagerModuleIsVisible();}
        if (descriptionModuleIsVisibleChanged) {saveDescriptionModuleIsVisible();owner.getMyOwner().saveDescriptionModuleIsVisible();}
        break;
      }
      default : {}
    }
  }
  
  /** save the OT path for the session */  
  private void saveOpenTool() {
    owner.getMyOwner().setOpenTool(openToolTextField.getText());
  }
  
  /** save the allActivitiesAreAccessible option for the session */  
  private void saveAllActivitiesAreAccessible() {
    owner.getMyOwner().setAllActivitiesAreAccessible(allActivitiesAreAccessibleCheckBox.isSelected());
    owner.repaint();
  }
  
  /** save the project path for the session */  
  private void saveProjectDirectory() {
    owner.getMyOwner().setProjectDirectory(projectDirectoryTextField.getText());
    try {
      owner.getMyOwner().getManagerModule().setDirectory((new java.io.File(projectDirectoryTextField.getText())).toURL());
    } catch(java.net.MalformedURLException e) {
      JOptionPane.showMessageDialog(this,
      this.languageChangeSupport.getRessourceBundle().getString("MalFormed Project Directory Path"),
      "",
      JOptionPane.WARNING_MESSAGE);
      
      printErrLog("saveProjectDirectory::java.net.MalformedURLException");
    }
  }
  
  /** save the text editor path for the session */  
  private void saveTextEditor() {
    owner.getMyOwner().setTextEditor(textEditorTextField.getText());
  }
  
  /** save the drawinf tool path for the session */  
  private void saveDrawingTool() {
    owner.getMyOwner().setDrawingTool(drawingToolTextField.getText());
  }
  
  /** save the synthesisModuleIsVisible option for the session */  
  private void saveSynthesisModuleIsVisible() {
    owner.getMyOwner().setSynthesisModuleIsVisible(synthesisModuleIsVisibleCheckBox.isSelected());
    owner.repaint();
  }
  
  /** save the documentModuleIsVisible option for the session */  
  private void saveDocumentModuleIsVisible() {
    owner.getMyOwner().setDocumentModuleIsVisible(documentModuleIsVisibleCheckBox.isSelected());
    owner.repaint();
  }
  
  /** save the exampleModuleIsVisible option for the session */  
  private void saveExampleModuleIsVisible() {
    owner.getMyOwner().setExampleModuleIsVisible(exampleModuleIsVisibleCheckBox.isSelected());
    owner.repaint();
  }
  
  /** save the managerModuleIsVisible option for the session */  
  private void saveManagerModuleIsVisible() {
    owner.getMyOwner().setSynthesisModuleIsVisible(managerModuleIsVisibleCheckBox.isSelected());
    owner.repaint();
  }
  
  /** save the descriptionModuleIsVisible option for the session */  
  private void saveDescriptionModuleIsVisible() {
    owner.getMyOwner().setDescriptionModuleIsVisible(descriptionModuleIsVisibleCheckBox.isSelected());
    owner.repaint();
  }
  
  /** This method request a URL by opening a JFileChooser at a given default path and
   * a given mode
   * @param defaultFile the default path or file
   * @param mode the mode of the JFileChooser
   * @return the URL specified by the user
   */  
  private URL urlRequest(String defaultFile, int mode) {
    JFileChooser chooser = new JFileChooser();
    chooser.setLocation(100, 200);
    chooser.setFileSelectionMode(mode);
    chooser.setCurrentDirectory(new File(owner.getMyOwner().getManagerModule().getDirectory().getFile()));
    int returnVal = JFileChooser.CANCEL_OPTION;
    
    returnVal = chooser.showOpenDialog(this);
    if(returnVal == JFileChooser.APPROVE_OPTION) {
      printOutLog("urlRequest::You chose to open this file: " +
      chooser.getSelectedFile().getName());
    }
    
    if (returnVal == JFileChooser.CANCEL_OPTION) {
      return null;
    }
    
    URL url = null;
    File choosedFile;
    try {
      url = new URL(new File(defaultFile).getPath());
    }
    catch (java.net.MalformedURLException e) {
      printErrLog("fileNameRequest::MalformedURLException1");
    }
    try {
      choosedFile = chooser.getSelectedFile();
      if (choosedFile != null) {
        url = choosedFile.toURL();
      }
    }
    catch (java.net.MalformedURLException e) {
      printErrLog("fileNameRequest::MalformedURLException2");
    }
    return url;
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    tabbedPane = new javax.swing.JTabbedPane();
    locationPanel = new javax.swing.JPanel();
    openToolPanel = new javax.swing.JPanel();
    openToolLabel = new javax.swing.JLabel();
    openToolSubPanel = new javax.swing.JPanel();
    openToolTextField = new javax.swing.JTextField();
    openToolButton = new javax.swing.JButton();
    projectDirectoryPanel = new javax.swing.JPanel();
    projectDirectoryLabel = new javax.swing.JLabel();
    projectDirectorySubPanel = new javax.swing.JPanel();
    projectDirectoryTextField = new javax.swing.JTextField();
    projectDirectoryButton = new javax.swing.JButton();
    drawingToolPanel = new javax.swing.JPanel();
    drawingToolLabel = new javax.swing.JLabel();
    drawingToolSubPanel = new javax.swing.JPanel();
    drawingToolTextField = new javax.swing.JTextField();
    drawingToolButton = new javax.swing.JButton();
    textEditorPanel = new javax.swing.JPanel();
    textEditorLabel = new javax.swing.JLabel();
    textEditorSubPanel = new javax.swing.JPanel();
    textEditorTextField = new javax.swing.JTextField();
    textEditorButton = new javax.swing.JButton();
    optionPanel = new javax.swing.JPanel();
    allActivitiesAreAccessiblePanel = new javax.swing.JPanel();
    allActivitiesAreAccessibleCheckBox = new javax.swing.JCheckBox();
    windowPanel = new javax.swing.JPanel();
    descriptionModuleIsVisiblePanel = new javax.swing.JPanel();
    descriptionModuleIsVisibleCheckBox = new javax.swing.JCheckBox();
    managerModuleIsVisiblePanel = new javax.swing.JPanel();
    managerModuleIsVisibleCheckBox = new javax.swing.JCheckBox();
    exampleModuleIsVisiblePanel = new javax.swing.JPanel();
    exampleModuleIsVisibleCheckBox = new javax.swing.JCheckBox();
    documentModuleIsVisiblePanel = new javax.swing.JPanel();
    documentModuleIsVisibleCheckBox = new javax.swing.JCheckBox();
    synthesisModuleIsVisiblePanel = new javax.swing.JPanel();
    synthesisModuleIsVisibleCheckBox = new javax.swing.JCheckBox();
    buttonPanel = new javax.swing.JPanel();
    initButton = new javax.swing.JButton();
    okButton = new javax.swing.JButton();

    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Parameter"));
    setResizable(false);
    addWindowListener(new java.awt.event.WindowAdapter() {
      public void windowClosing(java.awt.event.WindowEvent evt) {
        exitForm(evt);
      }
    });

    tabbedPane.setMinimumSize(new java.awt.Dimension(475, 128));
    tabbedPane.setName(this.languageChangeSupport.getRessourceBundle().getString("Locations"));
    tabbedPane.setPreferredSize(new java.awt.Dimension(475, 128));
    locationPanel.setLayout(new java.awt.GridLayout(6, 1));

    locationPanel.setMinimumSize(new java.awt.Dimension(470, 120));
    locationPanel.setPreferredSize(new java.awt.Dimension(470, 120));
    openToolPanel.setLayout(new java.awt.BorderLayout());

    openToolLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("OpenTool"));
    openToolPanel.add(openToolLabel, java.awt.BorderLayout.WEST);

    openToolSubPanel.setLayout(new java.awt.BorderLayout());

    openToolSubPanel.setAlignmentX(0.0F);
    openToolSubPanel.setAlignmentY(0.0F);
    openToolTextField.setMinimumSize(new java.awt.Dimension(300, 20));
    openToolTextField.setPreferredSize(new java.awt.Dimension(300, 20));
    openToolTextField.addKeyListener(new java.awt.event.KeyAdapter() {
      public void keyPressed(java.awt.event.KeyEvent evt) {
        openToolTextFieldKeyPressed(evt);
      }
    });

    openToolSubPanel.add(openToolTextField, java.awt.BorderLayout.WEST);

    openToolButton.setText("...");
    openToolButton.setMinimumSize(new java.awt.Dimension(18, 26));
    openToolButton.setPreferredSize(new java.awt.Dimension(18, 26));
    openToolButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        openToolButtonMouseReleased(evt);
      }
    });

    openToolSubPanel.add(openToolButton, java.awt.BorderLayout.EAST);

    openToolPanel.add(openToolSubPanel, java.awt.BorderLayout.EAST);

    locationPanel.add(openToolPanel);

    projectDirectoryPanel.setLayout(new java.awt.BorderLayout());

    projectDirectoryLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("ProjectDirectory"));
    projectDirectoryPanel.add(projectDirectoryLabel, java.awt.BorderLayout.WEST);

    projectDirectorySubPanel.setLayout(new java.awt.BorderLayout());

    projectDirectorySubPanel.setAlignmentX(0.0F);
    projectDirectorySubPanel.setAlignmentY(0.0F);
    projectDirectoryTextField.setMinimumSize(new java.awt.Dimension(300, 20));
    projectDirectoryTextField.setPreferredSize(new java.awt.Dimension(300, 20));
    projectDirectoryTextField.addKeyListener(new java.awt.event.KeyAdapter() {
      public void keyPressed(java.awt.event.KeyEvent evt) {
        projectDirectoryTextFieldKeyPressed(evt);
      }
    });

    projectDirectorySubPanel.add(projectDirectoryTextField, java.awt.BorderLayout.WEST);

    projectDirectoryButton.setText("...");
    projectDirectoryButton.setMinimumSize(new java.awt.Dimension(18, 26));
    projectDirectoryButton.setPreferredSize(new java.awt.Dimension(18, 26));
    projectDirectoryButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        projectDirectoryButtonMouseReleased(evt);
      }
    });

    projectDirectorySubPanel.add(projectDirectoryButton, java.awt.BorderLayout.EAST);

    projectDirectoryPanel.add(projectDirectorySubPanel, java.awt.BorderLayout.EAST);

    locationPanel.add(projectDirectoryPanel);

    drawingToolPanel.setLayout(new java.awt.BorderLayout());

    drawingToolLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("DrawingTool"));
    drawingToolPanel.add(drawingToolLabel, java.awt.BorderLayout.WEST);

    drawingToolSubPanel.setLayout(new java.awt.BorderLayout());

    drawingToolSubPanel.setAlignmentX(0.0F);
    drawingToolSubPanel.setAlignmentY(0.0F);
    drawingToolTextField.setMinimumSize(new java.awt.Dimension(300, 20));
    drawingToolTextField.setPreferredSize(new java.awt.Dimension(300, 20));
    drawingToolTextField.addKeyListener(new java.awt.event.KeyAdapter() {
      public void keyPressed(java.awt.event.KeyEvent evt) {
        drawingToolTextFieldKeyPressed(evt);
      }
    });

    drawingToolSubPanel.add(drawingToolTextField, java.awt.BorderLayout.WEST);

    drawingToolButton.setText("...");
    drawingToolButton.setMinimumSize(new java.awt.Dimension(18, 26));
    drawingToolButton.setPreferredSize(new java.awt.Dimension(18, 26));
    drawingToolButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        drawingToolButtonMouseReleased(evt);
      }
    });

    drawingToolSubPanel.add(drawingToolButton, java.awt.BorderLayout.EAST);

    drawingToolPanel.add(drawingToolSubPanel, java.awt.BorderLayout.EAST);

    locationPanel.add(drawingToolPanel);

    textEditorPanel.setLayout(new java.awt.BorderLayout());

    textEditorLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("TextEditor"));
    textEditorPanel.add(textEditorLabel, java.awt.BorderLayout.WEST);

    textEditorSubPanel.setLayout(new java.awt.BorderLayout());

    textEditorSubPanel.setAlignmentX(0.0F);
    textEditorSubPanel.setAlignmentY(0.0F);
    textEditorTextField.setMinimumSize(new java.awt.Dimension(300, 20));
    textEditorTextField.setPreferredSize(new java.awt.Dimension(300, 20));
    textEditorTextField.addKeyListener(new java.awt.event.KeyAdapter() {
      public void keyPressed(java.awt.event.KeyEvent evt) {
        textEditorTextFieldKeyPressed(evt);
      }
    });

    textEditorSubPanel.add(textEditorTextField, java.awt.BorderLayout.WEST);

    textEditorButton.setText("...");
    textEditorButton.setMinimumSize(new java.awt.Dimension(18, 26));
    textEditorButton.setPreferredSize(new java.awt.Dimension(18, 26));
    textEditorButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        textEditorButtonMouseReleased(evt);
      }
    });

    textEditorSubPanel.add(textEditorButton, java.awt.BorderLayout.EAST);

    textEditorPanel.add(textEditorSubPanel, java.awt.BorderLayout.EAST);

    locationPanel.add(textEditorPanel);

    tabbedPane.addTab(this.languageChangeSupport.getRessourceBundle().getString("Locations"), locationPanel);

    optionPanel.setLayout(new javax.swing.BoxLayout(optionPanel, javax.swing.BoxLayout.Y_AXIS));

    allActivitiesAreAccessiblePanel.setLayout(new java.awt.BorderLayout());

    allActivitiesAreAccessibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("AllActivitiesAreAccessible"));
    allActivitiesAreAccessibleCheckBox.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        allActivitiesAreAccessibleCheckBoxItemStateChanged(evt);
      }
    });

    allActivitiesAreAccessiblePanel.add(allActivitiesAreAccessibleCheckBox, java.awt.BorderLayout.CENTER);

    optionPanel.add(allActivitiesAreAccessiblePanel);

    tabbedPane.addTab(this.languageChangeSupport.getRessourceBundle().getString("Options"), optionPanel);

    windowPanel.setLayout(new javax.swing.BoxLayout(windowPanel, javax.swing.BoxLayout.Y_AXIS));

    descriptionModuleIsVisiblePanel.setLayout(new java.awt.BorderLayout());

    descriptionModuleIsVisiblePanel.setMinimumSize(new java.awt.Dimension(237, 20));
    descriptionModuleIsVisiblePanel.setPreferredSize(new java.awt.Dimension(237, 20));
    descriptionModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("DescriptionModuleIsVisible"));
    descriptionModuleIsVisibleCheckBox.setMaximumSize(new java.awt.Dimension(237, 20));
    descriptionModuleIsVisibleCheckBox.setMinimumSize(new java.awt.Dimension(237, 20));
    descriptionModuleIsVisibleCheckBox.setPreferredSize(new java.awt.Dimension(237, 20));
    descriptionModuleIsVisibleCheckBox.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        descriptionModuleIsVisibleCheckBoxItemStateChanged(evt);
      }
    });

    descriptionModuleIsVisiblePanel.add(descriptionModuleIsVisibleCheckBox, java.awt.BorderLayout.CENTER);

    windowPanel.add(descriptionModuleIsVisiblePanel);

    managerModuleIsVisiblePanel.setLayout(new java.awt.BorderLayout());

    managerModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("ManagerModuleIsVisible"));
    managerModuleIsVisibleCheckBox.setMaximumSize(new java.awt.Dimension(222, 20));
    managerModuleIsVisibleCheckBox.setMinimumSize(new java.awt.Dimension(222, 20));
    managerModuleIsVisibleCheckBox.setPreferredSize(new java.awt.Dimension(222, 20));
    managerModuleIsVisibleCheckBox.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        managerModuleIsVisibleCheckBoxItemStateChanged(evt);
      }
    });

    managerModuleIsVisiblePanel.add(managerModuleIsVisibleCheckBox, java.awt.BorderLayout.CENTER);

    windowPanel.add(managerModuleIsVisiblePanel);

    exampleModuleIsVisiblePanel.setLayout(new java.awt.BorderLayout());

    exampleModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("ExampleModuleIsVisible"));
    exampleModuleIsVisibleCheckBox.setMaximumSize(new java.awt.Dimension(221, 20));
    exampleModuleIsVisibleCheckBox.setMinimumSize(new java.awt.Dimension(221, 20));
    exampleModuleIsVisibleCheckBox.setPreferredSize(new java.awt.Dimension(221, 20));
    exampleModuleIsVisibleCheckBox.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        exampleModuleIsVisibleCheckBoxItemStateChanged(evt);
      }
    });

    exampleModuleIsVisiblePanel.add(exampleModuleIsVisibleCheckBox, java.awt.BorderLayout.CENTER);

    windowPanel.add(exampleModuleIsVisiblePanel);

    documentModuleIsVisiblePanel.setLayout(new java.awt.BorderLayout());

    documentModuleIsVisiblePanel.setMinimumSize(new java.awt.Dimension(230, 20));
    documentModuleIsVisiblePanel.setPreferredSize(new java.awt.Dimension(230, 20));
    documentModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("DocumentModuleIsVisible"));
    documentModuleIsVisibleCheckBox.setMaximumSize(new java.awt.Dimension(230, 20));
    documentModuleIsVisibleCheckBox.setMinimumSize(new java.awt.Dimension(230, 20));
    documentModuleIsVisibleCheckBox.setPreferredSize(new java.awt.Dimension(230, 20));
    documentModuleIsVisibleCheckBox.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        documentModuleIsVisibleCheckBoxItemStateChanged(evt);
      }
    });

    documentModuleIsVisiblePanel.add(documentModuleIsVisibleCheckBox, java.awt.BorderLayout.CENTER);

    windowPanel.add(documentModuleIsVisiblePanel);

    synthesisModuleIsVisiblePanel.setLayout(new java.awt.BorderLayout());

    synthesisModuleIsVisiblePanel.setMinimumSize(new java.awt.Dimension(228, 20));
    synthesisModuleIsVisiblePanel.setPreferredSize(new java.awt.Dimension(228, 20));
    synthesisModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("SynthesisModuleIsVisible"));
    synthesisModuleIsVisibleCheckBox.setMaximumSize(new java.awt.Dimension(228, 20));
    synthesisModuleIsVisibleCheckBox.setMinimumSize(new java.awt.Dimension(228, 20));
    synthesisModuleIsVisibleCheckBox.setPreferredSize(new java.awt.Dimension(228, 20));
    synthesisModuleIsVisibleCheckBox.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        synthesisModuleIsVisibleCheckBoxItemStateChanged(evt);
      }
    });

    synthesisModuleIsVisiblePanel.add(synthesisModuleIsVisibleCheckBox, java.awt.BorderLayout.CENTER);

    windowPanel.add(synthesisModuleIsVisiblePanel);

    tabbedPane.addTab(this.languageChangeSupport.getRessourceBundle().getString("Window"), windowPanel);

    getContentPane().add(tabbedPane, java.awt.BorderLayout.NORTH);

    buttonPanel.setLayout(new java.awt.BorderLayout());

    buttonPanel.setMinimumSize(new java.awt.Dimension(475, 26));
    buttonPanel.setPreferredSize(new java.awt.Dimension(475, 26));
    initButton.setText(this.languageChangeSupport.getRessourceBundle().getString("Init"));
    initButton.setMaximumSize(new java.awt.Dimension(100, 26));
    initButton.setMinimumSize(new java.awt.Dimension(100, 26));
    initButton.setPreferredSize(new java.awt.Dimension(100, 26));
    initButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        initButtonMouseReleased(evt);
      }
    });

    buttonPanel.add(initButton, java.awt.BorderLayout.WEST);

    okButton.setText(this.languageChangeSupport.getRessourceBundle().getString("OK"));
    okButton.setMaximumSize(new java.awt.Dimension(100, 26));
    okButton.setMinimumSize(new java.awt.Dimension(100, 26));
    okButton.setPreferredSize(new java.awt.Dimension(100, 26));
    okButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        okButtonMouseReleased(evt);
      }
    });

    buttonPanel.add(okButton, java.awt.BorderLayout.EAST);

    getContentPane().add(buttonPanel, java.awt.BorderLayout.WEST);

    pack();
  }//GEN-END:initComponents
  
  /** this method is called when the chexk box item state changed
   * @param evt the received event
   */  
  private void synthesisModuleIsVisibleCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_synthesisModuleIsVisibleCheckBoxItemStateChanged
    // Add your handling code here:
    synthesisModuleIsVisibleChanged=true;
  }//GEN-LAST:event_synthesisModuleIsVisibleCheckBoxItemStateChanged
  
  /** this method is called when the chexk box item state changed
   * @param evt the received event
   */  
  private void documentModuleIsVisibleCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_documentModuleIsVisibleCheckBoxItemStateChanged
    // Add your handling code here:
    documentModuleIsVisibleChanged=true;
  }//GEN-LAST:event_documentModuleIsVisibleCheckBoxItemStateChanged
  
  /** this method is called when the chexk box item state changed
   * @param evt the received event
   */  
  private void exampleModuleIsVisibleCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_exampleModuleIsVisibleCheckBoxItemStateChanged
    // Add your handling code here:
    exampleModuleIsVisibleChanged=true;
  }//GEN-LAST:event_exampleModuleIsVisibleCheckBoxItemStateChanged
  
  /** this method is called when the chexk box item state changed
   * @param evt the received event
   */  
  private void managerModuleIsVisibleCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_managerModuleIsVisibleCheckBoxItemStateChanged
    // Add your handling code here:
    managerModuleIsVisibleChanged=true;
  }//GEN-LAST:event_managerModuleIsVisibleCheckBoxItemStateChanged
  
  /** this method is called when the chexk box item state changed
   * @param evt the received event
   */  
  private void descriptionModuleIsVisibleCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_descriptionModuleIsVisibleCheckBoxItemStateChanged
    // Add your handling code here:
    descriptionModuleIsVisibleChanged=true;
  }//GEN-LAST:event_descriptionModuleIsVisibleCheckBoxItemStateChanged
  
  /** This method is called when a key was pressed in the text field
   * @param evt the received event
   */    
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */    
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */  
  private void textEditorButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_textEditorButtonMouseReleased
    // Add your handling code here:
    requestTextEditorURL();
  }//GEN-LAST:event_textEditorButtonMouseReleased
  
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */  
  private void drawingToolButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_drawingToolButtonMouseReleased
    // Add your handling code here:
    requestDrawingToolURL();
  }//GEN-LAST:event_drawingToolButtonMouseReleased
  
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */    
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */  
  private void projectDirectoryButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_projectDirectoryButtonMouseReleased
    // Add your handling code here:
    requestProjectDirectoryURL();
  }//GEN-LAST:event_projectDirectoryButtonMouseReleased
  
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */  
  private void openToolButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_openToolButtonMouseReleased
    // Add your handling code here:
    requestOpenToolURL();
  }//GEN-LAST:event_openToolButtonMouseReleased
  
  /** This method is called when a key was pressed in the text field
   * @param evt the received event
   */  
  private void openToolTextFieldKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_openToolTextFieldKeyPressed
    // Add your handling code here:
    openToolChanged = true;
  }//GEN-LAST:event_openToolTextFieldKeyPressed
  
  /** This method is called when a key was pressed in the text field
   * @param evt the received event
   */  
  private void textEditorTextFieldKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_textEditorTextFieldKeyPressed
    // Add your handling code here:
    textEditorChanged = true;
  }//GEN-LAST:event_textEditorTextFieldKeyPressed
  
  /** This method is called when a key was pressed in the text field
   * @param evt the received event
   */  
  private void drawingToolTextFieldKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_drawingToolTextFieldKeyPressed
    // Add your handling code here:
    drawingToolChanged = true;
  }//GEN-LAST:event_drawingToolTextFieldKeyPressed
  
  /** This method is called when a key was pressed in the text field
   * @param evt the received event
   */    
  /** This method is called when a key was pressed in the text field
   * @param evt the received event
   */  
  private void projectDirectoryTextFieldKeyPressed(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_projectDirectoryTextFieldKeyPressed
    // Add your handling code here:
    projectDirectoryChanged = true;
  }//GEN-LAST:event_projectDirectoryTextFieldKeyPressed
  
  /** this method is called when the chexk box item state changed
   * @param evt the received event
   */  
  private void allActivitiesAreAccessibleCheckBoxItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_allActivitiesAreAccessibleCheckBoxItemStateChanged
    // Add your handling code here:
    allActivitiesAreAccessibleChanged = true;
  }//GEN-LAST:event_allActivitiesAreAccessibleCheckBoxItemStateChanged
  
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */  
  private void okButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_okButtonMouseReleased
    // Add your handling code here:
    choice = JOptionPane.CANCEL_OPTION;
    saveParameters();
    if (choice != JOptionPane.CANCEL_OPTION) {
      this.hide();
      choice = JOptionPane.CANCEL_OPTION;
    }
  }//GEN-LAST:event_okButtonMouseReleased
  
  /** This method is called the mouse is released on the button is released
   * @param evt the received event
   */  
  private void initButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_initButtonMouseReleased
    // Add your handling code here:
    this.reInitOptions();
  }//GEN-LAST:event_initButtonMouseReleased
  
  /** Exit the Application
   * @param evt the received event
   */
  private void exitForm(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_exitForm
    choice = JOptionPane.CANCEL_OPTION;
    saveParameters();
    if (choice != JOptionPane.CANCEL_OPTION) {
      this.hide();
      choice = JOptionPane.CANCEL_OPTION;
    }
  }//GEN-LAST:event_exitForm
  
  /** This method read the personal config of the user and set the options */  
  private void reInitOptions() {
    owner.getMyOwner().setConfigToDefaults();
    owner.getMyOwner().setPropertiesToPersonalProperties();
    initOptions();
    repaint();
  }
  
  /** This method opens a JFileChooser to choose the path for the text editor */  
  private void requestTextEditorURL() {
    URL url = urlRequest(textEditorTextField.getText(),JFileChooser.FILES_ONLY);
    if (url != null) {
      textEditorTextField.setText(new File(url.getFile()).toString());
      textEditorChanged=true;
    }
  }
  
  /** This method opens a JFileChooser to choose the path for the drawing tool */  
  private void requestDrawingToolURL() {
    URL url = urlRequest(drawingToolTextField.getText(),JFileChooser.FILES_ONLY);
    if (url !=null) {
      drawingToolTextField.setText(new File(url.getFile()).toString());
      drawingToolChanged=true;
    }
  }
  
  /** This method opens a JFileChooser to choose the path for the project directory */  
  private void requestProjectDirectoryURL() {
    URL url = urlRequest(projectDirectoryTextField.getText(),JFileChooser.DIRECTORIES_ONLY);
    if (url != null) {
      projectDirectoryTextField.setText(new File(url.getFile()).toString());
      projectDirectoryChanged=true;
    }
  }
  
  /** This method opens a JFileChooser to choose the path for OpenTool */  
  private void requestOpenToolURL() {
    URL url = urlRequest(openToolTextField.getText(),JFileChooser.FILES_ONLY);
    if (url != null) {
      openToolTextField.setText(new File(url.getFile()).toString());
      openToolChanged=true;
    }
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    owner.getMyOwner().printlnLogFileOut("AdelfeParameterUI::"+s);
  }
  
  /** this method prints an error on the adelfe log file
   * @param s the error to print
   */  
  public void printErrLog(String s){
    owner.getMyOwner().printlnLogFileErr("AdelfeParameterUI::"+s);
  }
  
  /** This method re-set all the text of the contained components (labels, text
   * fields, ...)
   */  
  private void updateText() {
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Parameter"));
    tabbedPane.setName(this.languageChangeSupport.getRessourceBundle().getString("Locations"));
    openToolLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("OpenTool"));
    projectDirectoryLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("ProjectDirectory"));
    projectDirectoryPanel.add(projectDirectoryLabel, java.awt.BorderLayout.WEST);
    drawingToolLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("DrawingTool"));
    textEditorLabel.setText(this.languageChangeSupport.getRessourceBundle().getString("TextEditor"));
    tabbedPane.addTab(this.languageChangeSupport.getRessourceBundle().getString("Locations"), locationPanel);
    allActivitiesAreAccessibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("AllActivitiesAreAccessible"));
    tabbedPane.addTab(this.languageChangeSupport.getRessourceBundle().getString("Options"), optionPanel);
    initButton.setText(this.languageChangeSupport.getRessourceBundle().getString("Init"));
    okButton.setText(this.languageChangeSupport.getRessourceBundle().getString("OK"));
    synthesisModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("SynthesisModuleIsVisible"));
    managerModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("ManagerModuleIsVisible"));
    descriptionModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("DescriptionModuleIsVisible"));
    exampleModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("ExampleModuleIsVisible"));
    documentModuleIsVisibleCheckBox.setText(this.languageChangeSupport.getRessourceBundle().getString("DocumentModuleIsVisible"));
    tabbedPane.addTab(this.languageChangeSupport.getRessourceBundle().getString("Window"), windowPanel);
  }
  
  /** This method is called when a <CODE>LanguageChangeEvent</CODE> is received
   * @param evt the received event
   */  
  public void LanguageChanged(LanguageChangeEvent evt) {
    updateText();
    pack();
    repaint();
  }
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JCheckBox allActivitiesAreAccessibleCheckBox;
  private javax.swing.JPanel allActivitiesAreAccessiblePanel;
  private javax.swing.JPanel buttonPanel;
  private javax.swing.JCheckBox descriptionModuleIsVisibleCheckBox;
  private javax.swing.JPanel descriptionModuleIsVisiblePanel;
  private javax.swing.JCheckBox documentModuleIsVisibleCheckBox;
  private javax.swing.JPanel documentModuleIsVisiblePanel;
  private javax.swing.JButton drawingToolButton;
  private javax.swing.JLabel drawingToolLabel;
  private javax.swing.JPanel drawingToolPanel;
  private javax.swing.JPanel drawingToolSubPanel;
  private javax.swing.JTextField drawingToolTextField;
  private javax.swing.JCheckBox exampleModuleIsVisibleCheckBox;
  private javax.swing.JPanel exampleModuleIsVisiblePanel;
  private javax.swing.JButton initButton;
  private javax.swing.JPanel locationPanel;
  private javax.swing.JCheckBox managerModuleIsVisibleCheckBox;
  private javax.swing.JPanel managerModuleIsVisiblePanel;
  private javax.swing.JButton okButton;
  private javax.swing.JButton openToolButton;
  private javax.swing.JLabel openToolLabel;
  private javax.swing.JPanel openToolPanel;
  private javax.swing.JPanel openToolSubPanel;
  private javax.swing.JTextField openToolTextField;
  private javax.swing.JPanel optionPanel;
  private javax.swing.JButton projectDirectoryButton;
  private javax.swing.JLabel projectDirectoryLabel;
  private javax.swing.JPanel projectDirectoryPanel;
  private javax.swing.JPanel projectDirectorySubPanel;
  private javax.swing.JTextField projectDirectoryTextField;
  private javax.swing.JCheckBox synthesisModuleIsVisibleCheckBox;
  private javax.swing.JPanel synthesisModuleIsVisiblePanel;
  private javax.swing.JTabbedPane tabbedPane;
  private javax.swing.JButton textEditorButton;
  private javax.swing.JLabel textEditorLabel;
  private javax.swing.JPanel textEditorPanel;
  private javax.swing.JPanel textEditorSubPanel;
  private javax.swing.JTextField textEditorTextField;
  private javax.swing.JPanel windowPanel;
  // End of variables declaration//GEN-END:variables
  
  /** the toolkit UI thaht owns the AdelfeParameterUI */  
  private AdelfeToolkitUI owner;
  
  /** indicates if the path to OT has changed */  
  private boolean openToolChanged = false;
  
  /** indicates if the path to the drawing tool has changed */  
  private boolean drawingToolChanged = false;
  
  /** indicates if the path to the text editor has changed */  
  private boolean textEditorChanged = false;
  
  /** indicates if the path to the adequacy tool has changed */  
  private boolean adequacyChanged = false;
  
  /** indicates if the path to the Acrobat Reader has changed */  
  private boolean acrobatPathChanged = false;
  
  /** indicates if all the activities of the process are supposedd to be accessible or
   * if the user cazn only access to processed accessible activities
   */  
  private boolean allActivitiesAreAccessibleChanged = false;
  
  /** indicates if the path to project has changed */  
  private boolean projectDirectoryChanged = false;
  
  /** indicates if synthesis window is visisble at start */  
  private boolean synthesisModuleIsVisibleChanged = false;
  
  /** indicates if document window is visisble at start */  
  private boolean documentModuleIsVisibleChanged = false;
  
  /** indicates if example window is visisble at start */  
  private boolean exampleModuleIsVisibleChanged = false;
  
  /** indicates if manager window is visisble at start */  
  private boolean managerModuleIsVisibleChanged = false;
  
  /** indicates if description window is visisble at start */  
  private boolean descriptionModuleIsVisibleChanged = false;
  
  /** represents the choice made by the user in the dialog box */  
  private int choice = JOptionPane.CANCEL_OPTION;
  
  /** the LanguageChangeSupport that manages the language changes */  
  private LanguageChangeSupport languageChangeSupport = null;
  
}
