/*
 * AdelfeToolkitUI.java
 *
 * Created on 8 octobre 2002, 14:55
 */

package adelfeToolkit.gui;

import adelfeToolkit.AdelfeToolkit;
import adelfeToolkit.activities.Project;
import adelfeToolkit.activities.ProjectList;
import adelfeToolkit.exceptions.ProcessFailedException;
import adelfeToolkit.exceptions.InitSocketFailedException;
import java.net.UnknownHostException;
import adelfeToolkit.language.*;
import adelfeToolkit.utilities.Confirmer;
import java.awt.print.PrinterJob;
import java.awt.print.*;
import adelfeToolkit.adequacy.AdequacyLauncher;

/** This frame is the GUI for a AdelfeToolkit.
 * It is composed of :
 *  - a manager module;
 *  - a description module;
 *  - a example module;
 *  - a document module;
 *  - a synthesis module;
 *  - a help module.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class AdelfeToolkitUI
extends javax.swing.JFrame
implements adelfeToolkit.utilities.LogWriter, 
LanguageChangeListener,
adelfeToolkit.openTool.OpenToolMessageListener,
adelfeToolkit.shortcuts.ShortCutClickedListener,
adelfeToolkit.modules.ActionExitedListener{
  
  /** Creates new form AdelfeToolkitUI
   * @param own The <CODE>AdelfeToolkit</CODE> that owns the UI
   */
  public AdelfeToolkitUI(AdelfeToolkit own) {
    myOwner = own;
    otms = new adelfeToolkit.openTool.OTMessageSender(this);
    this.languageChangeSupport = new LanguageChangeSupport(myOwner.getLanguage());
    initComponents();
    prePackPersonnalInitComponents();
    pack();
    postPackPersonalInitComponents();
    printOutLog("AdelfeToolkitUI::Main Window created");
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    languageButtonGroup = new javax.swing.ButtonGroup();
    barPanel = new javax.swing.JPanel();
    mainToolBar = new javax.swing.JToolBar();
    newButton = new javax.swing.JButton();
    openButton = new javax.swing.JButton();
    saveButton = new javax.swing.JButton();
    saveAllButton = new javax.swing.JButton();
    printButton = new javax.swing.JButton();
    helpButton = new javax.swing.JButton();
    languageButton = new javax.swing.JButton();
    secondToolBar = new javax.swing.JToolBar();
    adequacyButton = new javax.swing.JButton();
    openToolButton = new javax.swing.JButton();
    previousButton = new javax.swing.JButton();
    nextButton = new javax.swing.JButton();
    mainScrollPane = new javax.swing.JScrollPane();
    mainDesktopPane = new javax.swing.JDesktopPane();
    mainMenuBar = new javax.swing.JMenuBar();
    fileMenu = new javax.swing.JMenu();
    newMenuItem = new javax.swing.JMenuItem();
    openMenuItem = new javax.swing.JMenuItem();
    closeMenuItem = new javax.swing.JMenuItem();
    jSeparator1 = new javax.swing.JSeparator();
    saveMenuItem = new javax.swing.JMenuItem();
    saveAsMenuItem = new javax.swing.JMenuItem();
    jSeparator2 = new javax.swing.JSeparator();
    printMenuItem = new javax.swing.JMenuItem();
    jSeparator3 = new javax.swing.JSeparator();
    quitMenuItem = new javax.swing.JMenuItem();
    editMenu = new javax.swing.JMenu();
    parameterMenuItem = new javax.swing.JMenuItem();
    toolsMenu = new javax.swing.JMenu();
    languageMenu = new javax.swing.JMenu();
    frenchRadioButtonMenuItem = new javax.swing.JRadioButtonMenuItem();
    englishRadioButtonMenuItem = new javax.swing.JRadioButtonMenuItem();
    jSeparator7 = new javax.swing.JSeparator();
    openToolMenuItem = new javax.swing.JMenuItem();
    amasAdequacyMenuItem = new javax.swing.JMenuItem();
    windowMenu = new javax.swing.JMenu();
    managerCheckBoxMenuItem = new javax.swing.JCheckBoxMenuItem();
    workProductCheckBoxMenuItem = new javax.swing.JCheckBoxMenuItem();
    descriptionCheckBoxMenuItem = new javax.swing.JCheckBoxMenuItem();
    exampleCheckBoxMenuItem = new javax.swing.JCheckBoxMenuItem();
    jSeparator8 = new javax.swing.JSeparator();
    synthesisCheckBoxMenuItem = new javax.swing.JCheckBoxMenuItem();
    projectMenu = new javax.swing.JMenu();
    helpMenu = new javax.swing.JMenu();
    aboutAdelfeMenuItem = new javax.swing.JMenuItem();
    helpOnAdelfeMenuItem = new javax.swing.JMenuItem();

    getContentPane().setLayout(new javax.swing.BoxLayout(getContentPane(), javax.swing.BoxLayout.Y_AXIS));

    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Toolkit"));
    setFocusCycleRoot(false);
    setFocusable(false);
    setFocusableWindowState(false);
    setEnabled(false);
    addWindowListener(new java.awt.event.WindowAdapter() {
      public void windowClosing(java.awt.event.WindowEvent evt) {
        exitForm(evt);
      }
    });

    barPanel.setLayout(new java.awt.BorderLayout());

    barPanel.setMaximumSize(new java.awt.Dimension(1024, 42));
    barPanel.setMinimumSize(new java.awt.Dimension(256, 42));
    barPanel.setPreferredSize(new java.awt.Dimension(1024, 42));
    barPanel.setAutoscrolls(true);
    mainToolBar.setFloatable(false);
    newButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/new.gif")));
    newButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("NewToolTip"));
    newButton.setMaximumSize(new java.awt.Dimension(36, 36));
    newButton.setMinimumSize(new java.awt.Dimension(36, 36));
    newButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        newButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(newButton);

    openButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/open.gif")));
    openButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolTip"));
    openButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        openButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(openButton);

    saveButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/save.gif")));
    saveButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveToolTip"));
    saveButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        saveButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(saveButton);

    saveAllButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/saveAll.gif")));
    saveAllButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveAllToolTip"));
    saveAllButton.setMaximumSize(new java.awt.Dimension(36, 36));
    saveAllButton.setMinimumSize(new java.awt.Dimension(36, 36));
    saveAllButton.setPreferredSize(new java.awt.Dimension(36, 36));
    saveAllButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        saveAllButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(saveAllButton);

    printButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/print.gif")));
    printButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("Print"));
    printButton.setMaximumSize(new java.awt.Dimension(36, 36));
    printButton.setMinimumSize(new java.awt.Dimension(36, 36));
    printButton.setPreferredSize(new java.awt.Dimension(36, 36));
    printButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        printButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(printButton);

    helpButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/help.gif")));
    helpButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("Help"));
    helpButton.setMaximumSize(new java.awt.Dimension(36, 36));
    helpButton.setMinimumSize(new java.awt.Dimension(36, 36));
    helpButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        helpButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(helpButton);

    languageButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/lang.gif")));
    languageButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("LanguageToolTip"));
    languageButton.setMaximumSize(new java.awt.Dimension(36, 36));
    languageButton.setMinimumSize(new java.awt.Dimension(36, 36));
    languageButton.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        languageButtonMouseReleased(evt);
      }
    });

    mainToolBar.add(languageButton);

    barPanel.add(mainToolBar, java.awt.BorderLayout.WEST);

    secondToolBar.setFloatable(false);
    adequacyButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/LienAdeq.jpg")));
    adequacyButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("AmasAdequacyToolTip"));
    adequacyButton.setMaximumSize(new java.awt.Dimension(37, 37));
    adequacyButton.setMinimumSize(new java.awt.Dimension(37, 37));
    adequacyButton.setPreferredSize(new java.awt.Dimension(37, 37));
    adequacyButton.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        adequacyButtonActionPerformed(evt);
      }
    });

    secondToolBar.add(adequacyButton);

    openToolButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/OpenTool.GIF")));
    openToolButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolToolTip"));
    openToolButton.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        openToolButtonActionPerformed(evt);
      }
    });

    secondToolBar.add(openToolButton);

    previousButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/previous.gif")));
    previousButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("PreviousToolTip"));
    previousButton.setMaximumSize(new java.awt.Dimension(37, 37));
    previousButton.setMinimumSize(new java.awt.Dimension(37, 37));
    previousButton.setName("previous");
    previousButton.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        previousButtonActionPerformed(evt);
      }
    });

    secondToolBar.add(previousButton);

    nextButton.setIcon(new javax.swing.ImageIcon(getClass().getResource("/adelfeToolkit/gui/image/next.gif")));
    nextButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("NextToolTip"));
    nextButton.setMaximumSize(new java.awt.Dimension(37, 37));
    nextButton.setMinimumSize(new java.awt.Dimension(37, 37));
    nextButton.setName("next");
    nextButton.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        nextButtonActionPerformed(evt);
      }
    });

    secondToolBar.add(nextButton);

    barPanel.add(secondToolBar, java.awt.BorderLayout.EAST);

    getContentPane().add(barPanel);

    mainScrollPane.setMinimumSize(new java.awt.Dimension(0, 0));
    mainScrollPane.setPreferredSize(new java.awt.Dimension(1024, 800));
    mainScrollPane.setAutoscrolls(true);
    mainScrollPane.setViewportView(mainDesktopPane);

    getContentPane().add(mainScrollPane);

    fileMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("File"));
    newMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("New"));
    newMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("NewToolTip"));
    newMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        newMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(newMenuItem);

    openMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Open"));
    openMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolTip"));
    openMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        openMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(openMenuItem);

    closeMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Close"));
    closeMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("CloseToolTip"));
    closeMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        closeMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(closeMenuItem);

    fileMenu.add(jSeparator1);

    saveMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Save"));
    saveMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveToolTip"));
    saveMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        saveMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(saveMenuItem);

    saveAsMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("SaveAs"));
    saveAsMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveAsToolTip"));
    saveAsMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        saveAsMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(saveAsMenuItem);

    fileMenu.add(jSeparator2);

    printMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Print"));
    printMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("PrintToolTip"));
    printMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        printMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(printMenuItem);

    fileMenu.add(jSeparator3);

    quitMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Quit"));
    quitMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("QuitToolTip"));
    quitMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        quitMenuItemMouseReleased(evt);
      }
    });

    fileMenu.add(quitMenuItem);

    mainMenuBar.add(fileMenu);

    editMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Edit"));
    parameterMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Parameter"));
    parameterMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        parameterMenuItemMouseReleased(evt);
      }
    });

    editMenu.add(parameterMenuItem);

    mainMenuBar.add(editMenu);

    toolsMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Tools"));
    toolsMenu.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        toolsMenuActionPerformed(evt);
      }
    });

    languageMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Language"));
    frenchRadioButtonMenuItem.setSelected(LanguageChangeSupport.FRENCH.equals(this.languageChangeSupport.getLanguage()));
    frenchRadioButtonMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("French"));
    frenchRadioButtonMenuItem.setActionCommand("LanguageChangeSupport.FRENCH");
    frenchRadioButtonMenuItem.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        frenchRadioButtonMenuItemActionPerformed(evt);
      }
    });

    languageMenu.add(frenchRadioButtonMenuItem);

    englishRadioButtonMenuItem.setSelected(LanguageChangeSupport.ENGLISH.equals(this.languageChangeSupport.getLanguage()));
    englishRadioButtonMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("English"));
    englishRadioButtonMenuItem.setActionCommand("LanguageChangeSupport.ENGLISH");
    englishRadioButtonMenuItem.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        englishRadioButtonMenuItemActionPerformed(evt);
      }
    });

    languageMenu.add(englishRadioButtonMenuItem);

    toolsMenu.add(languageMenu);

    toolsMenu.add(jSeparator7);

    openToolMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("OpenTool"));
    openToolMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolToolTip"));
    openToolMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        openToolMenuItemMouseReleased(evt);
      }
    });

    toolsMenu.add(openToolMenuItem);

    amasAdequacyMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Adequacy"));
    amasAdequacyMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("AmasAdequacyToolTip"));
    amasAdequacyMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        amasAdequacyMenuItemMouseReleased(evt);
      }
    });

    toolsMenu.add(amasAdequacyMenuItem);

    mainMenuBar.add(toolsMenu);

    windowMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Window"));
    managerCheckBoxMenuItem.setSelected(true);
    managerCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Manager"));
    managerCheckBoxMenuItem.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        managerCheckBoxMenuItemItemStateChanged(evt);
      }
    });

    windowMenu.add(managerCheckBoxMenuItem);

    workProductCheckBoxMenuItem.setSelected(true);
    workProductCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("WorkProduct"));
    workProductCheckBoxMenuItem.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        workProductCheckBoxMenuItemItemStateChanged(evt);
      }
    });

    windowMenu.add(workProductCheckBoxMenuItem);

    descriptionCheckBoxMenuItem.setSelected(true);
    descriptionCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Description"));
    descriptionCheckBoxMenuItem.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        descriptionCheckBoxMenuItemItemStateChanged(evt);
      }
    });

    windowMenu.add(descriptionCheckBoxMenuItem);

    exampleCheckBoxMenuItem.setSelected(true);
    exampleCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Example"));
    exampleCheckBoxMenuItem.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        exampleCheckBoxMenuItemItemStateChanged(evt);
      }
    });

    windowMenu.add(exampleCheckBoxMenuItem);

    windowMenu.add(jSeparator8);

    synthesisCheckBoxMenuItem.setSelected(true);
    synthesisCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Synthesis"));
    synthesisCheckBoxMenuItem.addItemListener(new java.awt.event.ItemListener() {
      public void itemStateChanged(java.awt.event.ItemEvent evt) {
        synthesisCheckBoxMenuItemItemStateChanged(evt);
      }
    });
    synthesisCheckBoxMenuItem.addMenuKeyListener(new javax.swing.event.MenuKeyListener() {
      public void menuKeyPressed(javax.swing.event.MenuKeyEvent evt) {
        synthesisCheckBoxMenuItemMenuKeyPressed(evt);
      }
      public void menuKeyReleased(javax.swing.event.MenuKeyEvent evt) {
      }
      public void menuKeyTyped(javax.swing.event.MenuKeyEvent evt) {
      }
    });

    windowMenu.add(synthesisCheckBoxMenuItem);

    mainMenuBar.add(windowMenu);

    projectMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Project"));
    projectMenu.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("ProjectToolTip"));
    projectMenu.addActionListener(new java.awt.event.ActionListener() {
      public void actionPerformed(java.awt.event.ActionEvent evt) {
        projectMenuActionPerformed(evt);
      }
    });

    mainMenuBar.add(projectMenu);

    helpMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Help"));
    aboutAdelfeMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("About"));
    aboutAdelfeMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        aboutAdelfeMenuItemMouseReleased(evt);
      }
    });

    helpMenu.add(aboutAdelfeMenuItem);

    helpOnAdelfeMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("HelpOn"));
    helpOnAdelfeMenuItem.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        helpOnAdelfeMenuItemMouseReleased(evt);
      }
    });

    helpMenu.add(helpOnAdelfeMenuItem);

    mainMenuBar.add(helpMenu);

    setJMenuBar(mainMenuBar);

  }//GEN-END:initComponents

  private void aboutAdelfeMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_aboutAdelfeMenuItemMouseReleased
    // Add your handling code here:
    AdelfeAboutFrame aaf =  new AdelfeAboutFrame(this);
    aaf.show();
    aaf.toFront();
  }//GEN-LAST:event_aboutAdelfeMenuItemMouseReleased
  
  private void workProductCheckBoxMenuItemItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_workProductCheckBoxMenuItemItemStateChanged
    // Add your handling code here:
    if (workProductCheckBoxMenuItem.getState()) {
      workProductModuleUI.show();
      repaint();
    }
    else {
      workProductModuleUI.hide();
      repaint();
    }
  }//GEN-LAST:event_workProductCheckBoxMenuItemItemStateChanged
  
  private void printMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_printMenuItemMouseReleased
    // Add your handling code here:
    printActiveWindow();
  }//GEN-LAST:event_printMenuItemMouseReleased
  
  private void quitMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_quitMenuItemMouseReleased
    // Add your handling code here:
    exitForm();
  }//GEN-LAST:event_quitMenuItemMouseReleased
  
  private void frenchRadioButtonMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_frenchRadioButtonMenuItemActionPerformed
    // Add your handling code here:
    this.languageChangeSupport.setLanguage(LanguageChangeSupport.FRENCH);
  }//GEN-LAST:event_frenchRadioButtonMenuItemActionPerformed
  
  private void englishRadioButtonMenuItemActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_englishRadioButtonMenuItemActionPerformed
    // Add your handling code here:
    this.languageChangeSupport.setLanguage(LanguageChangeSupport.ENGLISH);
  }//GEN-LAST:event_englishRadioButtonMenuItemActionPerformed
  
  private void toolsMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_toolsMenuActionPerformed
    // Add your handling code here:
  }//GEN-LAST:event_toolsMenuActionPerformed
  
  private void openButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_openButtonMouseReleased
    // Add your handling code here:
    managerModuleUI.openFile();
    refresh();
  }//GEN-LAST:event_openButtonMouseReleased
  
  private void helpButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_helpButtonMouseReleased
    // Add your handling code here:
    helpModuleUI.initPage();
    helpModuleUI.show();
  }//GEN-LAST:event_helpButtonMouseReleased
  
  private void languageButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_languageButtonMouseReleased
    // Add your handling code here:
    if (this.frenchRadioButtonMenuItem.isSelected()) {
      this.englishRadioButtonMenuItem.setSelected(true);
      this.frenchRadioButtonMenuItem.setSelected(false);
      this.languageChangeSupport.setLanguage(LanguageChangeSupport.ENGLISH);
    }
    else {
      this.frenchRadioButtonMenuItem.setSelected(true);
      this.englishRadioButtonMenuItem.setSelected(false);
      this.languageChangeSupport.setLanguage(LanguageChangeSupport.FRENCH);
    }
  }//GEN-LAST:event_languageButtonMouseReleased
  
  private void printButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_printButtonMouseReleased
    // Add your handling code here:
    printActiveWindow();
  }//GEN-LAST:event_printButtonMouseReleased
  
  private void saveAllButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_saveAllButtonMouseReleased
    // Add your handling code here:
    managerModuleUI.saveAllFiles();
    refresh();
  }//GEN-LAST:event_saveAllButtonMouseReleased
  
  private void openToolMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_openToolMenuItemMouseReleased
    // Add your handling code here:
    runOpenTool();
  }//GEN-LAST:event_openToolMenuItemMouseReleased
    
  private void amasAdequacyMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_amasAdequacyMenuItemMouseReleased
    // Add your handling code here:
    runAMASAdeq();
  }//GEN-LAST:event_amasAdequacyMenuItemMouseReleased
  
  private void parameterMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_parameterMenuItemMouseReleased
    // Add your handling code here:
    parameterUI.initOptions();
    parameterUI.show();
    this.refresh();
  }//GEN-LAST:event_parameterMenuItemMouseReleased
  
  private void nextButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_nextButtonActionPerformed
    // Add your handling code here:
    managerModuleUI.nextActivity();
    this.refresh();
  }//GEN-LAST:event_nextButtonActionPerformed
  
  private void previousButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_previousButtonActionPerformed
    // Add your handling code here:
    managerModuleUI.previousActivity();
    this.refresh();
  }//GEN-LAST:event_previousButtonActionPerformed
  
  private void openToolButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_openToolButtonActionPerformed
    // Add your handling code here:
    runOpenTool();
  }//GEN-LAST:event_openToolButtonActionPerformed
  
  private void adequacyButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_adequacyButtonActionPerformed
    // Add your handling code here:
    runAMASAdeq();
  }//GEN-LAST:event_adequacyButtonActionPerformed
  
  private void closeMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_closeMenuItemMouseReleased
    // Add your handling code here:
    managerModuleUI.closeFile();
    refresh();
  }//GEN-LAST:event_closeMenuItemMouseReleased
  
  private void projectMenuItemMouseReleased(java.awt.event.MouseEvent evt) {
    java.awt.Component jmi = evt.getComponent();
    
    String name = ((javax.swing.JMenuItem)jmi).getText();
    myOwner.getManagerModule().selectProject(name);
    //refresh();
    managerModuleUI.reInitialize();
    //this.managerModuleUI.selectActionToDo(myOwner.getManagerModule().getCurrentProject());
  }
  
  private void projectMenuActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_projectMenuActionPerformed
    // Add your handling code here:
  }//GEN-LAST:event_projectMenuActionPerformed
  
  private void saveAsMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_saveAsMenuItemMouseReleased
    // Add your handling code here:
    managerModuleUI.saveAsFile();
    refresh();
    managerModuleUI.refresh();
  }//GEN-LAST:event_saveAsMenuItemMouseReleased
  
  private void saveMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_saveMenuItemMouseReleased
    // Add your handling code here:
    managerModuleUI.saveFile();
    refresh();
  }//GEN-LAST:event_saveMenuItemMouseReleased
  
  private void openMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_openMenuItemMouseReleased
    // Add your handling code here:
    managerModuleUI.openFile();
    refresh();
  }//GEN-LAST:event_openMenuItemMouseReleased
  
  private void newMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_newMenuItemMouseReleased
    // Add your handling code here:
    managerModuleUI.newFile();
    refresh();
  }//GEN-LAST:event_newMenuItemMouseReleased
  
  private void newButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_newButtonMouseReleased
    // Add your handling code here:
    managerModuleUI.newFile();
    refresh();
  }//GEN-LAST:event_newButtonMouseReleased
  
  private void saveButtonMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_saveButtonMouseReleased
    // Add your handling code here:
    managerModuleUI.saveFile();
    refresh();
  }//GEN-LAST:event_saveButtonMouseReleased
  
  private void helpOnAdelfeMenuItemMouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_helpOnAdelfeMenuItemMouseReleased
    // Add your handling code here:
	helpModuleUI.initPage();
    helpModuleUI.show();
  }//GEN-LAST:event_helpOnAdelfeMenuItemMouseReleased
  
  private void synthesisCheckBoxMenuItemMenuKeyPressed(javax.swing.event.MenuKeyEvent evt) {//GEN-FIRST:event_synthesisCheckBoxMenuItemMenuKeyPressed
    // Add your handling code here:
    if (synthesisCheckBoxMenuItem.getState()) {
      synthesisModuleUI.show();
    }
    else {
      synthesisModuleUI.hide();
    }
  }//GEN-LAST:event_synthesisCheckBoxMenuItemMenuKeyPressed
  
  private void synthesisCheckBoxMenuItemItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_synthesisCheckBoxMenuItemItemStateChanged
    // Add your handling code here:
    if (synthesisCheckBoxMenuItem.getState()) {
      synthesisModuleUI.show();
    }
    else {
      synthesisModuleUI.hide();
    }
  }//GEN-LAST:event_synthesisCheckBoxMenuItemItemStateChanged
  
  private void exampleCheckBoxMenuItemItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_exampleCheckBoxMenuItemItemStateChanged
    // Add your handling code here:
    if (exampleCheckBoxMenuItem.getState()) {
      exampleModuleUI.show();
      this.repaint();
    }
    else {
      exampleModuleUI.hide();
      this.repaint();
    }
  }//GEN-LAST:event_exampleCheckBoxMenuItemItemStateChanged
  
  private void descriptionCheckBoxMenuItemItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_descriptionCheckBoxMenuItemItemStateChanged
    // Add your handling code here:
    if (descriptionCheckBoxMenuItem.getState()) {
      descriptionModuleUI.show();
      this.repaint();
    }
    else {
      descriptionModuleUI.hide();
      this.repaint();
    }
  }//GEN-LAST:event_descriptionCheckBoxMenuItemItemStateChanged
  
  private void managerCheckBoxMenuItemItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_managerCheckBoxMenuItemItemStateChanged
    // Add your handling code here:
    if (managerCheckBoxMenuItem.getState()) {
      managerModuleUI.show();
      this.repaint();
    }
    else {
      managerModuleUI.hide();
      this.repaint();
    }
  }//GEN-LAST:event_managerCheckBoxMenuItemItemStateChanged
  
  /** Exit the Application
   * @param evt the received event
   */
    private void exitForm(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_exitForm
      exitForm();
    }//GEN-LAST:event_exitForm
    
    private void exitForm() {
      int ch = confirmBeforeClosing();
      if (ch == Confirmer.YES_OPTION) {
        managerModuleUI.saveAllFiles();
        getMyOwner().exit();
        System.exit(0);
      }
      if (ch == Confirmer.NO_OPTION) {
        getMyOwner().exit();
        System.exit(0);
      }
      if (ch == Confirmer.CANCEL_OPTION) {
      }
    }
    
    private int confirmBeforeClosing() {
      return Confirmer.confirmYesNo(this, this.languageChangeSupport);
    }
    
    private void runOpenTool() {
      try {
        getMyOwner().runOpenTool();
        this.toBack();
        System.out.println(getMyOwner().getManagerModule().getCurrentProject().getSaveNumber());
        //if (getMyOwner().getManagerModule().getCurrentProject().getSaveNumber() != 0){
        //  this.managerModuleUI.saveOTFile();
        //}
      }
      catch (ProcessFailedException e) {
        displayError("OpenTool Process failed : "+e.getCause(),
        "OpenTool Shortcut Error Occured");
        printErrLog("openToolButtonActionPerformed::process failed");
        myOwner.setOpenToolRunning(false);
      }
      catch (UnknownHostException e) {
        displayError("OpenTool Socket Unknown "+e.getCause(),
        "OpenTool Shortcut Error Occured");
        printErrLog("openToolButtonActionPerformed::process failed");
        myOwner.setOpenToolRunning(false);
      }
      catch (InitSocketFailedException e) {
        try {
          myOwner.getOpenToolConnector().initSocket();
        }
        catch (Exception e2) {
        }
      }
    }
    
    public void runAMASAdeq() {
      String [] lf = {"francais"};
      String [] le = {"anglais"};
      AdequacyLauncher al = new AdequacyLauncher(this,this);;
      if (!this.isAdequacyRunning()) {
        if ((this.languageChangeSupport.getLanguage()) ==
        (LanguageChangeSupport.FRENCH)) {
          AdequacyLauncher.main(lf);
        }
        else {
          AdequacyLauncher.main(le);
        }
      }
      else {
        al.getMonCadre().show();
      }
    }
    
    private void prePackPersonnalInitComponents() {
      mainDesktopPane.setPreferredSize(new java.awt.Dimension(1600,1200));
      this.languageChangeSupport.addLanguageChangeListener(this);
      initManagerModuleUI();
      initWorkProductModuleUI();
      initDescriptionModuleUI();
      initExampleModuleUI();
      initHelpModuleUI();
      initSynthesisModuleUI();
      initAdelfeToolkitUI();
      initProjectMenu();
      initParameterUI();
      this.setIconImage(java.awt.Toolkit.getDefaultToolkit().getImage(
      getClass().getResource("/adelfeToolkit/gui/image/SMAC.gif")));
      this.languageButtonGroup.add(this.englishRadioButtonMenuItem);
      this.languageButtonGroup.add(this.frenchRadioButtonMenuItem);
    }
    
    private void postPackPersonalInitComponents() {
      managerModuleUI.renameCurrentProject();
      managerModuleUI.reInitialize();
    }
    
    /** this method selects and focus the initial ActionToDo in the managerModuleUI */    
    public void selectFocus() {
      managerModuleUI.selectAndFocus();
    }
    
    /** an initialization method */    
    private void initDescriptionModuleUI() {
      descriptionModuleUI = new DescriptionModuleUI(this,
      this.myOwner.getDescriptionModule());
      this.myOwner.getDescriptionModule().setUI(descriptionModuleUI);
      mainDesktopPane.add(descriptionModuleUI);
      descriptionModuleUI.setPreferredSize(new java.awt.Dimension(700,400));
      descriptionModuleUI.setBounds(300,0,700,400);
      descriptionModuleUI.setVisible(myOwner.isDescriptionModuleIsVisible());
      descriptionCheckBoxMenuItem.setState(myOwner.isDescriptionModuleIsVisible());
    }
    
    /** an initialization method */    
    private void initManagerModuleUI() {
      managerModuleUI = new ManagerModuleUI(this,this.myOwner.getManagerModule());
      this.myOwner.getManagerModule().setUI(managerModuleUI);
      mainDesktopPane.add(managerModuleUI);
      managerModuleUI.setPreferredSize(new java.awt.Dimension(300,550));
      managerModuleUI.setBounds(0,0,300,550);
      managerModuleUI.setVisible(myOwner.isManagerModuleIsVisible());
      managerCheckBoxMenuItem.setState(myOwner.isManagerModuleIsVisible());
    }
    
    /** an initialization method */    
    private void initHelpModuleUI() {
      helpModuleUI = new HelpModuleUI(this,this.myOwner.getHelpModule());
      this.myOwner.getHelpModule().setUI(helpModuleUI);
      helpModuleUI.setSize(new java.awt.Dimension(800,600));
      //helpModuleUI.setLocation(1000,0);
      helpModuleUI.setVisible(false);
    }
    
    /** an initialization method */    
    private void initExampleModuleUI() {
      exampleModuleUI = new ExampleModuleUI(this,this.myOwner.getExampleModule());
      this.myOwner.getExampleModule().setUI(exampleModuleUI);
      mainDesktopPane.add(exampleModuleUI);
      exampleModuleUI.setPreferredSize(new java.awt.Dimension(300,550));
      exampleModuleUI.setBounds(300,400,700,300);
      exampleModuleUI.setVisible(myOwner.isExampleModuleIsVisible());
      exampleCheckBoxMenuItem.setState(myOwner.isExampleModuleIsVisible());
    }
    
    /** an initialization method */    
    private void initSynthesisModuleUI() {
      synthesisModuleUI = new SynthesisModuleUI(this,this.myOwner.getSynthesisModule());
      this.myOwner.getSynthesisModule().setUI(synthesisModuleUI);
      synthesisModuleUI.setSize(new java.awt.Dimension(800,600));
      //synthesisModuleUI.setLocation(1000,200);
      synthesisModuleUI.setVisible(myOwner.isSynthesisModuleIsVisible());
      synthesisCheckBoxMenuItem.setState(myOwner.isSynthesisModuleIsVisible());
    }
    
    /** an initialization method */    
    private void initWorkProductModuleUI() {
      workProductModuleUI = new WorkProductModuleUI(this,this.myOwner.getWorkProductModule());
      this.myOwner.getWorkProductModule().setUI(workProductModuleUI);
      mainDesktopPane.add(workProductModuleUI);
      workProductModuleUI.setPreferredSize(new java.awt.Dimension(300,250));
      workProductModuleUI.setBounds(0,550,300,150);
      workProductModuleUI.setVisible(myOwner.isDocumentModuleIsVisible());
      workProductCheckBoxMenuItem.setState(myOwner.isDocumentModuleIsVisible());
    }
    
    /** an initialization method */    
    private void initAdelfeToolkitUI() {
      refresh();
    }
    
    /** initializes the project menu */    
    private void initProjectMenu() {
      projectMenu.removeAll();
      ProjectList pl = myOwner.getManagerModule().getProjectList();
      javax.swing.JMenuItem jmi;
      
      for (int i=0;i<pl.size();i++) {
        jmi=new javax.swing.JMenuItem();
        jmi.setText(((Project)pl.get(i)).getActionName());
        jmi.addMouseListener(new java.awt.event.MouseAdapter() {
          public void mouseReleased(java.awt.event.MouseEvent evt) {
            projectMenuItemMouseReleased(evt);
          }
        });
        projectMenu.add(jmi);
      }
    }
    
    /** initializes the <CODE>AdelfeParameterUI</CODE> */    
    private void initParameterUI() {
      parameterUI = new AdelfeParameterUI(this);
      helpModuleUI.setVisible(false);
    }
    
    /** This method updates the texts fo the UI components by using the languageChangeSupport */    
    private void updateText() {
      if (titleOption == PROJECT_NAME_WITHOUT_PATH) {
        this.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Toolkit") + " - " + myOwner.getManagerModule().getCurrentProject().getActionName());
      }
      else {
        java.net.URL file = myOwner.getManagerModule().getFileToSaveTo();
        this.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Toolkit") + " - " + file.getFile());
      }
      fileMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("File"));
      newMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("New"));
      openMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Open"));
      closeMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Close"));
      saveMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Save"));
      saveAsMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("SaveAs"));
      printMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Print"));
      quitMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Quit"));
      editMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Edit"));
//      copyMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Copy"));
//      pasteMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Paste"));
//      findMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Find"));
//      deleteMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Delete"));
      parameterMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Parameter"));
      toolsMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Tools"));
      projectMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Project"));
      languageMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Language"));
      openToolMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("OpenTool"));
      amasAdequacyMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Adequacy"));
      //quickPrototypingMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Prototyping"));
      windowMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Window"));
      managerCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Manager"));
      workProductCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("WorkProduct"));
      descriptionCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Description"));
      exampleCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Example"));
      synthesisCheckBoxMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("Synthesis"));
      helpMenu.setText(this.languageChangeSupport.getRessourceBundle().getString("Help"));
      aboutAdelfeMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("About"));
      helpOnAdelfeMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("HelpOn"));
      frenchRadioButtonMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("French"));
      englishRadioButtonMenuItem.setText(this.languageChangeSupport.getRessourceBundle().getString("English"));
      
      descriptionModuleUI.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Description"));
      managerModuleUI.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Manager"));
      workProductModuleUI.setTitle(this.languageChangeSupport.getRessourceBundle().getString("WorkProduct"));
      exampleModuleUI.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Example"));
      helpModuleUI.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Help"));
      synthesisModuleUI.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Synthesis"));
    }
    
    /** This method updates the tooltips by using the languageChangeSupport */    
    private void updateToolTip() {
      newMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("NewToolTip"));
      newButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("NewToolTip"));
      openMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolTip"));
      openButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolTip"));
      closeMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("CloseToolTip"));
      saveMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveToolTip"));
      saveButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveToolTip"));
      saveAllButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveAllToolTip"));
      saveAsMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("SaveAsToolTip"));
      printMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("PrintToolTip"));
      printButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("Print"));
      languageButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("Language"));
      quitMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("QuitToolTip"));
      languageMenu.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("LanguageToolTip"));
      openToolMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolToolTip"));
      openToolButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("OpenToolToolTip"));
      amasAdequacyMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("AmasAdequacyToolTip"));
      adequacyButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("AmasAdequacyToolTip"));
      //quickPrototypingMenuItem.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("PrototypingToolTip"));
      previousButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("PreviousToolTip"));
      nextButton.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString("NextToolTip"));
    }
    
    /** This method refreshes all the contained components of the <CODE>AdelfeToolkitUI</CODE> */    
    public void refresh() {
      descriptionModuleUI.refresh();
      exampleModuleUI.refresh();
      workProductModuleUI.refresh();
      helpModuleUI.refresh();
      if (titleOption == PROJECT_NAME_WITHOUT_PATH) {
        this.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Toolkit") + " - " + myOwner.getManagerModule().getCurrentProject().getActionName());
      }
      else {
        java.net.URL file = myOwner.getManagerModule().getFileToSaveTo();
        this.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Toolkit") + " - " + file.getFile());
      }
      synthesisModuleUI.refresh();
      initProjectMenu();
    }
    
    /** This method prints by a PrinterJob the content of the active frame. */    
    private void printActiveWindow() {
      Printable toPrint = null;
      if (descriptionModuleUI.isSelected()) {toPrint = descriptionModuleUI.getPrintableComponent();}
      if (exampleModuleUI.isSelected()) {toPrint = exampleModuleUI.getPrintableComponent();}
      if (synthesisModuleUI.isVisible()) {toPrint = synthesisModuleUI.getPrintableComponent();}
      
      if (toPrint != null) {
        PrinterJob printJob = PrinterJob.getPrinterJob();
        PageFormat pf = printJob.pageDialog(printJob.defaultPage());
        printJob.setPrintable(toPrint);
        //Book bk = new Book();
        //bk.append(toPrint, printJob.defaultPage());
        if (printJob.printDialog()) {
          try {
            printJob.print();
          } catch (Exception ex) {
            displayError("An exception occured during print job : \n"+ex.getMessage(),"Print Error");
            printErrLog("printActiveWindow::An exception occured during print job");
            ex.printStackTrace();
          }
        }
      }
      else {
        displayError("There is no printable component selected\n"+"You can only print description, example or synthesis","Print Error");
        printErrLog("printActiveWindow::There is no printable component selected");
      }
    }
    
    /** Getter for property synthesisCheckBoxMenuItem.
     * @return Value of property synthesisCheckBoxMenuItem.
     *
     */
    public javax.swing.JCheckBoxMenuItem getSynthesisCheckBoxMenuItem() {
      return synthesisCheckBoxMenuItem;
    }
    
    /** Setter for property synthesisCheckBoxMenuItem.
     * @param synthesisCheckBoxMenuItem New value of property synthesisCheckBoxMenuItem.
     *
     */
    public void setSynthesisCheckBoxMenuItem(javax.swing.JCheckBoxMenuItem synthesisCheckBoxMenuItem) {
      this.synthesisCheckBoxMenuItem = synthesisCheckBoxMenuItem;
    }
    
    /** Getter for property helpModuleUI.
     * @return Value of property helpModuleUI.
     *
     */
    public HelpModuleUI getHelpModuleUI() {
      return helpModuleUI;
    }
    
    /** Setter for property helpModuleUI.
     * @param helpModuleUI New value of property helpModuleUI.
     *
     */
    public void setHelpModuleUI(HelpModuleUI helpModuleUI) {
      this.helpModuleUI = helpModuleUI;
    }
    
    /** Getter for property descriptionModuleUI.
     * @return Value of property descriptionModuleUI.
     *
     */
    public DescriptionModuleUI getDescriptionModuleUI() {
      return descriptionModuleUI;
    }
    
    /** Setter for property descriptionModuleUI.
     * @param descriptionModuleUI New value of property descriptionModuleUI.
     *
     */
    public void setDescriptionModuleUI(DescriptionModuleUI descriptionModuleUI) {
      this.descriptionModuleUI = descriptionModuleUI;
    }
    
    /** Getter for property exampleModuleUI.
     * @return Value of property exampleModuleUI.
     *
     */
    public ExampleModuleUI getExampleModuleUI() {
      return exampleModuleUI;
    }
    
    /** Setter for property exampleModuleUI.
     * @param exampleModuleUI New value of property exampleModuleUI.
     *
     */
    public void setExampleModuleUI(ExampleModuleUI exampleModuleUI) {
      this.exampleModuleUI = exampleModuleUI;
    }
    
    /** Getter for property managerModuleUI.
     * @return Value of property managerModuleUI.
     *
     */
    public ManagerModuleUI getManagerModuleUI() {
      return managerModuleUI;
    }
    
    /** Setter for property managerModuleUI.
     * @param managerModuleUI New value of property managerModuleUI.
     *
     */
    public void setManagerModuleUI(ManagerModuleUI managerModuleUI) {
      this.managerModuleUI = managerModuleUI;
    }
    
    /** Getter for property synthesisModuleUI.
     * @return Value of property synthesisModuleUI.
     *
     */
    public SynthesisModuleUI getSynthesisModuleUI() {
      return synthesisModuleUI;
    }
    
    /** Setter for property synthesisModuleUI.
     * @param synthesisModuleUI New value of property synthesisModuleUI.
     *
     */
    public void setSynthesisModuleUI(SynthesisModuleUI synthesisModuleUI) {
      this.synthesisModuleUI = synthesisModuleUI;
    }
    
    /** Getter for property workProductModuleUI.
     * @return Value of property workProductModuleUI.
     *
     */
    public WorkProductModuleUI getWorkProductModuleUI() {
      return workProductModuleUI;
    }
    
    /** Setter for property workProductModuleUI.
     * @param workProductModuleUI New value of property workProductModuleUI.
     *
     */
    public void setWorkProductModuleUI(WorkProductModuleUI workProductModuleUI) {
      this.workProductModuleUI = workProductModuleUI;
    }
    
    /** Getter for property myOwner.
     * @return Value of property myOwner.
     *
     */
    public adelfeToolkit.AdelfeToolkit getMyOwner() {
      return myOwner;
    }
    
    /** Setter for property myOwner.
     * @param myOwner New value of property myOwner.
     *
     */
    public void setToolkit(adelfeToolkit.AdelfeToolkit myOwner) {
      this.myOwner = myOwner;
    }
    
    /** This method displays a dialog box to inform about an error
     * @param s the tile of the dialog box
     * @param m the message in the dialog box
     */    
    public void displayError(String s, String m) {
      javax.swing.JOptionPane.showMessageDialog(this,
      s,
      m,
      javax.swing.JOptionPane.WARNING_MESSAGE);
    }
    
    /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
    public void printOutLog(String s){
      myOwner.printlnLogFileOut("AdelfeToolkitUI::"+s);
    }
    
    /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
    public void printErrLog(String s){
      myOwner.printlnLogFileErr("AdelfeToolkitUI::"+s);
    }
    
    /** This method is called when a <CODE>LanguageChangeEvent</CODE> is received
     * @param evt the received event
     */    
    public void LanguageChanged(LanguageChangeEvent evt) {
      updateText();
      updateToolTip();
      refresh();
    }
    
    /** Getter for property languageChangeSupport.
     * @return Value of property languageChangeSupport.
     *
     */
    public adelfeToolkit.language.LanguageChangeSupport getLanguageChangeSupport() {
      return languageChangeSupport;
    }
    
    /** Setter for property languageChangeSupport.
     * @param languageChangeSupport New value of property languageChangeSupport.
     *
     */
    public void setLanguageChangeSupport(adelfeToolkit.language.LanguageChangeSupport languageChangeSupport) {
      this.languageChangeSupport = languageChangeSupport;
    }
    
    /** Getter for property adequacyRunning.
     * @return Value of property adequacyRunning.
     *
     */
    public boolean isAdequacyRunning() {
      return adequacyRunning;
    }
    
    /** Setter for property adequacyRunning.
     * @param adequacyRunning New value of property adequacyRunning.
     *
     */
    public void setAdequacyRunning(boolean adequacyRunning) {
      this.adequacyRunning = adequacyRunning;
    }
    
    /** Getter for property otms.
     * @return Value of property otms.
     *
     */
    public adelfeToolkit.openTool.OTMessageSender getOtms() {
      return otms;
    }
    
    /** Setter for property otms.
     * @param otms New value of property otms.
     *
     */
    public void setOtms(adelfeToolkit.openTool.OTMessageSender otms) {
      this.otms = otms;
    }
    
    /** This method is called when an <CODE>OpenToolMessageEvent</CODE> is received
     * @param evt the received event
     */    
    public void openToolMessageReceived(adelfeToolkit.openTool.OpenToolMessageEvent evt) {
      this.repaint();
    }
    
    /** This method is called when a <CODE>ShortCutClickedEvent</CODE> is received
     * @param evt the received event
     */    
    public void shortCutClicked(adelfeToolkit.shortcuts.ShortCutClickedEvent evt) {
      this.repaint();
    }
    
    /** This method is called when an <CODE>ActionExited</CODE> event is received
     * @param evt the received event
     */    
    public void actionExited(adelfeToolkit.modules.ActionExitedEvent evt) {
      this.repaint();
    }
    
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JMenuItem aboutAdelfeMenuItem;
  private javax.swing.JButton adequacyButton;
  private javax.swing.JMenuItem amasAdequacyMenuItem;
  private javax.swing.JPanel barPanel;
  private javax.swing.JMenuItem closeMenuItem;
  private javax.swing.JCheckBoxMenuItem descriptionCheckBoxMenuItem;
  private javax.swing.JMenu editMenu;
  private javax.swing.JRadioButtonMenuItem englishRadioButtonMenuItem;
  private javax.swing.JCheckBoxMenuItem exampleCheckBoxMenuItem;
  private javax.swing.JMenu fileMenu;
  private javax.swing.JRadioButtonMenuItem frenchRadioButtonMenuItem;
  private javax.swing.JButton helpButton;
  private javax.swing.JMenu helpMenu;
  private javax.swing.JMenuItem helpOnAdelfeMenuItem;
  private javax.swing.JSeparator jSeparator1;
  private javax.swing.JSeparator jSeparator2;
  private javax.swing.JSeparator jSeparator3;
  private javax.swing.JSeparator jSeparator7;
  private javax.swing.JSeparator jSeparator8;
  private javax.swing.JButton languageButton;
  private javax.swing.ButtonGroup languageButtonGroup;
  private javax.swing.JMenu languageMenu;
  private javax.swing.JDesktopPane mainDesktopPane;
  private javax.swing.JMenuBar mainMenuBar;
  private javax.swing.JScrollPane mainScrollPane;
  private javax.swing.JToolBar mainToolBar;
  private javax.swing.JCheckBoxMenuItem managerCheckBoxMenuItem;
  private javax.swing.JButton newButton;
  private javax.swing.JMenuItem newMenuItem;
  private javax.swing.JButton nextButton;
  private javax.swing.JButton openButton;
  private javax.swing.JMenuItem openMenuItem;
  private javax.swing.JButton openToolButton;
  private javax.swing.JMenuItem openToolMenuItem;
  private javax.swing.JMenuItem parameterMenuItem;
  private javax.swing.JButton previousButton;
  private javax.swing.JButton printButton;
  private javax.swing.JMenuItem printMenuItem;
  private javax.swing.JMenu projectMenu;
  private javax.swing.JMenuItem quitMenuItem;
  private javax.swing.JButton saveAllButton;
  private javax.swing.JMenuItem saveAsMenuItem;
  private javax.swing.JButton saveButton;
  private javax.swing.JMenuItem saveMenuItem;
  private javax.swing.JToolBar secondToolBar;
  private javax.swing.JCheckBoxMenuItem synthesisCheckBoxMenuItem;
  private javax.swing.JMenu toolsMenu;
  private javax.swing.JMenu windowMenu;
  private javax.swing.JCheckBoxMenuItem workProductCheckBoxMenuItem;
  // End of variables declaration//GEN-END:variables
  
  /** The <CODE>AdelfeToolkit</CODE> represented by the UI */  
  private AdelfeToolkit myOwner;
  
  /** The UI for the <CODE>DescriptionModule</CODE> of the <CODE>AdelfeToolkit</CODE> */  
  private DescriptionModuleUI descriptionModuleUI;
  
  /** The UI for the <CODE>ManagerModule</CODE> of the <CODE>AdelfeToolkit</CODE> */  
  private ManagerModuleUI managerModuleUI;
  
  /** The UI for the <CODE>HelpModule</CODE> of the <CODE>AdelfeToolkit</CODE> */  
  private HelpModuleUI helpModuleUI;
  
  /** The UI that displays synthesis of the current project */  
  private SynthesisModuleUI synthesisModuleUI;
  
  /** The UI for the <CODE>ExampleModule</CODE> of the <CODE>AdelfeToolkit</CODE> */  
  private ExampleModuleUI exampleModuleUI;
  
  /** The UI for the <CODE>WorkProductModule</CODE> of the <CODE>AdelfeToolkit</CODE> */  
  private WorkProductModuleUI workProductModuleUI;
  
  /** This UI is used to parameter the toolkit */  
  private AdelfeParameterUI parameterUI;
  
  /** represents an option */  
  private final int PROJECT_NAME_WITHOUT_PATH = 0;
  
  /** represents an option */  
  private final int PROJECT_NAME_WITH_PATH = 1;
  
  /** the current title display option */  
  private int titleOption = PROJECT_NAME_WITHOUT_PATH;
  
  /** The <CODE>LanguageChangeSupport</CODE> that manages the language changes */  
  private LanguageChangeSupport languageChangeSupport;
  
  /** is the adequacy tool running? */  
  private boolean adequacyRunning = false;
  
  /** to send message to OpenTool via a socket */  
  private adelfeToolkit.openTool.OTMessageSender otms;
  
}
