/*
 * AdelfeTreeCellRenderer.java
 *
 * Created on 6 dcembre 2002, 09:38
 */

package adelfeToolkit.gui;

import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.ImageIcon;
import javax.swing.JTree;
import java.awt.Component;
import adelfeToolkit.activities.Activity;
import adelfeToolkit.activities.Step;
import adelfeToolkit.activities.WorkProduct;
import adelfeToolkit.activities.Model;
import adelfeToolkit.activities.Document;
import adelfeToolkit.language.*;

/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class AdelfeTreeCellRenderer extends DefaultTreeCellRenderer {
  
  /** Creates a new instance of AdelfeTreeCellRenderer */
  public AdelfeTreeCellRenderer() {
  }
  
  public AdelfeTreeCellRenderer(AdelfeToolkitUI toolkit) {
    toolkitUI = toolkit;
    languageChangeSupport = toolkitUI.getLanguageChangeSupport();
  }
  
  public Component getTreeCellRendererComponent(
  JTree tree,
  Object value,
  boolean sel,
  boolean expanded,
  boolean leaf,
  int row,
  boolean hasFocus) {
    
    super.getTreeCellRendererComponent(
    tree, value, sel,
    expanded, leaf, row,
    hasFocus);
    
    if (value != null) {
      Object obj = ((AdelfeMutableTreeNode)value).getUserObject();
      
      if (obj instanceof Activity){// && (!(((AdelfeMutableTreeNode)value).isRoot()))) {
        image = new ImageIcon(getClass().getResource(IMAGE_PATH+"activity.gif"));
        Activity act = (Activity)((AdelfeMutableTreeNode)value).getUserObject();
        boolean acsb = act.isAccessible();
        boolean cmpl = act.isCompleted();
        boolean isAllActivitiesAreAccessible = toolkitUI.getMyOwner().isAllActivitiesAreAccessible();
        
        setIcon(image);
        setToolTipText(act.displayString());
        if (cmpl) {
          setForeground(java.awt.Color.green);
        }
        if (!acsb) {
          setForeground(java.awt.Color.GRAY);
        } else {
          setForeground(java.awt.Color.BLACK);
        }
        setEnabled(acsb || isAllActivitiesAreAccessible);
        setFocusable(acsb || isAllActivitiesAreAccessible);
      }
      else {
        if (obj instanceof Step) {
          image = new ImageIcon(getClass().getResource(IMAGE_PATH+"step.gif"));
          Step stp = (Step)((AdelfeMutableTreeNode)value).getUserObject();
          String name = stp.getActionName();
          boolean acsb = stp.isAccessible();
          boolean cmpl = stp.isCompleted();
          boolean isAllActivitiesAreAccessible = toolkitUI.getMyOwner().isAllActivitiesAreAccessible();
          
          setIcon(image);
          setToolTipText(stp.displayString());
          if (cmpl) {
            setForeground(java.awt.Color.green);
          }
          if (!acsb) {
            setForeground(java.awt.Color.GRAY);
          } else {
            setForeground(java.awt.Color.BLACK);
          }
          setEnabled(acsb || isAllActivitiesAreAccessible);
          setFocusable(acsb || isAllActivitiesAreAccessible);
        }
        else {
          if (obj instanceof Model) {
            image = new ImageIcon(getClass().getResource(IMAGE_PATH+"model.gif"));
            Model mdl = (Model)((AdelfeMutableTreeNode)value).getUserObject();
            boolean fnl = mdl.getState().equals(WorkProduct.FINAL);
            boolean prdt = mdl.isProducted();
            boolean acsb = mdl.isAccessible();
            boolean isAllActivitiesAreAccessible = toolkitUI.getMyOwner().isAllActivitiesAreAccessible();
            
            setIcon(image);
            setToolTipText(mdl.displayString());
            if (prdt) {
              setForeground(java.awt.Color.green);
            }
            setEnabled(acsb || isAllActivitiesAreAccessible);
            setFocusable(acsb || isAllActivitiesAreAccessible);
          }
          else {
            if (obj instanceof Document) {
              image = new ImageIcon(getClass().getResource(IMAGE_PATH+"document.gif"));
              Document doc = (Document)((AdelfeMutableTreeNode)value).getUserObject();
              boolean fnl = doc.getState().equals(WorkProduct.FINAL);
              boolean prdt = doc.isProducted();
              boolean acsb = doc.isAccessible();
              boolean isAllActivitiesAreAccessible = toolkitUI.getMyOwner().isAllActivitiesAreAccessible();
              
              setIcon(image);
              setToolTipText(doc.displayString());
              if (prdt) {
                setForeground(java.awt.Color.green);
              }
              setEnabled(acsb || isAllActivitiesAreAccessible);
              setFocusable(acsb || isAllActivitiesAreAccessible);
            }
            else {
              if (obj instanceof WorkProduct) {
                image = new ImageIcon(getClass().getResource(IMAGE_PATH+"workproduct.gif"));
                WorkProduct wrkp = (WorkProduct)((AdelfeMutableTreeNode)value).getUserObject();
                boolean fnl = wrkp.getState().equals(WorkProduct.FINAL);
                boolean prdt = wrkp.isProducted();
                boolean acsb = wrkp.isAccessible();
                boolean isAllActivitiesAreAccessible = toolkitUI.getMyOwner().isAllActivitiesAreAccessible();
                
                setIcon(image);
                setToolTipText(wrkp.displayString());
                if (prdt) {
                  setForeground(java.awt.Color.green);
                }
                setEnabled(acsb || isAllActivitiesAreAccessible);
                setFocusable(acsb || isAllActivitiesAreAccessible);
              }
              else {
                
                setToolTipText(null); //no tool tip
              }
            }
          }
        }
      }
      updateUI();
    }
    
    return this;
  }
  
  /** Getter for property toolkitUI.
   * @return Value of property toolkitUI.
   *
   */
  public AdelfeToolkitUI getToolkitUI() {
    return toolkitUI;
  }
  
  /** Setter for property toolkitUI.
   * @param toolkitUI New value of property toolkitUI.
   *
   */
  public void setToolkitUI(AdelfeToolkitUI toolkitUI) {
    this.toolkitUI = toolkitUI;
  }
  
  protected static String IMAGE_PATH = "/adelfeToolkit/gui/image/";
  
  private ImageIcon image;
  
  private AdelfeToolkitUI toolkitUI;
  
  private LanguageChangeSupport languageChangeSupport = null;
  
}
