/*
 * DescriptionModuleUI.java
 *
 * Created on 3 dcembre 2002, 11:09
 */

package adelfeToolkit.gui;

import adelfeToolkit.modules.DescriptionModule;
import java.util.Vector;
import java.net.URL;
import java.io.IOException;
import adelfeToolkit.shortcuts.*;
import javax.swing.event.HyperlinkEvent;
import adelfeToolkit.language.*;

/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class DescriptionModuleUI
extends javax.swing.JInternalFrame
implements adelfeToolkit.utilities.LogWriter,
LanguageChangeListener,
adelfeToolkit.print.PrintableComponentOwner,
adelfeToolkit.shortcuts.ShortClickedEventHandler {
  
  /** Creates new form DescriptionModuleUI */
  public DescriptionModuleUI() {
    initComponents();
  }
  
  public DescriptionModuleUI(AdelfeToolkitUI mf, DescriptionModule mod) {
    module = mod;
    owner = mf;
    languageChangeSupport = mf.getLanguageChangeSupport();
    languageChangeSupport.addLanguageChangeListener(this);
    initComponents();
    personalInitComponents();
  }
  
  public void updateDisplay() {
    String s = null;
    try {
      String sUrl = adelfeToolkit.AdelfeToolkit.DEFAULT_PATH
      +this.languageChangeSupport.getLanguage()
      +"/"
      +module.getCurrentDescription().getFilePath()
      +module.getCurrentDescription().getFileName();
      System.out.println(sUrl);
      displayURL(getClass().getResource(sUrl));
    } catch (Exception e) {
      displayError("Couldn't create help URL: " + s,"Description Module Error Occurred");
      printErrLog("updateDisplay::Couldn't create help URL: " + s);
      try {
        displayURL(getClass().getResource("/adelfeToolkit/resources/error.html"));
      } catch (Exception e2) {
        displayError("Couldn't create help URL: " + s,"Description Module Error Occurred");
        printErrLog("updateDisplay::Couldn't create help URL: " + s);
      }
    }
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("DF")+" "+
    this.languageChangeSupport.getRessourceBundle().getString(module.getCurrentDescription().getName()));
  }
  
  private void displayURL(URL url) {
    try {
      jEditorPane.setPage(url);
    } catch (IOException e) {
      displayError("Attempted to read a bad URL: " + url,"Description Module Error Occurred");
      printErrLog("displayURL::Attempted to read a bad URL: " + url);
      try {
        jEditorPane.setPage(getClass().getResource("/adelfeToolkit/resources/error.html"));
      } catch (Exception e2) {
        displayError("Could not display error URL","Description Module Error Occurred");
        printErrLog("displayURL::Could not display error URL");
      }
    }
  }
  
  private void updateShortcuts() {
    Vector v = module.getCurrentDescription().getShortcuts();
    toolBar.removeAll();
    
    for (int i = 0;i < v.size();i++) {
      ShortcutButton button = new ShortcutButton((Shortcut)v.get(i));
      button.setIcon(new javax.swing.ImageIcon(getClass().getResource(((Shortcut)v.get(i)).getIconUrl())));
      button.setMaximumSize(new java.awt.Dimension(37, 37));
      button.setMinimumSize(new java.awt.Dimension(37, 37));
      button.setName(((Shortcut)v.get(i)).getName());
      button.setToolTipText(this.languageChangeSupport.getRessourceBundle().getString(((Shortcut)v.get(i)).getName()));
      
      button.addActionListener(new java.awt.event.ActionListener() {
        public void actionPerformed(java.awt.event.ActionEvent evt) {
          buttonActionPerformed(evt);
        }
      });
      
      toolBar.add(button);
    }
    
  }
  
  private void buttonActionPerformed(java.awt.event.ActionEvent evt) {
    Shortcut sc = ((ShortcutButton)evt.getSource()).getShortcut();
    sc.setProjectName(this.owner.getMyOwner().getManagerModule().getCurrentProject().getActionName());
    
    System.out.println(sc.getType());
    
    if (sc.getType() == Shortcut.OPEN_TOOL_BATCH_COMMAND) {
      owner.getOtms().sendCommandToOpenTool(((OpenToolBatchCommandShortcut)sc).otCommand()+"\n\014");
      this.fireShortCutClickedReceived(new adelfeToolkit.shortcuts.ShortCutClickedEvent(this,this.module.getCurrentDescription().getName()));
      owner.refresh();
      owner.toBack();
    }
    if (sc.getType() == Shortcut.DRAWING_TOOL_COMMAND) {
      sc.setPath(owner.getMyOwner().getDrawingTool());
      try {
        java.lang.Process p  = Runtime.getRuntime().exec(((ShellCommandShortcut)sc).shellCommand());
        this.fireShortCutClickedReceived(new adelfeToolkit.shortcuts.ShortCutClickedEvent(this,this.module.getCurrentDescription().getName()));
        owner.refresh();
        owner.toBack();
      } catch (java.io.IOException e) {
        displayError("Drawing Tool Process Failed","Description Module Error Occurred");
        printErrLog("buttonActionPerformed::process failed");
      }
    }
    if (sc.getType() == Shortcut.TEXT_EDITOR_COMMAND) {
      sc.setPath(owner.getMyOwner().getTextEditor());
      try {
        java.lang.Process p  = Runtime.getRuntime().exec(((ShellCommandShortcut)sc).shellCommand());
        this.fireShortCutClickedReceived(new adelfeToolkit.shortcuts.ShortCutClickedEvent(this,this.module.getCurrentDescription().getName()));
        owner.refresh();
        owner.toBack();
      } catch (java.io.IOException e) {
        displayError("Text Editor Process Failed","Description Module Error Occurred");
        printErrLog("buttonActionPerformed::process failed");
      }
    }
    if (sc.getType() == Shortcut.JAVA_EXECUTABLE) {
    }
    
    if (sc.getType() == Shortcut.ADEQUACY_TOOL_COMMAND) {
      //try {
        owner.runAMASAdeq();
        this.fireShortCutClickedReceived(new adelfeToolkit.shortcuts.ShortCutClickedEvent(this,this.module.getCurrentDescription().getName()));
      //}
      //catch (ProcessFailedException e) {
      //  displayError("Adelfe Adequacy Tool Process failed : "+e.getCause(),"AMAS Adequacy Shortcut Error Occured");
      //  printErrLog("adequacyButtonActionPerformed::process failed");
      //}
    }
    
    if (sc.getType() == Shortcut.NCS_TEMPLATE_COMMAND) {
      ((adelfeToolkit.shortcuts.OpenNCSTemplateRtf)sc).setWorkingDirectory(this.owner.getMyOwner().getManagerModule().getDirectory().getFile());
      sc.setPath(owner.getMyOwner().getTextEditor());
      try {
        java.lang.Process p  = Runtime.getRuntime().exec(((ShellCommandShortcut)sc).shellCommand());
        this.fireShortCutClickedReceived(new adelfeToolkit.shortcuts.ShortCutClickedEvent(this,this.module.getCurrentDescription().getName()));
        owner.refresh();
        owner.toBack();
      } catch (java.io.IOException e) {
        displayError("Pdf viewer Process Failed","Description Module Error Occurred");
        printErrLog("buttonActionPerformed::process failed");
      }
    }
    
    if (sc.getType() == Shortcut.REQUIREMENTS_TEMPLATE_COMMAND) {
      ((adelfeToolkit.shortcuts.OpenRequirementsTemplateRtf)sc).setWorkingDirectory(this.owner.getMyOwner().getManagerModule().getDirectory().getFile());
      sc.setPath(owner.getMyOwner().getTextEditor());
      try {
        java.lang.Process p  = Runtime.getRuntime().exec(((ShellCommandShortcut)sc).shellCommand());
        this.fireShortCutClickedReceived(new adelfeToolkit.shortcuts.ShortCutClickedEvent(this,this.module.getCurrentDescription().getName()));
        owner.refresh();
        owner.toBack();
      } catch (java.io.IOException e) {
        displayError("Pdf viewer Process Failed","Description Module Error Occurred");
        printErrLog("buttonActionPerformed::process failed");
      }
    }
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    toolBarPanel = new javax.swing.JPanel();
    toolBar = new javax.swing.JToolBar();
    jScrollPane = new javax.swing.JScrollPane();

    setIconifiable(true);
    setMaximizable(true);
    setResizable(true);
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Description"));
    toolBarPanel.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.LEFT));

    toolBarPanel.add(toolBar);

    getContentPane().add(toolBarPanel, java.awt.BorderLayout.NORTH);

    getContentPane().add(jScrollPane, java.awt.BorderLayout.CENTER);

    pack();
  }//GEN-END:initComponents
  
  private void personalInitComponents() {
    jEditorPane = new PrintableEditorPane();
    jEditorPane.setEditable(false);
    jEditorPane.addHyperlinkListener(new javax.swing.event.HyperlinkListener() {
      public void hyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
        jEditorPaneHyperlinkUpdate(evt);
      }
    });
    jScrollPane.setViewportView(jEditorPane);
  }
  
  private void jEditorPaneHyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
    // Add your handling code here:
    if (evt.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
      try {
        URL url = evt.getURL();
        HyperLinkManipulator hlm = new HyperLinkManipulator(owner);
        hlm.processHyperLinkActivation(url);
      } catch (Throwable t) {
        t.printStackTrace();
      }
    }
    if (evt.getEventType() == HyperlinkEvent.EventType.ENTERED) {
    }
    if (evt.getEventType() == HyperlinkEvent.EventType.EXITED) {
    }
  }
  
  public void refresh() {
    updateDisplay();
    updateShortcuts();
  }
  
  private void displayError(String s, String m) {
    owner.displayError(s,m);
  }
  
  /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    owner.getMyOwner().printlnLogFileOut("DescriptionModuleUI::"+s);
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printErrLog(String s){
    owner.getMyOwner().printlnLogFileErr("DescriptionModuleUI::"+s);
  }
  
  public void LanguageChanged(LanguageChangeEvent evt) {
    refresh();
  }
  
  public java.awt.print.Printable getPrintableComponent() {
    return this.jEditorPane;
  }
  
  public void addShortCutClickedListener(ShortCutClickedListener listener) {
    this.listeners.addElement(listener);
  }
  
  public void fireShortCutClickedReceived(ShortCutClickedEvent evt) {
    int i;
    for(i=0;i<this.listeners.size();i++)
      ((ShortCutClickedListener) this.listeners.get(i)).shortCutClicked(evt);
  }
  
  public void removeShortCutClickedListener(ShortCutClickedListener listener) {
    this.listeners.removeElement(listener);
  }
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JScrollPane jScrollPane;
  private javax.swing.JToolBar toolBar;
  private javax.swing.JPanel toolBarPanel;
  // End of variables declaration//GEN-END:variables
  
  
  private PrintableEditorPane jEditorPane;
  private AdelfeToolkitUI owner;
  
  private DescriptionModule module;
  
  private LanguageChangeSupport languageChangeSupport = null;
  
  private java.util.Vector listeners = new java.util.Vector(0);
  
}
