/*
 * ExampleModuleUI.java
 *
 * Created on 3 dcembre 2002, 11:14
 */

package adelfeToolkit.gui;

import java.io.IOException;
import java.net.URL;

import javax.swing.JEditorPane;
import javax.swing.event.HyperlinkEvent;

import adelfeToolkit.language.LanguageChangeEvent;
import adelfeToolkit.language.LanguageChangeListener;
import adelfeToolkit.language.LanguageChangeSupport;
import adelfeToolkit.modules.ExampleModule;

/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class ExampleModuleUI extends javax.swing.JInternalFrame implements adelfeToolkit.utilities.LogWriter, LanguageChangeListener, adelfeToolkit.print.PrintableComponentOwner{
  
  private AdelfeToolkitUI owner;
  
  private ExampleModule module;
  
  private LanguageChangeSupport languageChangeSupport = null;
  
  /** Creates new form ExampleModuleUI */
  public ExampleModuleUI() {
    initComponents();
  }
  
  public ExampleModuleUI(AdelfeToolkitUI mf, ExampleModule mod) {
    owner = mf;
    module = mod;
    languageChangeSupport = owner.getLanguageChangeSupport();
    languageChangeSupport.addLanguageChangeListener(this);
    initComponents();
    personalInitComponents();
  }
  
  public void updateDisplay() {
    String s = null;
    try {
      displayURL(getClass().getResource(adelfeToolkit.AdelfeToolkit.DEFAULT_PATH
      +this.languageChangeSupport.getLanguage()
      +"/"
      +module.getCurrentExample().getFilePath()
      +module.getCurrentExample().getFileName()));
    } catch (Exception e) {
      printErrLog("updateDisplay::Couldn't create help URL: " + s);
    }
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("EF")+" "+
    this.languageChangeSupport.getRessourceBundle().getString(module.getCurrentExample().getName()));
  }
  
  private void displayURL(URL url) {
    try {
      jEditorPane.setPage(url);
    } catch (IOException e) {
      printErrLog("updateDisplay::Attempted to read a bad URL: " + url);
      try {
        jEditorPane.setPage(getClass().getResource("/adelfeToolkit/resources/error.html"));
      } catch (Exception e2) {
        printErrLog("updateDisplay::Couldn't create help URL");
      }
    }
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    jScrollPane = new javax.swing.JScrollPane();

    setIconifiable(true);
    setMaximizable(true);
    setResizable(true);
    setTitle("Example");
    getContentPane().add(jScrollPane, java.awt.BorderLayout.CENTER);

    pack();
  }//GEN-END:initComponents
  
  private void personalInitComponents() {
    jEditorPane = new PrintableEditorPane();
    jEditorPane.setEditable(false);
    jEditorPane.addHyperlinkListener(new javax.swing.event.HyperlinkListener() {
      public void hyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
        jEditorPaneHyperlinkUpdate(evt);
      }
    });
    
    jScrollPane.setViewportView(jEditorPane);
  }
  
  private void jEditorPaneHyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
    // Add your handling code here:
    JEditorPane pane = (JEditorPane) evt.getSource();
    if (evt.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
      try {
        URL url = evt.getURL();
        HyperLinkManipulator hlm = new HyperLinkManipulator(owner);
        hlm.processHyperLinkActivation(url);
      } catch (Throwable t) {
        t.printStackTrace();
      }
    }
    if (evt.getEventType() == HyperlinkEvent.EventType.ENTERED) {
    }
    if (evt.getEventType() == HyperlinkEvent.EventType.EXITED) {
    }
  }
  
  public void refresh() {
    updateDisplay();
  }
  
  private void displayError(String s, String m) {
    owner.displayError(s,m);
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    owner.getMyOwner().printlnLogFileOut("ExampleModuleUI::"+s);
  }
  
  /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
  public void printErrLog(String s){
    owner.getMyOwner().printlnLogFileErr("ExampleModuleUI::"+s);
  }
  
  public void LanguageChanged(LanguageChangeEvent evt) {
    refresh();
  }
  
  public java.awt.print.Printable getPrintableComponent() {
    return this.jEditorPane;
  }
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JScrollPane jScrollPane;
  // End of variables declaration//GEN-END:variables
  
  private PrintableEditorPane jEditorPane;
}
