/*
 * HelpModuleUI.java
 *
 * Created on 3 dcembre 2002, 11:18
 */

package adelfeToolkit.gui;

import adelfeToolkit.modules.HelpModule;
import java.net.URL;
import java.io.IOException;
import javax.swing.event.HyperlinkEvent;
import adelfeToolkit.language.*;

/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class HelpModuleUI
	extends javax.swing.JFrame
	implements adelfeToolkit.utilities.LogWriter, LanguageChangeListener {

	private AdelfeToolkitUI owner;

	private HelpModule module;

	private static String DEFAULT_PAGE =
		"/adelfeToolkit/resources/english/Help.html";

	private LanguageChangeSupport languageChangeSupport = null;

	/** Creates new form HelpModuleUI */
	public HelpModuleUI() {
		initComponents();
	}

	public HelpModuleUI(AdelfeToolkitUI mf, HelpModule mod) {
		owner = mf;
		module = mod;
		this.languageChangeSupport = owner.getLanguageChangeSupport();
		languageChangeSupport.addLanguageChangeListener(this);
		this.setVisible(false);
		initComponents();
		this.setIconImage(
			java.awt.Toolkit.getDefaultToolkit().getImage(
				getClass().getResource("/adelfeToolkit/gui/image/SMAC.gif")));
	}

	/** This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the Form Editor.
	 */
	private void initComponents() { //GEN-BEGIN:initComponents
		jScrollPane = new javax.swing.JScrollPane();
		jEditorPane = new javax.swing.JEditorPane();

		setDefaultCloseOperation(
			javax.swing.WindowConstants.DO_NOTHING_ON_CLOSE);
		setTitle("Help");
		addWindowListener(new java.awt.event.WindowAdapter() {
			public void windowClosing(java.awt.event.WindowEvent evt) {
				exitForm(evt);
			}
		});

		jEditorPane.setEditable(false);
		jEditorPane
			.addHyperlinkListener(new javax.swing.event.HyperlinkListener() {
			public void hyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
				jEditorPaneHyperlinkUpdate(evt);
			}
		});

		jScrollPane.setViewportView(jEditorPane);

		getContentPane().add(jScrollPane, java.awt.BorderLayout.CENTER);

		pack();
	} //GEN-END:initComponents

	public void initPage() {
		//displayURL(getClass().getResource("/adelfeToolkit/resources/english/Help.html"));
	}

	private void jEditorPaneHyperlinkUpdate(
		javax.swing.event.HyperlinkEvent evt) {
		//GEN-FIRST:event_jEditorPaneHyperlinkUpdate
		// Add your handling code here:
		if (evt.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
			try {
				URL url = evt.getURL();
				HyperLinkManipulator hlm = new HyperLinkManipulator(owner);
				hlm.processHyperLinkActivation(url);
			} catch (Throwable t) {
				t.printStackTrace();
			}
		}
		if (evt.getEventType() == HyperlinkEvent.EventType.ENTERED) {
		}
		if (evt.getEventType() == HyperlinkEvent.EventType.EXITED) {
		}
	} //GEN-LAST:event_jEditorPaneHyperlinkUpdate

	/** Exit the Application */
	private void exitForm(
		java.awt.event.WindowEvent evt) { //GEN-FIRST:event_exitForm
		this.hide();
	} //GEN-LAST:event_exitForm

	public void updateDisplay() {
		String s = null;
		try {
			module.setUrl(
				adelfeToolkit.utilities.URLManipulator.changeURLLanguage(
					module.getUrl(),
					this.languageChangeSupport.getLanguage()));
			displayURL(module.getUrl());
		} catch (Exception e) {
			displayError(
				"Couldn't create help URL: " + s,
				"Help Module Error Occurred");
			printErrLog("updateDisplay::Couldn't create help URL: " + s);
			try {
				displayURL(
					getClass().getResource(
						"/adelfeToolkit/resources/error.html"));
			} catch (Exception e2) {
				displayError(
					"Couldn't create help URL: " + s,
					"Help Module Error Occurred");
				printErrLog("updateDisplay::Couldn't create help URL: " + s);
			}
		}
		setTitle(
			this.languageChangeSupport.getRessourceBundle().getString("Help"));
	}

	public void displayURL(URL url) {
		try {
			module.setUrl(url);
			jEditorPane.setPage(url);
		} catch (IOException e) {
			printErrLog("displayURL::Attempted to read a bad URL: " + url);
			try {
				jEditorPane.setPage(
					getClass().getResource(
						"/adelfeToolkit/resources/error.html"));
			} catch (Exception e2) {
				printErrLog("displayURL::Could not display error URL");
			}
		}
	}

	public void refresh() {
		updateDisplay();
	}

	public void setHelpURL(URL url) {
		module.setUrl(url);
	}

	private void displayError(String s, String m) {
		owner.displayError(s, m);
	}

	/** this method prints message on the adelfe log file
	 * @param s the message to print
	 */
	public void printOutLog(String s) {
		owner.getMyOwner().printlnLogFileOut("HelpModuleUI::" + s);
	}

	/** this method prints error on the adelfe log file
	 * @param s the message to print
	 */
	public void printErrLog(String s) {
		owner.getMyOwner().printlnLogFileErr("HelpModuleUI::" + s);
	}

	public void LanguageChanged(LanguageChangeEvent evt) {
		refresh(); 
	}

	public javax.swing.JComponent componentToPrint() {
		return this.jEditorPane;
	}

	// Variables declaration - do not modify//GEN-BEGIN:variables
	private javax.swing.JEditorPane jEditorPane;
	private javax.swing.JScrollPane jScrollPane;
	// End of variables declaration//GEN-END:variables

}
