/*
 * HyperLinkManipulator.java
 *
 * Created on 6 mars 2003, 14:05
 */

package adelfeToolkit.gui;

import java.net.URL;

import adelfeToolkit.utilities.URLManipulator;


/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class HyperLinkManipulator implements adelfeToolkit.utilities.LogWriter{
  
  private AdelfeToolkitUI uI;
  
  protected static String ADELFE = "Ade";
  
  protected static String INTRO = "Int";
  
  protected static String ACTIVITY_DESCRIPTION = "Act";
  
  protected static String STEP_DESCRIPTION = "Stp";
  
  protected static String GLOSSARY_ITEM = "Glo";
  
  protected static String ACTIVITY_EXAMPLE = "ExA";
  
  protected static String STEP_EXAMPLE = "ExS";
  
  protected static String HELP = "Hel";
  
  /** Creates a new instance of HyperLinkManipulator */
  public HyperLinkManipulator() {
  }
  
  public HyperLinkManipulator(AdelfeToolkitUI ui) {
    setUI(ui);
  }
  
  public void processHyperLinkActivation(URL url) {
    String type = URLManipulator.getURLType(url);
    if (type.equals(ACTIVITY_DESCRIPTION)) {           //link to an activity description
      int actN = URLManipulator.getActivityNumber(url);
      goToDescription(url,actN,0);
    }
    else if (type.equals(STEP_DESCRIPTION)) {      //link to a step description
      int actN = URLManipulator.getActivityNumber(url);
      int stpN = URLManipulator.getStepNumber(url);
      goToDescription(url,actN,stpN);
    }
    else if (type.equals(GLOSSARY_ITEM)) {      //link to a glossary item
      goToGlossaryItem(url);
    }
    else if (type.equals(HELP)) {               //link to the help page
      goToGlossaryItem(url);
    }
    else if (type.equals(ACTIVITY_EXAMPLE)) {      //link to an activity example
      goToActivityExample(url);
    }
    else if (type.equals(STEP_EXAMPLE)) {      //link to a step example
      goToStepExample(url);
    }
	else if (type.equals(ADELFE) || type.equals(INTRO)) {           //link to an adelfe page
		HelpModuleUI hm = this.getUI().getHelpModuleUI();
  		hm.setHelpURL(url); 
  		hm.displayURL(url);
  		hm.show();
		}
    else {
      printErrLog("processHyperLinkActivation::File " + url + " is ill-named.");
    }
    uI.refresh();
  }
  
  private void goToDescription(URL url,int activityNumber, int stepNumber) {
    this.getUI().getManagerModuleUI().selectActionToDo(activityNumber,stepNumber);
  }
  
  private void goToGlossaryItem(URL url) {
    HelpModuleUI hm = this.getUI().getHelpModuleUI();
    hm.setHelpURL(url); 
    hm.displayURL(url);
    hm.show();
  }
  
  private void goToActivityExample(URL url) {
  }
  
  private void goToStepExample(URL url) {
  }
  
  /** Getter for property uI.
   * @return Value of property uI.
   *
   */
  public AdelfeToolkitUI getUI() {
    return uI;
  }
  
  /** Setter for property uI.
   * @param uI New value of property uI.
   *
   */
  public void setUI(AdelfeToolkitUI uI) {
    this.uI = uI;
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    uI.getMyOwner().printlnLogFileOut("HyperLinkManipulator::"+s);
  }
  
  /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
  public void printErrLog(String s){
    uI.getMyOwner().printlnLogFileErr("HyperLinkManipulator::"+s);
  }
  
}
