/*
 * ManagerModuleUI.java
 *
 * Created on 3 dcembre 2002, 11:23
 */

package adelfeToolkit.gui;

import adelfeToolkit.modules.ManagerModule;
import javax.swing.JTree;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.TreeSelectionModel;
import java.util.Vector;
import adelfeToolkit.activities.ActionToDo;
import adelfeToolkit.activities.Activity;
import adelfeToolkit.activities.Project;
import adelfeToolkit.activities.Step;
import adelfeToolkit.activities.ActivityList;
import adelfeToolkit.activities.StepList;
import adelfeToolkit.utilities.DlfFilter;
import adelfeToolkit.utilities.ExtensionGetter;
import javax.swing.event.TreeSelectionListener;
import javax.swing.event.TreeSelectionEvent;
import javax.swing.tree.TreePath;
import java.net.URL;
import java.io.File;
import javax.swing.JFileChooser;
import java.awt.event.MouseListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.JOptionPane;
import adelfeToolkit.utilities.StringRequester;
import adelfeToolkit.language.*;

/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */

public class ManagerModuleUI extends javax.swing.JInternalFrame implements adelfeToolkit.utilities.LogWriter, LanguageChangeListener{
  
  private final static int OPEN_FILE_IDENTIFIER = 0;
  private final static int SAVE_FILE_IDENTIFIER = 1;
  private final static int SAVE_AS_FILE_IDENTIFIER = 2;
  
  /** Creates new form ManagerModuleUI */
  public ManagerModuleUI() {
    initComponents();
  }
  
  public ManagerModuleUI(AdelfeToolkitUI mf, ManagerModule mod) {
    owner = mf;
    module = mod;
    languageChangeSupport = owner.getLanguageChangeSupport();
    languageChangeSupport.addLanguageChangeListener(this);
    initComponents();
    personalInitComponents();
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    jScrollPane = new javax.swing.JScrollPane();
    jTree = new javax.swing.JTree();

    setIconifiable(true);
    setMaximizable(true);
    setResizable(true);
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Manager"));
    jScrollPane.setViewportView(jTree);

    getContentPane().add(jScrollPane, java.awt.BorderLayout.CENTER);

    pack();
  }//GEN-END:initComponents
  
  private void personalInitComponents() {
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Manager"));
    createNodes();
    jTree = new JTree(treeModel);
    jTree.setEditable(false);
    jTree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);
    jTree.setShowsRootHandles(true);
    javax.swing.ToolTipManager.sharedInstance().registerComponent(jTree);
    jTree.setCellRenderer(new AdelfeTreeCellRenderer(this.owner));
    jScrollPane.setViewportView(jTree);
    jTree.addTreeSelectionListener(new TreeSelectionListener() {
      public void valueChanged(TreeSelectionEvent e) {
        AdelfeMutableTreeNode node = (AdelfeMutableTreeNode)jTree.getLastSelectedPathComponent();
        if (node == null) return;
        Object userObject = node.getUserObject();
        if ((((ActionToDo)userObject).isAccessible()) || (module.getOwner().isAllActivitiesAreAccessible())) {
          if (userObject instanceof Project || userObject instanceof Activity) {
            module.setCurrentActionToDo((ActionToDo)node.getUserObject());
          }
          else if (userObject instanceof Step) {
            AdelfeMutableTreeNode parent = (AdelfeMutableTreeNode)node.getParent();
            module.setCurrentActionToDo((ActionToDo)parent.getUserObject());
            module.setCurrentActionToDo((ActionToDo)userObject);
            module.fireActionExitedReceived(new adelfeToolkit.modules.ActionExitedEvent(userObject));
            //System.out.println(((ActionToDo)userObject).getActionName());
          }
          else {
            printErrLog("TreeSelectionListener::valueChanged::Bad node reference class");
          }
        }
        else {
          selectActionToDo(module.getCurrentProject());
        }
        owner.refresh();
      }
    });
    jTree.setSelectionPath(jTree.getPathForRow(module.getCurrentProject().getCurrentIndex()));
    
    MouseListener ml = new MouseAdapter() {
      public void mouseReleased(MouseEvent e) {
        int selRow = jTree.getRowForLocation(e.getX(), e.getY());
        TreePath selPath = jTree.getPathForLocation(e.getX(), e.getY());
        if(selRow != -1) {
          if (e.getButton() == MouseEvent.BUTTON3) {
            rightClick(selRow,selPath,e);
          }
        }
      }
    };
    jTree.addMouseListener(ml);
  }
  
  private void createNodes() {
    treeNode = new ActionToDoNode(module.getCurrentProject(),this.languageChangeSupport);
    nodeList = new Vector();
    ActivityList al = module.getCurrentProject().getActivityList();
    treeModel = new DefaultTreeModel(treeNode);
    
    for (int i=0;i<al.size();i++) {
      AdelfeMutableTreeNode node;
      Activity act = (Activity)al.get(i);
      node = new ActionToDoNode(act,this.languageChangeSupport);
      createSubNodes(node,0);
      nodeList.add(node);
      treeNode.add(node);
    }
  }
  
  private void createSubNodes(AdelfeMutableTreeNode n, int depth) {
    StepList sl = ((Activity)n.getUserObject()).getSteps();
    if (sl.size()>0) {
      int size = sl.size();
      for (int i=0;i<size;i++) {
        AdelfeMutableTreeNode node;
        Step step = (Step)sl.get(i);
        node = new ActionToDoNode(step,this.languageChangeSupport);
        if (depth>0) {
          createSubNodes(node,depth-1);
        }
        n.add(node);
      }
    }
  }
  
  public void selectActionToDo(int activityNumber, int stepNumber) {
    ActionToDo act = module.getActionToDoForIndexes(activityNumber,stepNumber);
    int currentActivity = 0;
    if (stepNumber == 0) {
      jTree.setSelectionPath(jTree.getNextMatch(act.toString(this.languageChangeSupport),0,javax.swing.text.Position.Bias.Forward));
    }
    else {
      ActionToDo activity  = module.getActionToDoForIndexes(activityNumber,0);
      TreePath path = jTree.getNextMatch(activity.toString(this.languageChangeSupport),0,javax.swing.text.Position.Bias.Forward);
      jTree.expandPath(path);
      path = jTree.getNextMatch(act.toString(this.languageChangeSupport),jTree.getRowForPath(path),javax.swing.text.Position.Bias.Forward);
      jTree.setSelectionPath(path);
    }
  }
  
  public void selectActionToDo(Project p) {
    ActionToDo act = p.getCurrentActivity();
    
    if (act instanceof Activity || act instanceof Step) {
      ActionToDo stp  = ((Activity)act).getCurrentStep();
      //jTree.setSelectionPath(jTree.getClosestPathForLocation(0,0));
      TreePath path = jTree.getNextMatch(act.toString(this.languageChangeSupport),0,javax.swing.text.Position.Bias.Forward);
      //if (ct.isActivity()) {
      jTree.expandPath(path);
      path = jTree.getNextMatch(act.toString(this.languageChangeSupport),jTree.getRowForPath(path),javax.swing.text.Position.Bias.Forward);
      jTree.setSelectionPath(path);
      //}
    } else {
      if (act instanceof Project) {
        jTree.setSelectionPath(jTree.getClosestPathForLocation(0,0));
      }
    }
  }
  
  public void nextActivity() {
    ActionToDoNode node = (ActionToDoNode)jTree.getLastSelectedPathComponent();
    int n = jTree.getRowForPath(jTree.getSelectionPath());
    String next;
    
    if (n == 0) {
      next = ((Activity)module.getCurrentProject().getActivityList().get(0)).toString(this.languageChangeSupport);
    }
    else {
      Object userObject = node.getUserObject();
      String name = "";
      if (userObject instanceof Activity) {
        name = ((Activity)node.getUserObject()).toString(this.languageChangeSupport);
      }
      else if (userObject instanceof Step) {
        node = (ActionToDoNode)(node.getParent());
        name = ((Activity)node.getUserObject()).toString(this.languageChangeSupport);
      }
      next = module.getCurrentProject().getNextActivityString(name,this.languageChangeSupport);
    }
    jTree.setSelectionPath(jTree.getNextMatch(next,n,javax.swing.text.Position.Bias.Forward));
  }
  
  public void previousActivity() {
    ActionToDoNode node = (ActionToDoNode)jTree.getLastSelectedPathComponent();
    int n = jTree.getRowForPath(jTree.getSelectionPath());
    String previous;
    
    if (n <= 1) {
      return;
      //previous = module.getProjectName();
    }
    else {
      Object userObject = node.getUserObject();
      String name = "";
      
      if (userObject instanceof Activity) {
        name = ((Activity)node.getUserObject()).toString(this.languageChangeSupport);
      }
      else if (userObject instanceof Step) {
        node = (ActionToDoNode)(node.getParent());
        name = ((Activity)node.getUserObject()).toString(this.languageChangeSupport);
      }
      previous = module.getCurrentProject().getPreviousActivityString(name,this.languageChangeSupport);
    }
    jTree.setSelectionPath(jTree.getNextMatch(previous,n,javax.swing.text.Position.Bias.Backward));
  }
  
  public void reInitialize() {
    personalInitComponents();
    selectActionToDo(module.getCurrentProject());
  }
  
  public void refresh() {
    treeModel.nodeChanged(treeNode);
  }
  
  public void saveFile() {
    URL url;
    if (module.getSaveNumber() == 0) {
      // the user has to type a file name to save :
      saveAsFile();
    }
    else {
      url = module.getFileToSaveTo();
      if (url != null) {
        module.saveFile(url);
        saveOTFile();
      }
    }
  }
  
  public void saveAllFiles() {
    Project ps = module.getCurrentProject();
    int np = module.getProjectList().size();
    int i;
    for (i=0;i<np;i++){
      Project p = (Project)(module.getProjectList().elementAt(i));
      module.selectProject(p.getActionName());
      saveFile();
    }
    module.selectProject(ps.getActionName());
  }
  
  public void openFile() {
    URL url = urlRequest(OPEN_FILE_IDENTIFIER);
    if (url != null) {
      module.openFile(url);
      openOTFile();
      treeModel.nodeChanged(treeNode);
      reInitialize();
    }
  }
  
  public void saveAsFile() {
    URL url = urlRequest(SAVE_AS_FILE_IDENTIFIER);
    if (url != null) {
      module.saveFile(url);
      saveOTFile();
      treeModel.nodeChanged(treeNode);
    }
  }
  
  public void saveOTFile() {
    //creates a directory for OT file if necessary
    String dir = module.getCurrentProject().getDirectory().getFile()
    +module.getCurrentProject().getActionName()
    +"_OT";
    java.io.File dirOT = new java.io.File(dir);
    if (!dirOT.exists()) {
      dirOT.mkdir();
    }
    
    if (owner.getMyOwner().isOpenToolRunning()) {
      //save the otu file if possible
      String filesep = System.getProperty("file.separator");
      String comm = "THIS.system.transactionSaveAs(\""
      +dirOT.getAbsolutePath()
      +filesep
      +module.getCurrentProject().getActionName()
      +".otu\");"//THIS.system.name:=\""
      //+module.getCurrentProject().getActionName()
      //+"\
      +"\n\014";
      owner.getOtms().sendCommandToOpenTool(comm);
    }
  }
  
  public void openOTFile() {
    String dir = module.getCurrentProject().getDirectory().getFile()
    +module.getCurrentProject().getActionName()
    +"_OT";
    java.io.File dirOT = new java.io.File(dir);
    if (!dirOT.exists()) {
      dirOT.mkdir();
    }
    
    if (owner.getMyOwner().isOpenToolRunning()) {
      //open the otu file if possible
//      String filesep = System.getProperty("file.separator");
//      String comm = "THIS.system.transactionSaveAs(\""
//      +dirOT.getAbsolutePath()
//      +filesep
//      +module.getCurrentProject().getActionName()
//      +".otu\");THIS.system.name:=\""
//      +module.getCurrentProject().getActionName()
//      +"\";\n\014";
//      System.out.println(comm);
//      owner.getOtms().sendCommandToOpenTool(comm);
    }
  }
  
  public void newFile() {
    module.newFile();
    reInitialize();
    renameCurrentProject();
  }
  
  public void renameCurrentProject() {
    Project p = module.getCurrentProject();
    p.setActionName(StringRequester.stringRequest(
    p.getActionName(),
    this.languageChangeSupport.getRessourceBundle().getString("ChooseAProjectName"),
    this.languageChangeSupport.getRessourceBundle().getString("TypeYourProjectNameHere"),
    this.languageChangeSupport.getRessourceBundle().getString("Yes"),
    this.languageChangeSupport.getRessourceBundle().getString("Cancel")));
    reInitialize();
  }
  
  private URL urlRequest(int id) {
    JFileChooser chooser = new JFileChooser();
    chooser.setLocation(100, 200);
    chooser.setCurrentDirectory(new File(module.getDirectory().getFile()));
    chooser.addChoosableFileFilter(new DlfFilter());
    chooser.setSelectedFile(new File(module.getCurrentProject().getActionName()));
    int returnVal = JFileChooser.CANCEL_OPTION;
    
    switch (id) {
      case SAVE_FILE_IDENTIFIER : {
        returnVal = chooser.showSaveDialog(this);
        if(returnVal == JFileChooser.APPROVE_OPTION) {
          printOutLog("urlRequest::You chose to save in this file: " +
          chooser.getSelectedFile().getName());
        }
        break;
      }
      case OPEN_FILE_IDENTIFIER : {
        returnVal = chooser.showOpenDialog(this);
        if(returnVal == JFileChooser.APPROVE_OPTION) {
          printOutLog("urlRequest::You chose to open this file: " +
          chooser.getSelectedFile().getName());
        }
        break;
      }
      case SAVE_AS_FILE_IDENTIFIER : {
        returnVal = chooser.showSaveDialog(this);
        if(returnVal == JFileChooser.APPROVE_OPTION) {
          String ext = ExtensionGetter.getExtension(chooser.getSelectedFile());
          if (!(ext.equals(ExtensionGetter.dlf))) {
            chooser.setSelectedFile(new File(chooser.getSelectedFile().toString()+"."+ExtensionGetter.dlf));
          }
          printOutLog("urlRequest::You chose to save in this file: " + chooser.getSelectedFile().getName());
        }
        break;
      }
    }
    
    if (returnVal == JFileChooser.CANCEL_OPTION) {
      return null;
    }
    
    URL url = module.getFileToSaveTo();
    try {
      File choosedFile = chooser.getSelectedFile();
      if (choosedFile != null) {
        url = (choosedFile.toURL());
      }
    }
    catch (java.net.MalformedURLException e) {
      printErrLog("fileNameRequest::MalformedURLException");
    }
    
    return url;
  }
  
  public void closeFile() {
    int choice = adelfeToolkit.utilities.Confirmer.confirm(this,this.languageChangeSupport);
    switch (choice) {
      case JOptionPane.NO_OPTION : {module.closeFile();reInitialize();break;}
      case JOptionPane.YES_OPTION  : {saveAsFile();module.closeFile();reInitialize();break;}
      default : {}
    }
  }
  
  private void rightClick(int row, TreePath path, MouseEvent evt) {
    Object obj = path.getLastPathComponent();
    //    if (obj instanceof ActionToDoNode) {
    //      if (((ActionToDoNode) obj).isLeaf()
    //      && (((DefaultMutableTreeNode)obj).getUserObject() instanceof MechanicalAgent.MechanicalAgent)) {
    //        NodeMenu pmenu = new NodeMenu(this.viewer,
    //        (MechanicalAgent.MechanicalAgent) ((DefaultMutableTreeNode)obj).getUserObject(),
    //        this.languageSupport);
    //        pmenu.show(this,e.getX()+10, e.getY()+25);
    //      }
    //    }
    
    ((ActionToDoNode)obj).rightClick(this.getContentPane(),evt);
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    owner.getMyOwner().printlnLogFileOut("ManagerModuleUI::"+s);
  }
  
  /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
  public void printErrLog(String s){
    owner.getMyOwner().printlnLogFileErr("ManagerModuleUI::"+s);
  }
  
  public void LanguageChanged(LanguageChangeEvent evt) {
    refresh();
  }
  
  public void selectAndFocus() {
    this.hide();
    this.show();
  }
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JScrollPane jScrollPane;
  private javax.swing.JTree jTree;
  // End of variables declaration//GEN-END:variables
  
  private AdelfeMutableTreeNode treeNode;
  private Vector nodeList = new Vector();
  private AdelfeToolkitUI owner;
  private ManagerModule module;
  private DefaultTreeModel treeModel;
  private LanguageChangeSupport languageChangeSupport = null;
}
