/*
 * PrintableEditorPane.java
 *
 * Created on 10 juin 2003, 14:14
 */

package adelfeToolkit.gui;

import javax.swing.JTextPane;
import java.awt.print.Printable;
import java.awt.Graphics;
import java.awt.print.PageFormat;
import java.awt.print.PrinterException;
import java.awt.Graphics2D;
import java.awt.Color;



/**
 *
 * @author  IRIT - Toulouse (projet ADELFE)
 */
public class PrintableEditorPane extends JTextPane implements Printable {
  
  /** Creates a new instance of PrintableEditorPane */
  public PrintableEditorPane() {
    super();
  }
  
  /** Prints the page at the specified index into the specified
   * {@link Graphics} context in the specified
   * format.  A <code>PrinterJob</code> calls the
   * <code>Printable</code> interface to request that a page be
   * rendered into the context specified by
   * <code>graphics</code>.  The format of the page to be drawn is
   * specified by <code>pageFormat</code>.  The zero based index
   * of the requested page is specified by <code>pageIndex</code>.
   * If the requested page does not exist then this method returns
   * NO_SUCH_PAGE; otherwise PAGE_EXISTS is returned.
   * The <code>Graphics</code> class or subclass implements the
   * {@link PrinterGraphics} interface to provide additional
   * information.  If the <code>Printable</code> object
   * aborts the print job then it throws a {@link PrinterException}.
   * @param graphics the context into which the page is drawn
   * @param pageFormat the size and orientation of the page being drawn
   * @param pageIndex the zero based index of the page to be drawn
   * @return PAGE_EXISTS if the page is rendered successfully
   *         or NO_SUCH_PAGE if <code>pageIndex</code> specifies a
   * 	       non-existent page.
   * @exception java.awt.print.PrinterException
   *         thrown when the print job is terminated.
   *
   */
  public int print(Graphics graphics, PageFormat pageFormat, int pageIndex) throws PrinterException {
    //    Graphics2D g2 = (Graphics2D) graphics;
    //    g2.translate((int)pageFormat.getImageableX(), (int)pageFormat.getImageableY());
    //    g2.setClip(0, 0, (int)pageFormat.getImageableWidth(), (int)pageFormat.getImageableHeight());
    //    if (pageIndex == 0) setupPrintView(pageFormat);
    //    if (!pv.paintPage(g2, pageIndex)) return NO_SUCH_PAGE;
    //    return PAGE_EXISTS;
    Graphics2D g2 = (Graphics2D)graphics;
    g2.setColor(Color.black);    //set default foreground color to black
    
    javax.swing.RepaintManager.currentManager(this).setDoubleBufferingEnabled(false);
    java.awt.Dimension d = this.getSize();    //get size of document
    double panelWidth  = d.width;    //width in pixels
    double panelHeight = d.height;   //height in pixels
    double pageHeight = pageFormat.getImageableHeight();   //height of printer page
    double pageWidth  = pageFormat.getImageableWidth();    //width of printer page
    double scale = pageWidth/panelWidth;
    int totalNumPages = (int)Math.ceil(scale * panelHeight / pageHeight);
    
    //System.out.println("panelWidth="+panelWidth+" panelHeight="+panelHeight);
    //System.out.println("pageHeight="+pageHeight+" pageWidth="+pageWidth);
    //System.out.println("scale= "+scale+" totalNumPages="+totalNumPages);
    
    // Make sure not print empty pages
    if(pageIndex >= totalNumPages) {
      return Printable.NO_SUCH_PAGE;
    }
    // Shift Graphic to line up with beginning of print-imageable region
    g2.translate(pageFormat.getImageableX(), pageFormat.getImageableY());
    // Shift Graphic to line up with beginning of next page to print
    g2.translate(0f, -pageIndex*pageHeight);
    // Scale the page so the width fits...
    g2.scale(scale, scale);
    this.paint(g2);   //repaint the page for printing
//    int posPageX = (int)pageFormat.getWidth()/2;
//    int posPageY = (int)panelHeight;//(int)pageFormat.getImageableHeight();
//    g2.drawString("page "+(pageIndex+1), posPageX, posPageY);
    javax.swing.RepaintManager.currentManager(this).setDoubleBufferingEnabled(true);
    return Printable.PAGE_EXISTS;    
  }
  
  
//  public void setupPrintView(PageFormat pf) {
//    View root = this.getUI().getRootView(this);
//    pv = new PrintView(
//    getStyledDocument().getDefaultRootElement(),
//    root,
//    (int)pf.getImageableWidth(),
//    (int)pf.getImageableHeight());
//  }
  
}
