/*
 * SynthesisModuleUI.java
 *
 * Created on 3 dcembre 2002, 11:27
 */

package adelfeToolkit.gui;

import java.io.IOException;
import java.net.URL;

import adelfeToolkit.language.LanguageChangeEvent;
import adelfeToolkit.language.LanguageChangeListener;
import adelfeToolkit.language.LanguageChangeSupport;
import adelfeToolkit.modules.SynthesisModule;

/**
 *
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class SynthesisModuleUI extends javax.swing.JFrame implements adelfeToolkit.utilities.LogWriter, LanguageChangeListener, adelfeToolkit.print.PrintableComponentOwner {
  
  private AdelfeToolkitUI owner;
  
  private SynthesisModule module;
  
  private LanguageChangeSupport languageChangeSupport = null;
  
  /** Creates new form SynthesisModuleUI */
  public SynthesisModuleUI() {
    initComponents();
  }
  
  public SynthesisModuleUI(AdelfeToolkitUI mf, SynthesisModule mod) {
    owner = mf;
    module = mod;
    languageChangeSupport = owner.getLanguageChangeSupport();
    languageChangeSupport.addLanguageChangeListener(this);
    this.setVisible(false);
    initComponents();
    personalInitComponents();
    this.setIconImage(java.awt.Toolkit.getDefaultToolkit().getImage(getClass().getResource("/adelfeToolkit/gui/image/SMAC.gif")));
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    jPanel1 = new javax.swing.JPanel();
    jButton1 = new javax.swing.JButton();
    jScrollPane = new javax.swing.JScrollPane();

    setTitle(this.languageChangeSupport.getRessourceBundle().getString("Refresh"));
    addWindowListener(new java.awt.event.WindowAdapter() {
      public void windowClosing(java.awt.event.WindowEvent evt) {
        exitForm(evt);
      }
    });

    jButton1.setText("refresh");
    jButton1.addMouseListener(new java.awt.event.MouseAdapter() {
      public void mouseReleased(java.awt.event.MouseEvent evt) {
        jButton1MouseReleased(evt);
      }
    });

    jPanel1.add(jButton1);

    getContentPane().add(jPanel1, java.awt.BorderLayout.NORTH);

    getContentPane().add(jScrollPane, java.awt.BorderLayout.CENTER);

    java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
    setBounds((screenSize.width-400)/2, (screenSize.height-300)/2, 400, 300);
  }//GEN-END:initComponents

  private void jButton1MouseReleased(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_jButton1MouseReleased
    // Add your handling code here:
    this.refresh();
  }//GEN-LAST:event_jButton1MouseReleased
  
  private void personalInitComponents() {
    jEditorPane = new PrintableEditorPane();
    jEditorPane.setEditable(false);
    jEditorPane.addHyperlinkListener(new javax.swing.event.HyperlinkListener() {
      public void hyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
        jEditorPaneHyperlinkUpdate(evt);
      }
    });
    this.jButton1.setText(this.languageChangeSupport.getRessourceBundle().getString("Refresh"));
    jScrollPane.setViewportView(jEditorPane);
  }
  
  private void jEditorPaneHyperlinkUpdate(javax.swing.event.HyperlinkEvent evt) {
    
  }
  
  /** Exit the Application */
  private void exitForm(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_exitForm
    this.hide();
    owner.getSynthesisCheckBoxMenuItem().setState(false);
  }//GEN-LAST:event_exitForm
  
  private void displayURL(URL url) {
    try {
      if (jEditorPane != null) {
        personalInitComponents();
        jEditorPane.setPage(url);
        jEditorPane.repaint();
      }
      else {
      }
    } catch (IOException e) {
      displayError("Attempted to read a bad URL: " + url,"Description Module Error Occurred");
      printErrLog("displayURL::Attempted to read a bad URL: " + url);
      try {
        jEditorPane.setPage(getClass().getResource("/adelfeToolkit/resources/error.html"));
      } catch (Exception e2) {
        displayError("Could not display error URL","Description Module Error Occurred");
        printErrLog("displayURL::Could not display error URL");
      }
    }
  }
  
  private void displayError(String s, String m) {
    owner.displayError(s,m);
  }
  
  public void refresh() {
    adelfeToolkit.activities.Project p = owner.getMyOwner().getManagerModule().getCurrentProject();
    String dir = p.getDirectory().getFile()+p.getActionName()+"_OT";
    String filesep = System.getProperty("file.separator");
    java.io.File f = new java.io.File(dir+filesep+p.getActionName()+"_syn.html");
    String filePath = f.getAbsolutePath()+filesep;
    String fileName = p.getActionName();
    
    this.setTitle(this.languageChangeSupport.getRessourceBundle().getString("Synthesis"));
    this.jButton1.setText(this.languageChangeSupport.getRessourceBundle().getString("Refresh"));
    if (f.exists()) {
      try {
        displayURL(f.toURL());
      } catch (java.net.MalformedURLException e) {
      }
    } else {
    }
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    owner.getMyOwner().printlnLogFileOut("SynthesisModuleUI::"+s);
  }
  
  /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
  public void printErrLog(String s){
    owner.getMyOwner().printlnLogFileErr("SynthesisModuleUI::"+s);
  }
  
  public void LanguageChanged(LanguageChangeEvent evt) {
    refresh();
  }
  
  public javax.swing.JComponent componentToPrint() {
    return this.jEditorPane;
  }
  
  public java.awt.print.Printable getPrintableComponent() {
    return this.jEditorPane;
  }
  
  public void show() {
    this.refresh();
    super.show();
  }
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JButton jButton1;
  private javax.swing.JPanel jPanel1;
  private javax.swing.JScrollPane jScrollPane;
  // End of variables declaration//GEN-END:variables
  
  private PrintableEditorPane jEditorPane;
  
}
