/*
 * WorkProductModuleUI.java
 *
 * Created on 3 dcembre 2002, 11:30
 */

package adelfeToolkit.gui;

import adelfeToolkit.modules.WorkProductModule;
import adelfeToolkit.activities.Project;
import adelfeToolkit.activities.Activity;
import adelfeToolkit.activities.Step;
import adelfeToolkit.activities.WorkProduct;
import adelfeToolkit.activities.WorkProductList;
import java.util.Vector;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.JTree;
import javax.swing.tree.TreeSelectionModel;
import adelfeToolkit.language.*;
import adelfeToolkit.openTool.*;


/** An UI to represent a <CODE>WorkProductModule</CODE>
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class WorkProductModuleUI extends javax.swing.JInternalFrame implements adelfeToolkit.utilities.LogWriter, LanguageChangeListener, OpenToolMessageListener{
  
  /** Creates new form WorkProductModuleUI */
  public WorkProductModuleUI() {
    initComponents();
  }
  
  /** Creates new form WorkProductModuleUI
   * @param mf The <CODE>AdelfeToolkitUI</CODE> that owns the <CODE>WorkProductModuleUI</CODE>
   * @param mod The moduke represented by the UI
   */  
  public WorkProductModuleUI(AdelfeToolkitUI mf, WorkProductModule mod) {
    owner = mf;
    module = mod;
    languageChangeSupport = owner.getLanguageChangeSupport();
    languageChangeSupport.addLanguageChangeListener(this);
    initComponents();
    personalInitComponents();
  }
  
  /** This method is called from within the constructor to
   * initialize the form.
   * WARNING: Do NOT modify this code. The content of this method is
   * always regenerated by the Form Editor.
   */
  private void initComponents() {//GEN-BEGIN:initComponents
    jScrollPane = new javax.swing.JScrollPane();
    jTree = new javax.swing.JTree();

    setIconifiable(true);
    setMaximizable(true);
    setResizable(true);
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("WorkProduct"));
    jScrollPane.setViewportView(jTree);

    getContentPane().add(jScrollPane, java.awt.BorderLayout.CENTER);

    pack();
  }//GEN-END:initComponents
  
  private void personalInitComponents() {
    setTitle(this.languageChangeSupport.getRessourceBundle().getString("WorkProduct"));
    createNodes();
    createJTree();
  }
  
  private void createJTree() {
    jTree = new JTree(treeModel);
    jTree.setEditable(false);
    jTree.getSelectionModel().setSelectionMode(TreeSelectionModel.SINGLE_TREE_SELECTION);
    jTree.setShowsRootHandles(true) ;
    javax.swing.ToolTipManager.sharedInstance().registerComponent(jTree);
    jTree.setCellRenderer(new AdelfeTreeCellRenderer(this.owner));
    jTree.setLargeModel(true);
    jScrollPane.setViewportView(jTree);
  }
  
  private void createNodes() {
    ActionToDoNode treeNode;
    WorkProductList wpl = null;
    Project p = module.getOwner().getManagerModule().getCurrentProject();
    if (p.getCurrentIndex() >= 0) {
      Activity a = (Activity)p.getCurrentActivity();
      if (a.getCurrentIndex() >= 0) {
        Step s = (Step)a.getCurrentStep();
        treeNode = new ActionToDoNode(s,this.languageChangeSupport);
      }
      else {
        treeNode = new ActionToDoNode(a,this.languageChangeSupport);
      }
    }
    else {
      treeNode = new ActionToDoNode(p,this.languageChangeSupport);
    }    
    
    nodeList = new Vector();
    wpl = module.getCurrentWorkProductList();
    treeModel = new DefaultTreeModel(treeNode);
    
    for (int i=0;i<wpl.size();i++) {
      WorkProductNode node;
      WorkProduct wp = (WorkProduct)wpl.get(i);
      node = new WorkProductNode(wp,this.languageChangeSupport);
      createSubNodes(node,2);
      nodeList.add(node);
      treeNode.add(node);
    }
  }
  
  private void createSubNodes(AdelfeMutableTreeNode n, int depth) {
    WorkProductList wpl = ((WorkProduct)n.getUserObject()).getSubWorkProducts();
    if (wpl.size()>0) {
      int size = wpl.size();
      
      for (int i=0;i<size;i++) {
        WorkProductNode node;
        WorkProduct wp = (WorkProduct)wpl.get(i);
        node = new WorkProductNode(wp,this.languageChangeSupport);
        if (depth>0) {
          createSubNodes(node,depth-1);
        }
        n.add(node);
      }
    }
  }
  
  /** This method re-initalizes the <CODE>WorkProductModuleUI</CODE> */  
  public void refresh() {
    personalInitComponents();
    
  }
  
  /** this method prints message on the adelfe log file
   * @param s the message to print
   */  
  public void printOutLog(String s){
    owner.getMyOwner().printlnLogFileOut("WorkProductModuleUI::"+s);
  }
  
  /** this method prints error on the adelfe log file
   * @param s the message to print
   */  
  public void printErrLog(String s){
    owner.getMyOwner().printlnLogFileErr("WorkProductModuleUI::"+s);
  }
  
  /** This method is called when a <CODE>LanguageChange</CODE> event is received
   * @param evt the received event
   */  
  public void LanguageChanged(LanguageChangeEvent evt) {
    refresh();
  }  
  
  /** This methos is called when an <CODE>OpenToolMessageEvent</CODE> is received
   * @param evt the received event
   */  
  public void openToolMessageReceived(OpenToolMessageEvent evt) {
    
  }
  
  // Variables declaration - do not modify//GEN-BEGIN:variables
  private javax.swing.JScrollPane jScrollPane;
  private javax.swing.JTree jTree;
  // End of variables declaration//GEN-END:variables
  
  private AdelfeMutableTreeNode treeNode;
  private Vector nodeList = new Vector();
  private AdelfeToolkitUI owner;
  private WorkProductModule module;
  private DefaultTreeModel treeModel;
  private LanguageChangeSupport languageChangeSupport = null;
}
