/*
 * LanguageSupport.java
 *
 * Created on 12 fvrier 2003, 10:56
 */

package adelfeToolkit.language;

/** This class manages language changes : language files, listeners...
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class LanguageChangeSupport {
  
  /** the string that represents the english language */  
  public final static String ENGLISH = "english";
  
  /** the string that represents the french language */  
  public final static String FRENCH = "french";
  
  /** the string that represents the directory in which the language file are located */  
  public final static String DIRECTORY = "adelfeToolkit/language/";
  
  
  /** Holds value of property ressourceBundle. */
  private java.util.ResourceBundle ressourceBundle;
  /** the list of listeners */  
  private java.util.Vector listeners = new java.util.Vector(0);
  /** the string that represents the directory in which the language file are located */  
  private String languageDirectory = LanguageChangeSupport.DIRECTORY;
  
  /** Holds value of property language. */
  private String language = LanguageChangeSupport.ENGLISH;
  
  /** Creates new LanguageSupport
   * @param lg the initial language
   */
  public LanguageChangeSupport(String lg) {
    language = lg;
    languageDirectory = LanguageChangeSupport.DIRECTORY;
    this.ressourceBundle= java.util.ResourceBundle.getBundle(this.languageDirectory+this.language);
  }
  
  
  /** Getter for property ressourceBundle.
   * @return Value of property ressourceBundle.
   */
  public java.util.ResourceBundle getRessourceBundle() {
    return ressourceBundle;
  }
  
  /** Setter for property ressourceBundle.
   * @param ressourceBundle New value of property ressourceBundle.
   */
  public void setRessourceBundle(java.util.ResourceBundle ressourceBundle) {
    this.ressourceBundle = ressourceBundle;
    fireLanguageChange(new LanguageChangeEvent(this));
  }
  
  /** Getter for property language.
   * @return Value of property language.
   */
  public String getLanguage() {
    return language;
  }
  
  /** Setter for property language.
   * @param language New value of property language.
   */
  public void setLanguage(String language) {
    this.language = language;
    this.setRessourceBundle(java.util.ResourceBundle.getBundle(this.languageDirectory+this.language));
  }
  
  /** this method adds a new listener to the languageChangeListener list
   * @param listener the listener to add
   */  
  public void addLanguageChangeListener(LanguageChangeListener listener) {
    this.listeners.addElement(listener);
  }
  
  /** thsi method sends a languageChangeEvent to all the listeners appearing in the
   * listener list.
   * @param evt the event to send
   */  
  public void fireLanguageChange(LanguageChangeEvent evt) {
    int i;
    for(i=0;i<this.listeners.size();i++)
      ((LanguageChangeListener) this.listeners.get(i)).LanguageChanged(evt);
  }
  
  /** This method removes a listener of the languageChangeListener list
   * @param listener the listener to remove
   */  
  public void removeLanguageChangeListener(LanguageChangeListener listener) {
    this.listeners.removeElement(listener);
  }
}