/*
 * MabagerModule.java
 *
 * Created on 2 dcembre 2002, 10:16
 */

package adelfeToolkit.modules;

import adelfeToolkit.AdelfeToolkit;
import adelfeToolkit.gui.*;
import adelfeToolkit.activities.*;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.FileOutputStream;
import java.io.Serializable;
import java.net.URL;
import adelfeToolkit.utilities.*;

/** The class that manage the different projects of the user.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class ManagerModule 
implements Serializable, 
adelfeToolkit.utilities.LogWriter,
adelfeToolkit.modules.ActionExitedHandler
{
  
  // Constants :
  
  /** This constant represents the extension taht appears at the end of adelfe project files
   * names.
   */
  public final static String ADELFE_EXTENSION = "."+ExtensionGetter.dlf;
  
  /** a constant that encode the failure during a save process. */
  public final int SAVE_FILE_FAILURE = 1;
  
  /** a constant that encode the failure during a save process. */
  public final int SAVE_FILE_SUCCESS = 0;
  
  // Fields :
  
  /** The GUI that represents the <CODE>ManagerModule</CODE>. */
  private ManagerModuleUI uI;
  
  /** The <CODE>AdelfeToolkit</CODE> that owns the <CODE>ManagerModule</CODE>. */
  private AdelfeToolkit owner;
  
  /** The <CODE>java.io.String</CODE> that represents a new line. */
  private String newline = System.getProperty("line.separator");
  
  /** The name of the current project. */
  private String projectName = "Project";
  
  //private boolean alreadySaved = false;
  
  /** The <CODE>URL</CODE> to the file to save the current project. */
  private URL fileToSaveTo;
  
  /** The <CODE>URL</CODE> to the file to open as a default file. */
  private URL defaultFile = getClass().getResource("/adelfeToolkit/resources/defaultProject"+ADELFE_EXTENSION);
  
  /** The <CODE>URL</CODE> to the current directory. */
  private URL directory;
  
  /** The <CODE>URL</CODE> to the last open file. */
  private URL lastWorkingOnFile;
  
  /** the URL to the initial file */  
  private URL initFile;
  
  /** a counter */  
  private int newProjectCounter = 0;
  
  /** the save number of the current project */  
  private int saveNumber;
  
  /** the list of projects */  
  private ProjectList projectList = new ProjectList();
  
  /** the cruurent working on project */  
  private Project currentProject;
  
  /** the default project */  
  private Project defaultProject = new Project();
  
  /** the <CODE>ActionExitedListener</CODE> list */  
  private java.util.Vector listeners = new java.util.Vector(0); 
  
  /** Creates a new instance of ManagerModule */
  public ManagerModule() {
  }
  
  /** Creates a new instance of ManagerModule that is owned by own.
   * @param own the AdelfeToolkit that uses the ManagerModule.
   */
  public ManagerModule(AdelfeToolkit own) {
    owner = own;
    try {
      directory = (new java.io.File(owner.getProjectDirectory())).toURL();
      printOutLog("ManagerModule::current directory set to "+directory.toString());
    }
    catch (java.net.MalformedURLException e) {
      printErrLog("ManagerModule::java.net.MalformedURLException");
    }
  }
  
  /** This method initializes the list of activities corresponding to the current
   * project to display the several topics in th different modules.
   */
  public void initializeActivities() {
    lookingForLastWorkingOnFile(lastWorkingOnFile);
    openProject(lastWorkingOnFile);
    printOutLog("initializeActivities::Activities Initalization done");
  }
  
  /**
   * @param file
   */  
  private void lookingForLastWorkingOnFile(URL file) {
    if (initFile != null) {
      try {
        ObjectInputStream ois = new ObjectInputStream(initFile.openStream());
        lastWorkingOnFile = (URL)ois.readObject();
        printOutLog("lookingForLastWorkingOnFile::File "+lastWorkingOnFile.getFile()+" opened...OK");
      }
      catch (java.io.FileNotFoundException e) {
        printErrLog("lookingForLastWorkingOnFile::File "+lastWorkingOnFile.getFile()+" Not Found.");
      }
      catch (java.io.IOException e) {
        printErrLog("lookingForLastWorkingOnFile::IO exception.");
      }
      catch (java.lang.ClassNotFoundException e) {
        printErrLog("lookingForLastWorkingOnFile::Class not found.");
      }
    }
  }
  
  private void openProject(URL file) {
    
    if (file == null) {
      newProject();
      return;
    }
    
    printOutLog("openProject::Opening file..."+file.getFile());
    try {
      ObjectInputStream ois = new ObjectInputStream(file.openStream());
      Project p = (Project)ois.readObject();
      
      setCurrentProject(p);
      System.out.println(p.getActionName());
      projectList.addProject(currentProject);
      projectList.displayList();
      if (file != defaultFile) {
        setFileToSaveTo(file);
        //setAlreadySaved(true);
        setSaveNumber(1);
      }
      else {
        //setAlreadySaved(false);
        setSaveNumber(0);
      }
      setDirectory(currentProject.getDirectory());
      ois.close();
      printOutLog("openProject::File "+file+" opened...OK");
    }
    catch (java.io.FileNotFoundException e) {
      printErrLog("openProject::File "+file+" Not Found.");
    }
    catch (java.io.IOException e) {
      printErrLog("openProject::IO exception.");
    }
    catch (java.lang.ClassNotFoundException e) {
      printErrLog("openProject::Class not found.");
    }
  }
  
  /** This method opens the file that is at the url <CODE>file</CODE>.
   * @param file The url to the file to open.
   */
  public void openFile(URL file) {
    openProject(file);
  }
  
  private int saveProject(URL file) {
    printOutLog("saveProject::Saving file...");
    if (file != null) {
      try {
        FileOutputStream fos = new FileOutputStream(file.getFile());
        ObjectOutputStream oos = new ObjectOutputStream(fos);
        String filesep = System.getProperty("file.separator");
        
        setFileToSaveTo(file);
        currentProject.setActionName(URLManipulator.removeExtension(URLManipulator.convertURLToFileName(file)));
        setDirectory(URLManipulator.extractPathFromURL(file));
        
        setSaveNumber(getSaveNumber()+1);
        oos.writeObject(currentProject);
        oos.close();
        printOutLog("saveProject::File saved.");
        return SAVE_FILE_SUCCESS;
      }
      catch (java.io.FileNotFoundException e) {
        printErrLog("saveFile::File not found.");
        printOutLog("saveProject::File not saved.");
        return SAVE_FILE_FAILURE;
      }
      catch (java.io.IOException e) {
        printErrLog("saveFile::IO exception");
        printOutLog("saveProject::File not saved.");
        return SAVE_FILE_FAILURE;
      }
    }
    else {
      return SAVE_FILE_FAILURE;
    }
  }
  
  /** This method saves the file to the url <CODE>file</CODE>.
   * @param file The url to the file to save to.
   * @return <CODE>SAVE_FILE_SUCCESS</CODE> if the save process is sucessful or <CODE>SAVE_FILE_FAILURE</CODE> if the save process fails, because of a <CODE>java.io.FileNotFoundException</CODE>
   * or a <CODE>java.io.IOException</CODE> or if the <CODE>file</CODE> url is
   * eroneous.
   */
  public int saveFile(URL file) {
    return saveProject(file);
  }
  
  public void saveAllFiles() {
  }
  
  private void newProject() {
    URL file = defaultFile;
    
    newProjectCounter++;
    
    printOutLog("newProject::New file...from "+file);
    try {
      ObjectInputStream ois = new ObjectInputStream(file.openStream());
      Project p = (Project)ois.readObject();
      
      setCurrentProject(p);
      currentProject.setActionName(currentProject.getActionName()+newProjectCounter);
      setDirectory(directory);
      setSaveNumber(0);
      setCurrentActionToDo(p);
      
      String dir = getDirectory().getFile();
      java.io.File fil = new java.io.File(dir.substring(0,dir.length()-2)+URLManipulator.removeExtension(currentProject.getActionName())+ADELFE_EXTENSION);
      
      setFileToSaveTo(fil.toURL());
      projectList.addProject(currentProject);
      printOutLog("newProject::File "+file+" opened...OK");
    }
    catch (java.io.FileNotFoundException e) {
      printErrLog("newProject::File "+file+" Not Found.");
    }
    catch (java.io.IOException e) {
      printErrLog("newProject::IO exception.");
    }
    catch (java.lang.ClassNotFoundException e) {
      printErrLog("newProject::Class not found.");
    }
  }
  
  public void newFile() {
    newProject();
  }
  
  private void closeProject() {
    projectList.remove(currentProject);
    printOutLog("closeProject::Current Project Closed.");
    if (projectList.size() == 0) {
      newProject();
    }
    else {
      setCurrentProject((Project)projectList.get(0));
      setDirectory(currentProject.getDirectory());
      setFileToSaveTo(currentProject.getFileToSaveTo());
    }
  }
  
  public void closeFile() {
    closeProject();
  }
  
  public void selectProject(String p) {
    Project proj = projectList.getProjectByName(p);
    
    //projectList.removeElement(proj);
    //projectList.addProject(proj);
    
    setCurrentProject(proj);
    setSaveNumber(proj.getSaveNumber());
    printOutLog("selectProject::Project "+proj.toString()+" selected.");
  }
  
  /** Getter for property currentProject.
   * @return Value of property currentProject.
   *
   */
  public Project getCurrentProject() {
    return currentProject;
  }
  
  /** Setter for property currentProject.
   * @param currentProject New value of property currentProject.
   *
   */
  public void setCurrentProject(Project currentProject) {
    this.currentProject = currentProject;
  }
  
  /** Getter for property defaultFile.
   * @return Value of property defaultFile.
   *
   */
  public java.net.URL getDefaultFile() {
    return defaultFile;
  }
  
  /** Setter for property defaultFile.
   * @param defaultFile New value of property defaultFile.
   *
   */
  public void setDefaultFile(java.net.URL defaultFile) {
    this.defaultFile = defaultFile;
  }
  
  /** Getter for property directory.
   * @return Value of property directory.
   *
   */
  public java.net.URL getDirectory() {
    return directory;
  }
  
  /** Setter for property directory.
   * @param directory New value of property directory.
   *
   */
  public void setDirectory(java.net.URL directory) {
    this.directory = directory;
    currentProject.setDirectory(directory);
  }
  
  /** Getter for property fileToSaveTo.
   * @return Value of property fileToSaveTo.
   *
   */
  public java.net.URL getFileToSaveTo() {
    return fileToSaveTo;
  }
  
  /** Setter for property fileToSaveTo.
   * @param fileToSaveTo New value of property fileToSaveTo.
   *
   */
  public void setFileToSaveTo(java.net.URL fileToSaveTo) {
    this.fileToSaveTo = fileToSaveTo;
    currentProject.setFileToSaveTo(fileToSaveTo);
  }
  
  /** Getter for property projectList.
   * @return Value of property projectList.
   *
   */
  public ProjectList getProjectList() {
    return projectList;
  }
  
  /** Setter for property projectList.
   * @param projectList New value of property projectList.
   *
   */
  public void setProjectList(ProjectList projectList) {
    this.projectList = projectList;
  }
  
  /** Getter for property saveNumber.
   * @return Value of property saveNumber.
   *
   */
  public int getSaveNumber() {
    return saveNumber;
  }
  
  /** Setter for property saveNumber.
   * @param saveNumber New value of property saveNumber.
   *
   */
  public void setSaveNumber(int saveNumber) {
    this.saveNumber = saveNumber;
    currentProject.setSaveNumber(saveNumber);
  }
  
  /** Getter for property uI.
   * @return Value of property uI.
   *
   */
  public ManagerModuleUI getUI() {
    return uI;
  }
  
  /** Setter for property uI.
   * @param uI New value of property uI.
   *
   */
  public void setUI(ManagerModuleUI uI) {
    this.uI = uI;
  }
  
  public void setCurrentActionToDo(ActionToDo actionToDo) {
    this.fireActionExitedReceived(new ActionExitedEvent(currentProject.getCurrentActivity()));
    currentProject.setCurrentActionToDo(actionToDo);
    owner.getDescriptionModule().setCurrentDescription(actionToDo.getDescription());
    owner.getExampleModule().setCurrentExample(actionToDo.getExample());
    owner.getWorkProductModule().setCurrentWorkProductList(actionToDo.getWorkProducts());
  }
  
  public ActionToDo getActionToDoForIndexes(int actNum, int stpNum) {
    ActionToDo act = (ActionToDo)(this.currentProject.getActivityList().elementAt(actNum-1));
    if (stpNum<1) {
      return act;
    }
    else {
      return (ActionToDo)(((Activity)act).getSteps().elementAt(stpNum-1));
    }
  }
  
  public void setActCompl(String actName, boolean comp) {
    for (int i =0;i<this.owner.getManagerModule().getCurrentProject().getActivityList().size();i++) {
      ((Activity)this.owner.getManagerModule().getCurrentProject().getActivityList().get(i)).setCompl(actName, comp);
    }
  }
  
  public void setActAcces(String wpName, boolean acces) {
    for (int i =0;i<this.owner.getManagerModule().getCurrentProject().getActivityList().size();i++) {
      ((Activity)this.owner.getManagerModule().getCurrentProject().getActivityList().get(i)).setAcces(wpName, acces);
    }
  }
  
  /** Getter for property owner.
   * @return Value of property owner.
   *
   */
  public adelfeToolkit.AdelfeToolkit getOwner() {
    return owner;
  }
  
  /** Setter for property owner.
   * @param owner New value of property owner.
   *
   */
  public void setOwner(adelfeToolkit.AdelfeToolkit owner) {
    this.owner = owner;
  }
  
  public void printErrLog(String s) {
    owner.printlnLogFileErr("ManagerModule::"+s);
  }
  
  public void printOutLog(String s) {
    owner.printlnLogFileOut("ManagerModule::"+s);
  }
  
  public void addActionExitedListener(ActionExitedListener listener) {
    this.listeners.addElement(listener);
  }
  
  public void fireActionExitedReceived(ActionExitedEvent evt) {
    int i;
    for(i=0;i<this.listeners.size();i++)
      ((ActionExitedListener) this.listeners.get(i)).actionExited(evt);
  }
  
  public void removeActionExitedListener(ActionExitedListener listener) {
    this.listeners.removeElement(listener);
  }
}
