/*
 * LogMessageParser.java
 *
 * Created on 1 juillet 2003, 14:57
 */

package adelfeToolkit.openTool;

/** This class contains static methods to parse lines of the OT log files
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class LogMessageParser {
  
  /** Creates a new instance of <CODE>LogMessageParser</CODE> */
  public LogMessageParser() {
  }
  
  /** This method gets the index of the first bracket character ('[') of a given line
   * @param m the message to analyze
   * @return the index of the first bracket ('[') character, -1 if it does not appears
   */  
  private static int getFirstBracketIndex(String m) {
    return m.indexOf('[');
  }
  
  /** This method gets the index of the last bracket character (']') of a given line
   * @param m the message to analyze
   * @return the index of the last bracket character (']') of a given linev
   */  
  private static int getLastBracketIndex(String m) {
    return m.lastIndexOf(']');
  }
  
  /** This method gets the index of the second space character (' ') of a given line
   * @param m the message to parse
   * @return the index of the second space character (' ') of a given line, -1 if it does not appears
   */  
  private static int getSecondSpaceIndex(String m) {
    return m.indexOf(' ',getFirstBracketIndex(m));
  }
  
  /** This method gets the index of the third space character (' ') of a given line
   * @param m the message to parse
   * @return the index of the third space character (' ') of a given line, -1 if it does not appears
   */  
  private static int getThirdSpaceIndex(String m) {
    return m.indexOf(' ',getSecondSpaceIndex(m)+1);
  }
  
  /** This method gets the index of the first double quote character ('"') of a given line
   * @param m the message to parse
   * @return the index of the first double quote character ('"') of a given line, -1 if it does not appears
   */  
  private static int getFirstDoubleQuoteIndex(String m) {
    return m.indexOf('"');
  }
  
  /** This method gets the index of the last double quote character ('"') of a given line
   * @param m the message to parse
   * @return index of the first double quote character ('"') of a given line, -1 if it does not appears
   */  
  private static int getLastDoubleQuoteIndex(String m) {
    return m.lastIndexOf('"');
  }
  
  /** This method extracts the date of the message
   * @param message the message to parse
   * @return the String representing the date of the message
   */  
  public static String extractDate(String message) {
    char c = message.charAt(0);
    if ((c <= '9') && (c >= '0')) {
      if (getFirstBracketIndex(message) == -1) {
        return "";
      } else {
        return message.substring(0,getFirstBracketIndex(message)-1);
      }
    }
    else {
      return "";
    }
  }
  
  /** This method extracts the type of the source of the message
   * @param message the message to parse
   * @return the String representing the type of the source of the message
   */  
  public static String extractSourceType(String message) {
    char c = message.charAt(0);
    if ((c <= '9') && (c >= '0')) {
      if (getFirstBracketIndex(message) == -1) {
        return "";
      } else if (getSecondSpaceIndex(message) == -1) {
        return "";
      } else {
        return message.substring(getFirstBracketIndex(message)+1,getSecondSpaceIndex(message));
      }
    }
    else {
      return "";
    }
  }
  
  /** This method extracts the name of the source of the message
   * @param message the message to parse
   * @return the String representing the name of the source of the message
   */  
  public static String extractSourceName(String message) {
    char c = message.charAt(0);
    if ((c <= '9') && (c >= '0')) {
      if (getSecondSpaceIndex(message) == -1) {
        return "";
      } else if (getThirdSpaceIndex(message) == -1) {
        return "";
      } else {
      return message.substring(getSecondSpaceIndex(message)+1,getThirdSpaceIndex(message));
      }
    }
    else {
      return "";
    }
  }
  
  /** This method extracts the action indicated by the message
   * @param message the message to parse
   * @return the String that represents the action indicated by the message
   */  
  public static String extractAction(String message) {
    char c = message.charAt(0);
    if ((c <= '9') && (c >= '0')) {
      if (getLastBracketIndex(message) == -1) {
        return "";
      } else {
      return message.substring(getLastBracketIndex(message)+2,message.length());
      }
    }
    else {
      return "";
    }
  }
}
