/*
 * OTMessageSender.java
 *
 * Created on 30 juin 2003, 14:30
 */

package adelfeToolkit.openTool;

/** This class is usd by <CODE>AdelfeToolkitUI</CODE> to send message to OpenTool thanks to an
 * <CODE>OpenToolConnector</CODE>
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class OTMessageSender implements adelfeToolkit.utilities.LogWriter {
  
  /** The <CODE>AdelfeToolkitUI</CODE> that owns the sender */  
  private adelfeToolkit.gui.AdelfeToolkitUI owner;
  
  /** Creates a new instance of O<CODE>TMessageSender</CODE>
   * @param o the owner
   */
  public OTMessageSender(adelfeToolkit.gui.AdelfeToolkitUI o) {
    owner = o;
  }
  
  /** the method send a given message to OT thanks to an <CODE>OpenToolConnector</CODE>
   * @param c the message to send
   */  
  public void sendCommandToOpenTool(String c) {
    try {
      owner.getMyOwner().getOpenToolConnector().send(c);
    }
    catch (java.io.IOException e){
      if (owner.getMyOwner().isOpenToolRunning()){
        owner.getMyOwner().setOpenToolRunning(false);
        try {
          owner.getMyOwner().getOpenToolConnector().initSocket();
          owner.getMyOwner().getOpenToolConnector().send(c);
        }
        catch(java.io.IOException e2) {
          displayError("Not able to write on OpenTool Socket. May be OpenTool is closed : try to open it.","IOException");
          printErrLog("sendCommandToOpenTool::Not able to write on OpenTool Socket...");
        }
      }
      else {
        displayError("Not able to write on OpenTool Socket. May be OpenTool is closed : try to open it.","IOException");
        printErrLog("sendCommandToOpenTool::Not able to write on OpenTool Socket...");
        owner.getMyOwner().setOpenToolRunning(false);
      }
    }
  }
  
  /** this method display an error dialog box
   * @param s the title of the error
   * @param m the message of the error
   * @see LogWriter
   */  
  private void displayError(String s, String m) {
    owner.displayError(s,m);
  }
  
  /** this method prints an eror in the log file
   * @param s the string to print
   * @see LogWriter
   */  
  public void printErrLog(String s) {
    owner.getMyOwner().printlnLogFileErr("OTMessageSender::"+s);
  }
  
  /** this method prints an message in the log file
   * @param s the String to print
   * @see LogWriter
   */  
  public void printOutLog(String s) {
    owner.getMyOwner().printlnLogFileOut("OTMessageSender::"+s);
  }
  
}
