/*
 * OpenToolReaderThread.java
 *
 * Created on 18 juin 2003, 09:58
 */

package adelfeToolkit.openTool;

import java.io.*;

/** This class is used to read in the OT socket
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class OpenToolSocketReader extends Thread implements Runnable, OpenToolMessageHandler{
  
  /** the input strem to read in */  
  private InputStreamReader br;
  
  /** the endline character */  
  private static char el = '\014';
  
  /** the <CODE>OpenToolMessageListener</CODE> list */  
  private java.util.Vector listeners = new java.util.Vector(0);
  
  /** Creates a new instance of OpenToolReaderThread
   * @param br the buffered reader to read in
   */
  public OpenToolSocketReader(InputStreamReader br) {
    setBr(br);
  }
  
  /** this method read a line in the socket and send an <CODE>OpenToolMessageEvent</CODE>
   * to the listeners
   */  
  public void run() {
    String s;
    while (true) {
      s = readLine();
      fireOpenToolMessageReceived(new OpenToolMessageEvent(this,s));
    }
  }
  
  /** This method reads characters in the stream until it finds the endline character
   * @return the readen lie
   */  
  private String readLine() {
    int c = 0;
    String res = "";
    while (c != el) {
      try {
        c = br.read();
        if (c != el) {
          res = res + (char)c;
        }
      } catch (IOException e) {
      }
    }
    return res;
  }
  
  /** Getter for property br.
   * @return Value of property br.
   *
   */
  public InputStreamReader getBr() {
    return br;
  }
  
  /** Setter for property br.
   * @param br New value of property br.
   *
   */
  public void setBr(InputStreamReader br) {
    this.br = br;
  }
  
  /** adds a <CODE>OpenToolMessageListener</CODE> to the list
   * @param listener the listener to add
   * @see OpenToolMessageHandler
   */  
  public void addOpenToolMessageListener(OpenToolMessageListener listener) {
    this.listeners.addElement(listener);
  }
  
  /** send an <CODE>OpenToolMessageEvent</CODE> to all the listeners
   * @param evt the event to send
   */  
  public void fireOpenToolMessageReceived(OpenToolMessageEvent evt) {
    int i;
    for(i=0;i<this.listeners.size();i++)
      ((OpenToolMessageListener) this.listeners.get(i)).openToolMessageReceived(evt);
  }
  
  /** removes a listener to the list
   * @param listener the listener to remove
   */  
  public void removeOpenToolMessageListener(OpenToolMessageListener listener) {
    this.listeners.removeElement(listener);
  }
  
}
