/*
 * Shortcut.java
 *
 * Created on 25 fvrier 2003, 10:43
 */

package adelfeToolkit.shortcuts;

import java.io.Serializable;

/** A Shortcut is a command that is represented by a textual command (shell for
 * example) and an icon for a button for example.
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class Shortcut implements Serializable {
  
  /** the name of the shortcut */
  private String name;
  
  /** the string that represents the URL of the icon of the shorcut */
  private String iconUrl;
  
  /** the name of the current project */  
  private String projectName = "";
  
  /** the type of the shortcut */  
  private int type;
  
  /** the OpenToolBatchCommand type */  
  static public int OPEN_TOOL_BATCH_COMMAND = 0;
  
  /** the Shell Command type */  
  static public int SHELL_COMMAND = 1;
  
  /** the Java Executable type */  
  static public int JAVA_EXECUTABLE = 2;
  
  /** the Drawing Tool Command type */  
  static public int DRAWING_TOOL_COMMAND = 3;
  
  /** the Text Editor Command type */  
  static public int TEXT_EDITOR_COMMAND = 4;
  
  /** the Adequacy Tool Command type */  
  static public int ADEQUACY_TOOL_COMMAND = 5;
  
  /** the Adobe Acrobat Redaer type */
  static public int ACROBAT_COMMAND = 6;
  
  /** the NCS Template type */
  static public int NCS_TEMPLATE_COMMAND = 7;

  /** the requirements Template type */
  static public int REQUIREMENTS_TEMPLATE_COMMAND = 8;
  
  /** the path of the command */  
  private String path = "";
  
  /** Creates a new instance of Shortcut */
  public Shortcut() {
  }
  
  /** Creates a new instance of Shortcut
   * @param projectName the name of the project
   * @param type the type of the command
   * @param name initial value for name field
   * @param command initial value for command field
   * @param url initial value for url field
   */
  public Shortcut(String name, String command, String url, String projectName, int type) {
    setName(name);
    setIconUrl(url);
    setProjectName(projectName);
    setType(type);
  }
  
  /** Getter for property name.
   * @return Value of property name.
   *
   */
  public java.lang.String getName() {
    return name;
  }
  
  /** Setter for property name.
   * @param name New value of property name.
   *
   */
  public void setName(java.lang.String name) {
    this.name = name;
  }
  
  /** Getter for property iconUrl.
   * @return Value of property iconUrl.
   *
   */
  public String getIconUrl() {
    return iconUrl;
  }
  
  /** Setter for property iconUrl.
   * @param iconUrl New value of property iconUrl.
   *
   */
  public void setIconUrl(String iconUrl) {
    this.iconUrl = iconUrl;
  }
  
  /** Getter for property projectName.
   * @return Value of property projectName.
   *
   */
  public java.lang.String getProjectName() {
    return projectName;
  }
  
  /** Setter for property projectName.
   * @param projectName New value of property projectName.
   *
   */
  public void setProjectName(java.lang.String projectName) {
    this.projectName = projectName;
  }
  
  /** Getter for property type.
   * @return Value of property type.
   *
   */
  public int getType() {
    return type;
  }
  
  /** Setter for property type.
   * @param type New value of property type.
   *
   */
  public void setType(int type) {
    this.type = type;
  }
  
  /** Getter for property path.
   * @return Value of property path.
   *
   */
  public java.lang.String getPath() {
    return path;
  }
  
  /** Setter for property path.
   * @param path New value of property path.
   *
   */
  public void setPath(java.lang.String path) {
    this.path = path;
  }
  
}
