/*
 * Confirmer.java
 *
 * Created on 5 juin 2003, 16:48
 */

package adelfeToolkit.utilities;

import javax.swing.JOptionPane;
import adelfeToolkit.language.*;

/** This class regroups method to dialog via JOptionPane
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class Confirmer {
  
  /** value for the NO option */  
  public static final int NO_OPTION = JOptionPane.NO_OPTION;
  /** value for the YES option */  
  public static final int YES_OPTION = JOptionPane.YES_OPTION;
  /** value for the CANCEL option */  
  public static final int CANCEL_OPTION = JOptionPane.CANCEL_OPTION;
  
  
  /** This method requests confirmation by opening a JOptionPane, with YES, NO or
   * CANCEL options, linked to the given Component. Texts in the request are found thanks to a LanguageChangeSupport
   * @param o The Component that wil own the JOpntionPane
   * @param lcs The LanguageChangeSupport that manages the language changes.
   * @return the user's answer
   */  
  public static int confirm(java.awt.Component o, LanguageChangeSupport lcs) {
    JOptionPane pane = new JOptionPane();
    Object[] options = {lcs.getRessourceBundle().getString("Yes"),lcs.getRessourceBundle().getString("No"),lcs.getRessourceBundle().getString("Cancel")};
    int n = JOptionPane.showOptionDialog(o,
    lcs.getRessourceBundle().getString("ConfirmText"),
    lcs.getRessourceBundle().getString("Confirm"),
    JOptionPane.YES_NO_CANCEL_OPTION,
    JOptionPane.QUESTION_MESSAGE,
    null,
    options,
    options[2]);
    return n;
  }
  
  /** This method requests confirmation by opening a JOptionPane, with YES, NO and
   * CANCEL options, linked to the given Component. Texts in the request are found thanks to a LanguageChangeSupport and
   * given has parameters.
   * @param o The component taht will own the JOptionPane
   * @param lcs the LanguageChangeSupport that manages the language changes
   * @param conf The title to display
   * @param confText the text to display
   * @return the user's answer
   */  
  public static int confirm(java.awt.Component o, LanguageChangeSupport lcs, String conf, String confText) {
    JOptionPane pane = new JOptionPane();
    Object[] options = {lcs.getRessourceBundle().getString("Yes"),lcs.getRessourceBundle().getString("No"),lcs.getRessourceBundle().getString("Cancel")};
    int n = JOptionPane.showOptionDialog(o,
    confText,
    conf,
    JOptionPane.YES_NO_CANCEL_OPTION,
    JOptionPane.QUESTION_MESSAGE,
    null,
    options,
    options[2]);
    return n;
  }
  
  /** This method requests confirmation by opening a JOptionPane, with YES and NO options, linked to the given Component. Texts in the request are found thanks to a LanguageChangeSupport
   * @param o the Component that owns the JOptionPane
   * @param lcs the LanguageChangeSupport that manages the language changes
   * @return the user's answer
   */  
  public static int confirmYesNo(java.awt.Component o, LanguageChangeSupport lcs) {
    JOptionPane pane = new JOptionPane();
    Object[] options = {lcs.getRessourceBundle().getString("Yes"),lcs.getRessourceBundle().getString("No")};
    int n = JOptionPane.showOptionDialog(o,
    lcs.getRessourceBundle().getString("ConfirmText"),
    lcs.getRessourceBundle().getString("Confirm"),
    JOptionPane.YES_NO_OPTION,
    JOptionPane.QUESTION_MESSAGE,
    null,
    options,
    options[1]);
    return n;
  }
  
  /** This method requests confirmation by opening a JOptionPane, with YES and NO options, linked to the given Component. Texts in the request are found thanks to a LanguageChangeSupport and
   * given has parameters.
   * @param o The component taht will own the JOptionPane
   * @param lcs the LanguageChangeSupport that manages the language changes
   * @param conf The title to display
   * @param confText the text to display
   * @return the text to display
   */  
  public static int confirmYesNo(java.awt.Component o, LanguageChangeSupport lcs, String conf, String confText) {
    JOptionPane pane = new JOptionPane();
    Object[] options = {lcs.getRessourceBundle().getString("Yes"),lcs.getRessourceBundle().getString("No")};
    int n = JOptionPane.showOptionDialog(o,
    confText,
    conf,
    JOptionPane.YES_NO_OPTION,
    JOptionPane.QUESTION_MESSAGE,
    null,
    options,
    options[1]);
    return n;
  }
}
