/*
 * URLToFileConverter.java
 *
 * Created on 4 mars 2003, 14:17
 */

package adelfeToolkit.utilities;

import java.net.MalformedURLException;
import java.net.URL;

/** This class regroups static methods to manipulate URLs
 * @author IRIT - Toulouse (projet ADELFE)
 */
public class URLManipulator {
  
  /** This method convert a URL into a String
   * @param url the URL to manipulate
   * @return the String that represents the URL
   */  
  public static String convertURLToFileName(URL url) {
    java.io.File f = new java.io.File(url.getFile());
    String fName = f.getName();
    return fName.substring(0,(fName.length()));
  }
  
  /** This method extracts the path without the file name of the given URL
   * @param url the URL to manipulate
   * @return the string that represents the URL without the file name
   */  
  public static URL extractPathFromURL(URL url) {
    java.io.File f = new java.io.File(url.getFile());
    String filesep = System.getProperty("file.separator");
    String pName = f.getAbsolutePath();
    int pos = pName.lastIndexOf(filesep);
    
    f = new java.io.File(f.toString().substring(0,pos));
    
    try {
      return f.toURL();
    }
    catch (java.net.MalformedURLException e) {
      return url;
    }
  }
  
  public static URL changeURLLanguage(URL url, String l1) {
	String sUrl = url.toString();
	int pos = sUrl.lastIndexOf("resources/");
	int t = l1.length();
	int pos2 = sUrl.indexOf("/",pos+10);
	String sUrl2 = sUrl.substring(0,pos+10)+l1+sUrl.substring(pos2,sUrl.length());
	URL rurl = null;
  	try {
		rurl = new URL(sUrl2);
	} catch (MalformedURLException e) {
		// TODO Auto-generated catch block
		e.printStackTrace();
	}
	return rurl;
  }
  
  public static String extractFileNameFromURL(URL url) {
	java.io.File f = new java.io.File(url.getFile());
		String filesep = System.getProperty("file.separator");
		String pName = f.getAbsolutePath();
		int pos = pName.lastIndexOf(filesep);
    	return f.toString().substring(pos+1,f.toString().length());
  }
  
  /** This method removes the extension of a given file represented by a String
   * @param fileName the name of the file to manipulate
   * @return the name of the file without extension
   */  
  public static String removeExtension(String fileName) {
    int i = fileName.lastIndexOf('.');
    if (i>0 & i<fileName.length()-1) {
      return fileName.substring(0,i);
    }
    else {
      return fileName;
    }
  }
  
  /** This method extracts the number of the Activity represented by the given URL.
   * The URL must have a well-formed file name : ActXX.XXX
   * @return the number of the activity if the URL is well formed, else it returns 0
   * @param url the URL to manipulate
   */  
  public static int getActivityNumber(URL url) {
    String type = getURLType(url);
    int result = 0;
    
    if (type.equals("Act")) {
      result = new Integer(convertURLToFileName(url).substring(3,5)).intValue();
    }
    else if (type.equals("Stp")) {
      result = new Integer(convertURLToFileName(url).substring(8,10)).intValue();
    }
    return result;
  }
  
  /** This method extracts the number of the Step represented by the given URL.
   * The URL must have a well-formed file name : StpXXActXX.html
   * @param url the URL to manipulate
   * @return the number of the Step if the URL is well formed, else it returns 0
   */  
  public static int getStepNumber(URL url) {
    String type = getURLType(url);
    int result = 0;
    
    if (type.equals("Stp")) {
      result = new Integer(convertURLToFileName(url).substring(3,5)).intValue();
    }
    return result;
  }
  
  /** This method return the type of the URL, i.e. the 3 first characters of the file
   * name.
   * @param url the URL to manipulate
   * @return the 3 first characters of the file name
   */  
  public static String getURLType(URL url) {
    String s = convertURLToFileName(url);
    return s.substring(0,3);
  }
  
  /** this method extracts the extension of the file represented by the URL
   * @param url the URL to manipulate
   * @return the extension of the URL
   */  
  public static String getExtension(URL url) {
    String ext = null;
    String s = url.getFile();
    int i = s.lastIndexOf('.');
    
    if (i > 0 &&  i < s.length() - 1) {
      ext = s.substring(i+1).toLowerCase();
    }
    return ext;
  }
}
