package adequation.Fenetre;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Locale;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

import adequation.ecouteurs.EcouteurBoutonRaz;
import adequation.interfac.InterfaceGlissieres;
import adequation.interfac.InterfaceResultats;
import adequation.ressources.Ressources;


/**
 * Titre :        ADELFE
 * Description :  Atelier pour le DEveloppement de Logiciels a Fonctionnalite Emergente
 * Copyright :    Copyright (c) 2001
 * Socit :      Artal Technologie
 * @author Spey
 * @version 1.0
 */


public class Fenetre extends JPanel {
  
  /*******************************/
  /********** Attributs **********/
  /*******************************/
  
  /** Par defaut, on fixe la langue et le pays a ceux par defaut de l'OS */
  private static String _langue = Locale.getDefault().getLanguage();;
  private static String _pays = Locale.getDefault().getCountry();
  
  
  
  
  
  /***********************************/
  /********** Constructeurs **********/
  /***********************************/
  
  /*******************************************************************************************/
  /** constructeur parametre */
  public Fenetre(JFrame frame) {
    // application de la grille generale
    setLayout(new BorderLayout());
    
    // creation du panneau des questions
    InterfaceGlissieres panneau_glissieres = new InterfaceGlissieres(frame);
    
    // fenetre avec scrollBar qui va accueillir le panneau des questions
    JScrollPane panneau_scroll = new JScrollPane();
    
    // affectation de la taille
    panneau_scroll.setPreferredSize(new Dimension(500, 460));
    
    // ajout du panneau des glissieres
    panneau_scroll.getViewport().add(panneau_glissieres);
    
    // ajout du panneau scrolle au centre de la fenetre globale
    add(panneau_scroll, BorderLayout.CENTER);
    
    // creation du panneau permettant d'afficher les resultats et le bouton de Remise a Zero
    JPanel panneau_bas = new JPanel();
    
    // affectation de la grille classique
    panneau_bas.setLayout(new BorderLayout());
    
    // ajout du panneau des resultat au centre
    panneau_bas.add(new InterfaceResultats(frame), BorderLayout.CENTER);
    
    // Creation du bouton de Remise a Zero
    JButton raz = new JButton(Ressources.getInstance().getTexteBoutonRaz());
    
    // si le background du bouton doit etre colore
    if (Ressources.getInstance().getBackgroundRaz() != null) {
      // Coloriage du bouton
      raz.setBackground(Ressources.getInstance().getBackgroundRaz());
    }
    
    // si le foreground du bouton doit etre colore
    if (Ressources.getInstance().getForegroundRaz() != null) {
      // Coloriage du bouton
      raz.setForeground(Ressources.getInstance().getForegroundRaz());
    }
    
    // Affectation de l'ecouteur du bouton
    raz.addActionListener(new EcouteurBoutonRaz());
    
    // ajout du bouton en bas du panneau
    panneau_bas.add(raz, BorderLayout.SOUTH);
    
    // ajout du panneau en bas de la fenetre globale
    add(panneau_bas, BorderLayout.SOUTH);
    
    // application du style Windows a la fenetre
    try {
      UIManager.setLookAndFeel(Ressources.getInstance().getLaf());
      SwingUtilities.updateComponentTreeUI(this);
    }
    catch (Exception e) {}
  }
  
  
  
  
  
  /*************************************/
  /********** Autres mthodes **********/
  /*************************************/
  
  /*******************************************************************************************/
  /** Main */
  public static void main(String[] arg) {
    // si la langue est passee en parametre
    if (arg.length == 1) {
      // Affichage de la langue choisie
      System.out.print("\nLangue: ");
      
      // si l'utilisateur veut l'interface en francais
      if (arg[0].equals("francais")) {
        // Affichage de la langie choisie
        System.out.println("Franais");
        
        // on regle les parametre de langue en fonction
        _langue = "fr";
        _pays = "FR";
      }
      
      // sinon s'il veut l'anglais comme langue
      else if (arg[0].equals("anglais")) {
        // Affichage de la langie choisie
        System.out.println("Anglais");
        
        // pouf pouf, on met l'anglais
        _langue = "en";
        _pays = "EN";
      }
      
      // si l'utilisateur demande une autre langue, c'est que c'est un gros boulet parce qu'il n'y en a pas d'autre pour l'instant
      else {
        System.out.println("\nLa langue que vous demandez n'est pas disponible. Pour l'instant il existe:\n- anglais\n- francais\n");
        System.exit(0);
      }
    }
    
    // creation de la frame generale
    JFrame monCadre = new JFrame(Ressources.getInstance().getTitreAdequation());
    
    // ajout de la fenetre de l'adequation
    monCadre.setContentPane(new Fenetre(monCadre));
    
    // permet de killer le process si on clique sur la croix
    monCadre.addWindowListener(new WindowAdapter() {public void windowClosing(WindowEvent e) {System.exit(0);}});
    
    // permet que la fenetre ne soit pas redimensionnable
    monCadre.setResizable(false);
    
    // mise en place des elements et ajustement de la forme de la fenetre
    monCadre.pack();
    
    // recuperation des dimensions de l'ecran
    Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
    
    // on situe la fenetre au centre de l'ecran
    monCadre.setLocation(screenSize.width/2-monCadre.getSize().width/2, screenSize.height/2-monCadre.getSize().height/2);
    
    // affichage de la fenetre
    monCadre.setVisible(true);
  }
  
  
  
  /*******************************************************************************************/
  /** retourne la langue determinee soit par l'utilisateur soit par le systeme */
  public static String getLangue() {
    return(_langue);
  }
  
  public static void setLangue(String l) {
    _langue = l;
  }
  
  
  
  /*******************************************************************************************/
  /** retourne le pays determine soit par l'utilisateur soit par le systeme */
  public static String getPays() {
    return(_pays);
  }
  
  public static void setPays(String p) {
    _pays = p;
  }
  
}
// fin de la classe Fenetre
