package adequation.Fenetre;

import java.io.*;
import java.util.*;

import adequation.ressources.*;


/**
 * Titre :        ADELFE
 * Description :  Atelier pour le DEveloppement de Logiciels a Fonctionnalite Emergente
 * Copyright :    Copyright (c) 2001
 * Socit :      Artal Technologie
 * @author Spey
 * @version 1.0
 */


public class Glissieres extends Vector
{

/*******************************/
/********** Attributs **********/
/*******************************/

/** Tableau memorisant les ai relatifs au systeme */
	private double _somme_ai_systeme[] = new double[Ressources.getInstance().getMaxGlissiere()+1];

/** Tableau memoridant les ai relatifs aux composants */
	private double _somme_ai_composants[] = new double[Ressources.getInstance().getMaxGlissiere()+1];

/** Somme des coef oui systeme de toutes les questions */
	private int _coef_oui_systeme = 0;

/** Somme des coef non systeme de toutes les questions */
	private int _coef_non_systeme = 0;

/** Somme des coef oui composants de toutes les questions */
	private int _coef_oui_composants = 0;

/** Somme des coef non composants de toutes les questions */
	private int _coef_non_composants = 0;

/** numero du commentaire adequation resultat systeme */
	private int _num_commentaire_adequation_systeme = 0;

/** numero du commentaire precision resultat systeme */
	private int _num_precision_resultat_systeme = 0;

/** numero du commentaire adequation resultat composants */
	private int _num_commentaire_adequation_composants = 0;





/***********************************/
/********** Constructeurs **********/
/***********************************/

/*******************************************************************************************/
/** constructeur par defaut */
    public Glissieres()
	{
		// construction du vecteur
		super();

		// recuperation du nom du fichier contenant les questions
		String fichier_adequation = Ressources.getInstance().getFichierAdequation();

		// verification que le fichier soit bien un fichier ".adelfe"
        if (fichier_adequation.endsWith(".adelfe"))
        {
			// message de debut
			System.out.println("\nInitialisation Glissieres");

			// declaration du RandomAccessFile
			RandomAccessFile fichier = null;

            // tentative d'ouverture du fichier en lecture
		    try
		    {
		        // ouverture du fichier
				fichier = new RandomAccessFile(fichier_adequation, "r");
                //fichier = new RandomAccessFile(getClass().getResource(fichier_adequation).getFile(), "r");
		    }

		    // on leve l'exception
		    catch (IOException ioe)
		    {
			    // on signale l'erreur d'ouverture  l'utilisateur en l'inscrivant dans le fichier des erreurs
			    Erreur.setMessage("Erreur d'ouverture du fichier adequation \"" + fichier_adequation + "\" (Glissieres)");
		    }

            // Dclaration de la variable memorisant les lignes au fur et a mesure de la lecture
		    String ligne = null;

			// lecture de la premiere ligne
            ligne = Ressources.getInstance().litLigne(fichier);

			// tant qu'on a pas lu tout le fichier
			while (ligne != null)
			{
				// si la ligne n'est pas vide, c'est que je suis sur une nouvelle question
				if (!ligne.trim().equals(""))
				{
					// la question est sauvee comme etant le titre du panneau de la glissiere
					String titre_glissiere = ligne;

					// lecture de la ligne suivante contenant les differentes valeurs
                    ligne = Ressources.getInstance().litLigne(fichier);

					// decoupage de la ligne au niveau des "$"
					StringTokenizer decoupe = new StringTokenizer(ligne, "$");

					// pas trop dur
					int non_systeme = (new Integer(decoupe.nextToken())).intValue();
					int oui_systeme = (new Integer(decoupe.nextToken())).intValue();
					int non_composants = (new Integer(decoupe.nextToken())).intValue();
					int oui_composants = (new Integer(decoupe.nextToken())).intValue();

					_coef_oui_systeme += oui_systeme;
					_coef_non_systeme += non_systeme;
					_coef_oui_composants += oui_composants;
					_coef_non_composants += non_composants;

					// lecture de la ligne suivante contenant le texte de l'aide
                    ligne = Ressources.getInstance().litLigne(fichier);

					// creation de la glissiere
					add(new Glissiere(0, titre_glissiere, non_systeme, oui_systeme, non_composants, oui_composants, ligne));
				}

				// lecture de la ligne suivante
                ligne = Ressources.getInstance().litLigne(fichier);
			}

			// fermeture du fichier
            try {fichier.close();}
		    catch (IOException ioe) {Erreur.setMessage("Erreur lors de la fermeture du fichier des pages (Glissieres)");}

			// message de fin
			System.out.println("Fin Initialisation Glissieres");
        }

		// si le fichier n'est pas un fichier ".adelfe"
        else
        {
			// on envoie un message pour le signaler a l'utilisateur
			Erreur.setMessage("Le fichier des pages " + fichier_adequation + " a ouvrir n'est pas un fichier .adelfe (Glissieres)");
		}
    }





/*************************************/
/********** Autres mthodes **********/
/*************************************/

/*******************************************************************************************/
/**  */
	public void majResultat()
	{
		// initialisation du ai inferieur
		double ai_inf_systeme = Ressources.getInstance().getMaxGlissiere()*size()*10000;
		double ai_inf_composants = Ressources.getInstance().getMaxGlissiere()*size()*10000;

		// initialisation des i_min
		int i_min_systeme = 0;
		int i_min_composants = 0;

		// comptabilise les ecarts qu'il y a entre chaque reponse et la reponse globale
		int somme_ecarts_systeme = 0;

		// comptabilise le nombre de points gaux au minimum de la reponse totale
		// ca correspond au segment que peut etre le minimum local
		int cpt_inf_systeme = 0;
		int cpt_inf_composants = 0;

		// memorise successivement le min de la glissiere et son coef
		// le coef d'un glissiere etant un mix entre le coef "oui" et le coef "non"
		Vector couple_coef_imin = new Vector();

	    // Remise a 0 du tableau des resultats (somme des ai de toutes les glissieres)
		for (int i=0; i<_somme_ai_systeme.length; i++)
		{
			_somme_ai_systeme[i] = 0;
			_somme_ai_composants[i] = 0;
		}

		// pour chaque glissiere
		for (Enumeration enum = elements(); enum.hasMoreElements();)
		{
			Glissiere glissiere = (Glissiere)enum.nextElement();

			// memorisation de la valeur de la glissiere
			couple_coef_imin.add(new Integer(glissiere.getValue()));

			// calcul et memorisation de la valeur du coef moyen
			couple_coef_imin.add(new Integer((glissiere.getValOuiSysteme()+glissiere.getValNonSysteme())/2));

			// pour chaque case du tableau resultat
			for (int j=0; j<_somme_ai_systeme.length; j++)
			{
				// si la reponse est du cote NON
				/*if (glissiere.getValue() < Ressources.getInstance().getMaxGlissiere()/2)
				{
					// on comptabilise la reponse affectee du coef NON
					_somme_ai_systeme[j] += glissiere.getValNonSysteme() * Math.abs(glissiere.getValue()-j);
					_somme_ai_composants[j] += glissiere.getValNonComposants() * Math.abs(glissiere.getValue()-j);
				}

				// si la reponse se trouve du cote OUI
				else
				{
					// on comptabilise la reponse affecteee du coef OUI
					_somme_ai_systeme[j] += glissiere.getValOuiSysteme() * Math.abs(glissiere.getValue()-j);
					_somme_ai_composants[j] += glissiere.getValOuiComposants() * Math.abs(glissiere.getValue()-j);
				}*/

				_somme_ai_systeme[j] += glissiere._coef_systeme[glissiere.getValue()] * Math.abs(glissiere.getValue()-j);
				_somme_ai_composants[j] += glissiere._coef_composants[glissiere.getValue()] * Math.abs(glissiere.getValue()-j);






				// si on passe la derniere glissiere, on en profite pour recuperer les min
			    if (!enum.hasMoreElements())
			    {
					// si le ai systeme courant est egal au min systeme
					if (_somme_ai_systeme[j] == ai_inf_systeme)
					{
						// on le compte
						cpt_inf_systeme++;
					}

			    	// si il est inferieur au min systeme
			        else if (_somme_ai_systeme[j] < ai_inf_systeme)
			        {
						// on le memorise comme nouveau min systeme
				        ai_inf_systeme = _somme_ai_systeme[j];

						// on releve sa position
						i_min_systeme = j;

						// et on iniitialise le compteur des min systeme
						cpt_inf_systeme = 1;
			        }

					// pareil pour les composants
					if (_somme_ai_composants[j] == ai_inf_composants)
					{
						cpt_inf_composants++;
					}

			        if (_somme_ai_composants[j] < ai_inf_composants)
			        {
				        ai_inf_composants = _somme_ai_composants[j];
						i_min_composants = j;
						cpt_inf_composants = 1;
			        }
				}
			}
		}

		// calcul de la position du min systeme
		i_min_systeme -= cpt_inf_systeme/2;

		// calcul de la position du min composants
		i_min_composants -= cpt_inf_composants/2;

		// on mesure les ecarts totaux qu'il y a entre chaque reponse et la reponse totale
		// Cela sert a mesurer la coherence entre les reponses
		// Pour chaque couple (valeur de la glissiere, coef)
		for (Enumeration enum = couple_coef_imin.elements(); enum.hasMoreElements();)
		{
			// on additionne la distance entre la position de la glissiere et la reponse totale
			// ceci affecte du coef
			somme_ecarts_systeme += Math.abs(((Integer)enum.nextElement()).intValue()-i_min_systeme) * ((Integer)enum.nextElement()).intValue();
		}

		// calcul du maximum theorique systeme
		int max_theorique_systeme = (_coef_non_systeme+_coef_oui_systeme)*Ressources.getInstance().getMaxGlissiere()/2;

		// calaul du maximum theorique composants
		int max_theorique_composants = (_coef_non_composants+_coef_oui_composants)*Ressources.getInstance().getMaxGlissiere()/2;
                System.out.println("ai: "+ai_inf_systeme+"\t"+ai_inf_composants);
                System.out.println("imin: "+i_min_systeme+"\t"+i_min_composants);
		// pour chaque ai
		for (int i=0; i<_somme_ai_systeme.length; i++)
		{
			// on tronque a un dixieme du max theorique et on echelonne ensuite sur [0,255]
			_somme_ai_systeme[i] = Math.min(_somme_ai_systeme[i]-ai_inf_systeme, max_theorique_systeme/10)*255/(max_theorique_systeme/10);
                        //_somme_ai_systeme[i] = (_somme_ai_systeme[i]-ai_inf_systeme)*255/(Math.max(_somme_ai_systeme[0],_somme_ai_systeme[100])-ai_inf_systeme);
			// on tronque a un dixieme du max theorique et on echelonne ensuite sur [0,255]
			_somme_ai_composants[i] = Math.min(_somme_ai_composants[i]-ai_inf_composants, max_theorique_composants/10)*255/(max_theorique_composants/10);
                        //_somme_ai_composants[i] = (_somme_ai_composants[i]-ai_inf_composants)*255/(Math.max(_somme_ai_composants[0],_somme_ai_composants[100])-ai_inf_composants);
		}

		// affichage du resultat
		for (int i=0; i< Ressources.getInstance().getTabResultatSysteme().length; i++)
		{
			Ressources.getInstance().getTabResultatSysteme()[i].repaint();
			Ressources.getInstance().getTabResultatComposants()[i].repaint();
		}

		// calcul du numero du commentaire a afficher pour le resultat systeme
		_num_commentaire_adequation_systeme = (i_min_systeme*Ressources.getInstance().getNbCommmentairesAdequationSysteme()/(Ressources.getInstance().getMaxGlissiere()+1));

		// calcul du numero du commentaire a afficher pour le resultat composants
		_num_commentaire_adequation_composants = (i_min_composants*Ressources.getInstance().getNbCommmentairesAdequationComposants()/(Ressources.getInstance().getMaxGlissiere()+1));

		// Trace pour le commentaire
		System.out.println("\nSomme des ecarts: " + somme_ecarts_systeme);
		System.out.println("Ecart maximum theorique: " + (_coef_oui_systeme+_coef_non_systeme)*50/2);

		// calcul du numero du commentaire a afficher pour la coherence des reponses au niveau du systeme
		_num_precision_resultat_systeme = (int) (somme_ecarts_systeme*Ressources.getInstance().getNbCommmentairesPrecision()/((_coef_oui_systeme+_coef_non_systeme)*50/2));

		// Quand ca depasse le maximum theorique (et oui ca peut arriver a cause des coef qui font chier), on tronque pour pas s'emmerder
		if (_num_precision_resultat_systeme > Ressources.getInstance().getNbCommmentairesPrecision()-1)
		{
			_num_precision_resultat_systeme = Ressources.getInstance().getNbCommmentairesPrecision()-1;
		}
	}



/*******************************************************************************************/
/** retourne la glissiere demandee */
	public Glissiere getGlissiere(int i)
	{
		return((Glissiere)get(i));
	}



/*******************************************************************************************/
/** retourne le tableau des ai globaux */
	public double[] getSommeAiSysteme()
	{
		return(_somme_ai_systeme);
	}



/*******************************************************************************************/
/** retourne le tableau des ai loocaux */
	public double[] getSommeAiComposants()
	{
		return(_somme_ai_composants);
	}



/*******************************************************************************************/
/** retourne le numero du commentaire de l'adequation du point de vue systeme */
	public int getNumComAdeqSysteme()
	{
		return(_num_commentaire_adequation_systeme);
	}



/*******************************************************************************************/
/** retourne le numero du commentaire de l'adequation du point de vue composants */
	public int getNumComAdeqComposants()
	{
		return(_num_commentaire_adequation_composants);
	}



/*******************************************************************************************/
/** retourne le numero du commentaire de la prescision du resultat systeme */
	public int getNumPrecResultatSysteme()
	{
		return(_num_precision_resultat_systeme);
	}

}
// fin de la classe Glissieres
