package adequation.ressources;


import java.awt.Color;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.Locale;
import java.util.ResourceBundle;
import java.util.StringTokenizer;
import java.util.Vector;

import adequation.Fenetre.Fenetre;
import adequation.Fenetre.Glissieres;
import adequation.Fenetre.Resultat;
import adequation.ecouteurs.EcouteurSourisResultat;


/**
 * Titre :        ADELFE
 * Description :  Atelier pour le DEveloppement de Logiciels a Fonctionnalite Emergente
 * Copyright :    Copyright (c) 2001
 * Socit :      Artal Technologie
 * @author Spey
 * @version 1.0
 */


public class Ressources {
  
  /*******************************/
  /********** Attributs **********/
  /*******************************/
  
  /** instance unique de la classe */
  private static Ressources _instance = null;
  
  /** RessourceBundle permettant d'accder au fichier .properties definit par le langage utilis sur l'ordinateur */
  private ResourceBundle _resource = null;
  
  /** mmorise le chemin et le nom du fichier dans lequel sont sauves les questions de l'adequation et leur importance */
  private String _fichier_adequation = null;
  
  /** mmorise le titre de la fenetre relative a l'adequation */
  private String _titre_adequation = null;
  
  /** vecteur des commentaires sur l'adequation du systeme */
  private Vector _commentaires_adequation_systeme = null;
  
  /** vecteur des commentaires sur l'adequation des composants */
  private Vector _commentaires_adequation_composants = null;
  
  /** vecteur des commentaires sur la precision des reponses */
  private Vector _commentaires_precision_reponses = null;
  
  /** mmorise la valeur max des glissieres */
  private int _max_glissiere = 0;
  
  /** mmorise la valeur init des glissieres */
  private int _init_glissiere = 0;
  
  /** mmorise la valeur min des ticks des glissieres */
  private int _tick_min_glissiere = 0;
  
  /** mmorise la valeur max des ticks des glissieres */
  private int _tick_max_glissiere = 0;
  
  /** mmorise le nom du label de gauche des glissieres */
  private String _glissiere_label_gauche = null;
  
  /** mmorise le nom du label du milieu des glissieres */
  private String _glissiere_label_milieu = null;
  
  /** mmorise le nom du label de droite des glissieres */
  private String _glissiere_label_droite = null;
  
  /** declaration du tableau memorisant les parties du resultat systeme */
  private Resultat _tab_resultat_systeme[] = null;
  
  /** declaration du tableau memorisant les parties du resultat composants */
  private Resultat _tab_resultat_composants[] = null;
  
  /** definition de l'ecouteur de glissiere */
  private static EcouteurSourisResultat _ecouteur_souris_resultat = null;
  
  /** vecteur des glissieres */
  private static Glissieres _glissieres = null;
  
  /** mmorise le LAF */
  private String _laf = "";
  
  /** definition de la couleur background du fond de la partie glissieres */
  private Color _fond_glissieres_background = null;
  
  /** definition de la couleur foreground du fond de la partie glissieres */
  private Color _fond_glissieres_foreground = null;
  
  /** definition de la couleur background des panneaux des glissieres */
  private Color _panneau_glissiere_background = null;
  
  /** definition de la couleur foreground des panneaux des glissieres */
  private Color _panneau_glissiere_foreground = null;
  
  /** definition de la couleur background des glissieres */
  private Color _glissiere_background = null;
  
  /** definition de la couleur foreground des glissieres */
  private Color _glissiere_foreground = null;
  
  /** definition de la couleur background du fond de la partie resultat */
  private Color _fond_resultat_background = null;
  
  /** definition de la couleur foreground du fond de la partie resultat */
  private Color _fond_resultat_foreground = null;
  
  /** definition de la couleur background de l'aide */
  private Color _aide_background = null;
  
  /** definition de la couleur foreground de l'aide */
  private Color _aide_foreground = null;
  
  /** definition de la couleur background du bouton RAZ */
  private Color _raz_background = null;
  
  /** definition de la couleur foreground du bouton RAZ */
  private Color _raz_foreground = null;
  
  /** mmorise le texte a afficher sur le bouton RAZ */
  private String _texte_bouton_raz = "";
  
  /** definition de la couleur background de la partie resultat */
  private Color _resultat_background = null;
  
  /** definition de la couleur foreground de la partie resultat */
  private Color _resultat_foreground = null;
  
  /** mmorise le titre du resultat global */
  private String _titre_resultat_systeme = null;
  
  /** mmorise le titre du resultat local */
  private String _titre_resultat_composants = null;
  
  /** mmorise le nom du label de gauche des rsultats */
  private String _resultat_label_gauche = null;
  
  /** mmorise le nom du label du milieu des rsultats */
  private String _resultat_label_milieu = null;
  
  /** mmorise le nom du label de droite des rsultats */
  private String _resultat_label_droite = null;
  
  /** couleur indicatrice du degrade du resultat */
  private Color _resultat_degrade_couleur = null;
  
  /** couleur de fond du degrade du resultat */
  private Color _resultat_degrade_fond = null;
  
  
  
  
  
  /***********************************/
  /********** Constructeurs **********/
  /***********************************/
  
  /*******************************************************************************************/
  /** constructeur par defaut */
  public Ressources() {
    _resource = ResourceBundle.getBundle("adelfeToolkit/adequacy/Adelfe", new Locale(Fenetre.getLangue(), Fenetre.getPays()));//Locale.getDefault().getLanguage(), Locale.getDefault().getCountry()));
    
    _fichier_adequation = _resource.getString("ADEQUATION.FICHIER");
    
    _titre_adequation = _resource.getString("ADEQUATION.TITRE");
    
    System.out.println("\nGnration des commentaires");
    _commentaires_adequation_systeme = fichierToCommentaires(_resource.getString("COMMENTAIRES.ADEQUATION_SYSTEME"));
    _commentaires_adequation_composants = fichierToCommentaires(_resource.getString("COMMENTAIRES.ADEQUATION_COMPOSANTS"));
    _commentaires_precision_reponses = fichierToCommentaires(_resource.getString("COMMENTAIRES.PRECISION_REPONSES"));
    System.out.println("Fin gnration des commentaires");
    
    _max_glissiere = (new Integer(_resource.getString("GLISSIERE.MAX"))).intValue();
    _init_glissiere = (new Integer(_resource.getString("GLISSIERE.INIT"))).intValue();
    _tick_min_glissiere = (new Integer(_resource.getString("GLISSIERE.TICKMIN"))).intValue();
    _tick_max_glissiere = (new Integer(_resource.getString("GLISSIERE.TICKMAX"))).intValue();
    
    _glissiere_label_gauche = _resource.getString("GLISSIERE.LABEL_GAUCHE");
    _glissiere_label_milieu = _resource.getString("GLISSIERE.LABEL_MILIEU");
    _glissiere_label_droite = _resource.getString("GLISSIERE.LABEL_DROITE");
    
    _tab_resultat_systeme = new Resultat[_max_glissiere+1];
    _tab_resultat_composants = new Resultat[_max_glissiere+1];
    
    _laf = _resource.getString("INTERFACE.LAF");
    
    _fond_glissieres_background = stringToColor(_resource.getString("FOND_GLISSIERES.BACKGROUND"));
    _fond_glissieres_foreground = stringToColor(_resource.getString("FOND_GLISSIERES.FOREGROUND"));
    
    _panneau_glissiere_background = stringToColor(_resource.getString("PANNEAU_GLISSIERE.BACKGROUND"));
    _panneau_glissiere_foreground = stringToColor(_resource.getString("PANNEAU_GLISSIERE.FOREGROUND"));
    
    _glissiere_background = stringToColor(_resource.getString("GLISSIERE.BACKGROUND"));
    _glissiere_foreground = stringToColor(_resource.getString("GLISSIERE.FOREGROUND"));
    
    _fond_resultat_background = stringToColor(_resource.getString("FOND_RESULTAT.BACKGROUND"));
    _fond_resultat_foreground = stringToColor(_resource.getString("FOND_RESULTAT.FOREGROUND"));
    
    _aide_background = stringToColor(_resource.getString("AIDE.BACKGROUND"));
    _aide_foreground = stringToColor(_resource.getString("AIDE.FOREGROUND"));
    
    _raz_background = stringToColor(_resource.getString("BOUTON_RAZ.BACKGROUND"));
    _raz_foreground = stringToColor(_resource.getString("BOUTON_RAZ.FOREGROUND"));
    
    _texte_bouton_raz = _resource.getString("BOUTON_RAZ.TEXTE");
    
    _resultat_background = stringToColor(_resource.getString("RESULTAT.BACKGROUND"));
    _resultat_foreground = stringToColor(_resource.getString("RESULTAT.FOREGROUND"));
    
    _titre_resultat_systeme = _resource.getString("RESULTAT.TITRE_SYSTEME");
    _titre_resultat_composants = _resource.getString("RESULTAT.TITRE_COMPOSANTS");
    
    _resultat_label_gauche = _resource.getString("RESULTAT.LABEL_GAUCHE");
    _resultat_label_milieu = _resource.getString("RESULTAT.LABEL_MILIEU");
    _resultat_label_droite = _resource.getString("RESULTAT.LABEL_DROITE");
    
    _resultat_degrade_couleur = stringToColor(_resource.getString("RESULTAT.COULEUR_INDICATRICE"));
    _resultat_degrade_fond = stringToColor(_resource.getString("RESULTAT.COULEUR_FOND"));
  }
  
  
  
  
  
  /*************************************/
  /********** Autres Methodes **********/
  /*************************************/
  
  /*******************************************************************************************/
  /** retourne l'instance unique de la classe */
  public static Ressources getInstance() {
    if (_instance == null) {
      _instance = new Ressources();
      
      _ecouteur_souris_resultat = new EcouteurSourisResultat();
      
      _glissieres = new Glissieres();
    }
    
    return (_instance);
  }
  
  
  /*******************************************************************************************/
  /** retourne l'emplacement physique du fichier adequation */
  public String getFichierAdequation() {
    return (_fichier_adequation);
  }
  
  
  /*******************************************************************************************/
  /** retourne le titre de la fenetre de l'adequation */
  public String getTitreAdequation() {
    return (_titre_adequation);
  }
  
  
  /*******************************************************************************************/
  /** retourne la valeur max des glissieres */
  public int getMaxGlissiere() {
    return (_max_glissiere);
  }
  
  
  /*******************************************************************************************/
  /** retourne la valeur init des glissieres */
  public int getInitGlissiere() {
    return (_init_glissiere);
  }
  
  
  /*******************************************************************************************/
  /** retourne la valeur min des ticks des glissieres */
  public int getTickMinGlissiere() {
    return (_tick_min_glissiere);
  }
  
  
  /*******************************************************************************************/
  /** retourne la valeur max des ticks des glissieres */
  public int getTickMaxGlissiere() {
    return (_tick_max_glissiere);
  }
  
  
  /*******************************************************************************************/
  /** retourne le label de gauche des glissieres */
  public String getLabelGaucheGlissiere() {
    return (_glissiere_label_gauche);
  }
  
  
  /*******************************************************************************************/
  /** retourne le label du milieu des glissieres */
  public String getLabelMilieuGlissiere() {
    return (_glissiere_label_milieu);
  }
  
  
  /*******************************************************************************************/
  /** retourne le label de droite des glissieres */
  public String getLabelDroiteGlissiere() {
    return (_glissiere_label_droite);
  }
  
  
  /*******************************************************************************************/
  /** retourne le tableau des resultats systeme */
  public Resultat[] getTabResultatSysteme() {
    return (_tab_resultat_systeme);
  }
  
  
  /*******************************************************************************************/
  /** retourne le tableau des resultats composants */
  public Resultat[] getTabResultatComposants() {
    return (_tab_resultat_composants);
  }
  
  
  /*******************************************************************************************/
  /** retourne le vecteur des glissieres */
  public Glissieres getGlissieres() {
    return (_glissieres);
  }
  
  
  /*******************************************************************************************/
  /** retourne l'ecouteur des glissieres */
  public EcouteurSourisResultat getEcouteurSourisResultat() {
    return (_ecouteur_souris_resultat);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background du fond de la partie glissieres */
  public Color getBackgroundFondGlissieres() {
    return (_fond_glissieres_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground du fond de la partie glissieres */
  public Color getForegroundFondGlissieres() {
    return (_fond_glissieres_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background du fond de la partie resultat */
  public Color getBackgroundFondResultat() {
    return (_fond_resultat_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground du fond de la partie resultat */
  public Color getForegroundFondResultat() {
    return (_fond_resultat_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background des panneau des glissieres */
  public Color getBackgroundPanneauGlissiere() {
    return (_panneau_glissiere_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground des panneaux des glissieres */
  public Color getForegroundPanneauGlissiere() {
    return (_panneau_glissiere_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background des glissieres */
  public Color getBackgroundGlissiere() {
    return (_glissiere_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground des glissieres */
  public Color getForegroundGlissiere() {
    return (_glissiere_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background de la partie resultat */
  public Color getBackgroundResultat() {
    return (_resultat_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground de la partie resultat */
  public Color getForegroundResultat() {
    return (_resultat_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background de l'aide */
  public Color getBackgroundAide() {
    return (_aide_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground de l'aide */
  public Color getForegroundAide() {
    return (_aide_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur background du bouton raz */
  public Color getBackgroundRaz() {
    return (_raz_background);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur foreground du bouton raz */
  public Color getForegroundRaz() {
    return (_raz_foreground);
  }
  
  
  /*******************************************************************************************/
  /** retourne le texte du bouton raz */
  public String getTexteBoutonRaz() {
    return (_texte_bouton_raz);
  }
  
  
  /*******************************************************************************************/
  /** retourne le Laf */
  public String getLaf() {
    return (_laf);
  }
  
  
  /*******************************************************************************************/
  /** retourne le titre du rsultat "systeme" */
  public String getTitreSysteme() {
    return (_titre_resultat_systeme);
  }
  
  
  /*******************************************************************************************/
  /** retourne le titre du rsultat "composants" */
  public String getTitreComposants() {
    return (_titre_resultat_composants);
  }
  
  
  /*******************************************************************************************/
  /** retourne le texte du label de gauche du resultat */
  public String getLabelGaucheResultat() {
    return (_resultat_label_gauche);
  }
  
  
  /*******************************************************************************************/
  /** retourne le texte du label du milieu du resultat */
  public String getLabelMilieuResultat() {
    return (_resultat_label_milieu);
  }
  
  
  /*******************************************************************************************/
  /** retourne le texte du label de droite du resultat */
  public String getLabelDroiteResultat() {
    return (_resultat_label_droite);
  }
  
  
  /*******************************************************************************************/
  /** retourne la couleur du fond du degrade de la partie resultat */
  public Color getResultatDegradeCouleurFond() {
    return (_resultat_degrade_fond);
  }
  
  
  /*******************************************************************************************/
  /** retourne le denominateur du vert pour l'affichage des degrades */
  public Color getResultatDegradeCouleurIndicatrice() {
    return (_resultat_degrade_couleur);
  }
  
  
  /*******************************************************************************************/
  /** retourne le commentaire de l'adequation au niveau du systeme qui va bien */
  public String getCommmentaireSysteme(int i) {
    return ((String) _commentaires_adequation_systeme.get(i));
  }
  
  
  /*******************************************************************************************/
  /** retourne le commentaire de l'adequation au niveau des composants qui va bien */
  public String getCommmentaireComposants(int i) {
    return ((String) _commentaires_adequation_composants.get(i));
  }
  
  
  /*******************************************************************************************/
  /** retourne le commentaire qui va bien sur la precision */
  public String getCommmentairePrecision(int i) {
    return ((String) _commentaires_precision_reponses.get(i));
  }
  
  
  /*******************************************************************************************/
  /** retourne le nombre de commentaires de precision */
  public int getNbCommmentairesPrecision() {
    return (_commentaires_precision_reponses.size());
  }
  
  
  /*******************************************************************************************/
  /** retourne le nombre de commentaires sur l'adequation des composants */
  public int getNbCommmentairesAdequationComposants() {
    return (_commentaires_adequation_composants.size());
  }
  
  
  /*******************************************************************************************/
  /** retourne le nombre de commentaires sur l'adequation du systeme */
  public int getNbCommmentairesAdequationSysteme() {
    return (_commentaires_adequation_systeme.size());
  }
  
  
  /*******************************************************************************************/
  /** transforme une chaine "int,int,int" en Color */
  public Color stringToColor(String chaine) {
    // si l'utilisateur ne souhaite pas de couleur
    if (chaine.equals("incolore")) {
      return(null);
    }
    
    // sinon, on decoupe le parametre en 3 entier
    StringTokenizer decoupe = new StringTokenizer(chaine, ",");
    
    // et on renvoie la couleur correspondante
    return (new Color((new Integer(decoupe.nextToken())).intValue(),
    (new Integer(decoupe.nextToken())).intValue(),
    (new Integer(decoupe.nextToken())).intValue()));
  }
  
  
  
  /*******************************************************************************************/
  /** retourne la premiere ligne qui n'est pas un commentaire */
  public String litLigne(RandomAccessFile fichier) {
    // declaration de la String servant de tampon de lecture
    String ligne = null;
    
    // lecture de la ligne suivante
    try {ligne = fichier.readLine();}
    catch (IOException ioe) {Erreur.setMessage("Erreur de lecture d'une ligne dans le fichier \"" + fichier + "\" (Ressources.litLigne)");}
    
    //
    if (ligne == null) {
      return(ligne);
    }
    
    // si la ligne commence par la chaine de commentaire
    if (ligne.trim().startsWith("/*")) {
      // on lit la ligne suivante
      return litLigne(fichier);
    }
    
    // retour de la ligne
    return(ligne);
  }
  
  
  
  /*******************************************************************************************/
  /** extrait du fichier en parametre un vecteur de commentaires */
  public Vector fichierToCommentaires(String nom_fichier) {
    // creation du vecteur permettant de memoriser les differents commentaires
    Vector commentaires = new Vector();
    
    // verification que le fichier soit bien un fichier ".adelfe"
    if (nom_fichier.endsWith(".adelfe")) {
      // message de debut
      System.out.println("ouverture du fichier: " + nom_fichier);
      System.out.println();
      // declaration du RandomAccessFile
      RandomAccessFile fichier = null;
      
      // tentative d'ouverture du fichier en lecture
      try {
        //System.out.println(getClass().getResource(nom_fichier).getFile().toString());
        // ouverture du fichier
        //fichier = new RandomAccessFile(getClass().getResource(nom_fichier).getFile(), "r");
        System.out.println(nom_fichier);
        fichier = new RandomAccessFile(nom_fichier,"r");
      }
      
      // on leve l'exception
      catch (IOException ioe) {
        // on signale l'erreur d'ouverture  l'utilisateur en l'inscrivant dans le fichier des erreurs
        Erreur.setMessage("Erreur d'ouverture du fichier de commentaires \"" + nom_fichier + "\" (Ressources)");
      }
      
      // Dclaration de la variable memorisant les lignes au fur et a mesure de la lecture
      String ligne = null;
      
      // lecture de la premiere ligne
      ligne = litLigne(fichier);
      
      // tant qu'on a pas lu tout le fichier
      while (ligne != null) {
        // si la ligne n'est pas vide, c'est que je suis sur un nouveau commentaire
        if (!ligne.trim().equals("")) {
          // je le memorise donc
          commentaires.add(ligne.trim());
        }
        
        // lecture de la ligne suivante
        ligne = litLigne(fichier);
      }
      
      // fermeture du fichier
      try {fichier.close();}
      catch (IOException ioe) {Erreur.setMessage("Erreur lors de la fermeture du fichier des commentaires " + nom_fichier + " (Ressources)");}
    }
    
    // si le fichier n'est pas un fichier ".adelfe"
    else {
      // on envoie un message pour le signaler a l'utilisateur
      Erreur.setMessage("Le fichier des commentaires " + nom_fichier + " a ouvrir n'est pas un fichier .adelfe (Ressources)");
    }
    
    // retour du vecteur des commentaires
    return(commentaires);
  }
  
}
// fin de la classe Ressources
